<?php

use App\Models\Currency;
use App\Models\Menu;
use App\Models\Option;
use Illuminate\Pagination\LengthAwarePaginator;
use Illuminate\Pagination\Paginator;
use Illuminate\Support\Collection;
use App\Helpers\API\Context;
use App\Models\Language;

if (!function_exists('get_option')) {
    function get_option($name, $default = null)
    {
        return Option::getOption($name, $default);
    }
}

if (!function_exists('collectionPaginate')) {
    function collectionPaginate(Collection $items, $perPage = 15, $page = null, $options = [])
    {
        $page = $page ?: (Paginator::resolveCurrentPage() ?: 1);

        $items = $items instanceof Collection ? $items : Collection::make($items);

        return new LengthAwarePaginator($items->forPage($page, $perPage), $items->count(), $perPage, $page, $options);
    }
}

if (!function_exists('convert_currency')) {
    function convert_currency($amount, $to, $from = null)
    {
        if (!$from) {
            $from = Currency::getDefaultCurrency();
        } elseif (is_string($from)) {
            $from = Currency::query()->where('code', $from)->first();
        }
        $to = Currency::query()->where('code', $to)->first();
        if (!($from instanceof Currency) || !($to instanceof Currency) || !is_numeric($amount)) throw new Exception('Unable to convert currency');
        return $amount * ($to->rate / $from->rate);
    }
}

if (!function_exists('as_currency')) {
    function as_currency($amount)
    {
        $defaultCurrency = Currency::getDefaultCurrency();
        $requestCurrencyCode = Context::getCurrency();
        if (!$requestCurrencyCode) return round($amount, config('iwallet.decimals'));
        if (strtolower($defaultCurrency->code) != strtolower($requestCurrencyCode)) {
            return round(convert_currency($amount, $requestCurrencyCode, $defaultCurrency->code), config('iwallet.decimals'));
        }
        return round($amount, config('iwallet.decimals'));
    }
}

function trim_zeros($amount, $currency)
{
    return preg_replace('/' . preg_quote($currency->decimal_separator, '/') . '0++$/', '', $amount);
}

function currency_format_decimal($amount, $currency)
{
    $decimal_separator = $currency->decimal_separator ?? '.';
    $thousand_separator = $currency->thousand_separator ?? ',';
    $decimals = is_numeric($currency->precision) ? $currency->precision : 2;
    $amount = number_format($amount, $decimals, $decimal_separator, $thousand_separator);
    if ($decimals > 0) {
        $amount = trim_zeros($amount, $currency);
    }
    return $amount;
}

function currency_round($amount, $currency)
{
    $decimals = is_numeric($currency->precision) ? $currency->precision : 2;
    return round($amount, $decimals);
}

function currency_format($amount, $currency = null)
{
    $currency = $currency ?? Currency::getDefaultCurrency();
    $price_format = config('currencies.formats.' . ($currency->symbol_position ?? 'left'));

    $negative = $amount < 0;
    $amount = floatval($negative ? $amount * -1 : $amount);
    $amount = currency_format_decimal($amount, $currency);

    $formatted_price = ($negative ? '-' : '') . sprintf($price_format, $currency->symbol, $amount);

    return html_entity_decode($formatted_price);
}

function get_language_list()
{
    $languages = Language::where('status',1)->get();
    if ($languages->count()<=0){
        $languages =[];
    }
    return $languages;
}

if (!function_exists('get_nav_menu')) {
    function get_nav_menu($menu_location, $items_only = true)
    {
        $menu = Menu::where('location', $menu_location)
            ->with(['parent_items.children' => function ($q) {
                $q->orderBy('order');
            }])->first();

        $menuItems = (!is_null($menu)) ? $menu : null;
        return $menuItems;
    }
}
