<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Foundation\Auth\AuthenticatesUsers;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Laravel\Socialite\Facades\Socialite;

class LoginController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Login Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles authenticating users for the application and
    | redirecting them to your home screen. The controller uses a trait
    | to conveniently provide its functionality to your applications.
    |
    */

    use AuthenticatesUsers;

    /**
     * Where to redirect users after login.
     *
     * @var string
     */
    protected $redirectTo = '/dashboard';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest:web')->except('logout');
    }

    /**
     * Show the application's login form.
     *
     * @return \Illuminate\View\View
     */
    public function showLoginForm()
    {
        return view('auth.login');
    }

    protected function guard()
    {
        return Auth::guard('web');
    }

    /**
     * Get the needed authorization credentials from the request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    protected function credentials(Request $request)
    {
        if (filter_var($request->username, FILTER_VALIDATE_EMAIL)) {
            return ['email' => $request->username, 'password' => $request->password, 'status' => 1];
        }
        return ['username' => $request->username, 'password' => $request->password, 'status' => 1];
    }

    public function username()
    {
        return 'username';
    }

    /**
     * Redirect the user to the GitHub authentication page.
     *
     * @param $provider
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function redirectToProvider($provider)
    {
        return Socialite::driver($provider)->redirect();
    }

    /**
     * Obtain the user information from GitHub.
     *
     * @param $provider
     */
    public function handleProviderCallback($provider)
    {
        try {
            if($provider == 'google') {

                $userResponse = Socialite::driver('google')->stateless()->user();
            }else{
                $userResponse = Socialite::driver($provider)->user();
            }

            $provider_id = $userResponse->getId();

            $user = User::query()->whereHas('socialAccounts', function ($q) use ($provider,$provider_id) {
                $q->where('provider', $provider)->where('provider_id', $provider_id);
            })->where('status', 1)->first();

            if (!$user) {
                $n = $userResponse->getName();;
                $u = Str::slug($n);
                $e = $userResponse->getEmail() ?? $u . '@' . $provider . '.com';
                $status = config('iwallet.default_user_status', 1);
                /* @var User $user */
                $user = User::create([
                    'name' => $n,
                    'username' => $u,
                    'email' => $e,
                    'phone' => null,
                    'password' => Hash::make($provider_id),
                    'email_verified_at' => now(),
                    'phone_verified_at' => now(),
                    'status' => $status
                ]);
                $user->socialAccounts()->create([
                    'provider' => $provider,
                    'provider_id' => $provider_id,
                ]);
            }

            if ($user->status == 1) {
                Auth::guard('web')->login($user,true);

                return redirect()->route('dashboard');
            }
        }catch (\Exception $e) {
            return redirect()->route('login');
        }


        return redirect()->route('login');
    }
}
