<?php

namespace App\Http\Controllers\Staff;

use App\Models\PaymentGateway;
use App\Models\Staff;
use App\Models\Transaction;
use App\Models\User;
use App\Models\Withdraw;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class MixedController
{
    function dashboard()
    {
        $todayTotalWithdrawRequests = Withdraw::whereDate('created_at', date('Y-m-d'))->count();
        $todayTotalTransactions = Transaction::whereDate('created_at', date('Y-m-d'))->count();
        $totalActiveCustomers = User::where('status',1)->count();
        $totalActivePaymentGateways = PaymentGateway::where('status',1)->count();
        return view('staff.dashboard',compact('todayTotalWithdrawRequests','todayTotalTransactions','totalActiveCustomers','totalActivePaymentGateways'));
    }

    function profile()
    {
        $user = \request()->user('staff');
        return view('staff.profile', compact('user'));
    }

    function updateProfile(Request $request)
    {
        /* @var Staff $user */
        $user = Auth::guard('staff')->user();
        $request->validate([
            'name' => 'required|max:191',
            'email' => 'required|max:191|email|unique:staff,email,' . $user->id,
            'phone' => 'required|numeric|unique:staff,phone,' . $user->id,
            'password' => 'nullable|min:6|confirmed'
        ]);
        $p = $request->only(['name', 'email', 'phone', 'avatar']);
        if ($request->password) {
            $p['password'] = Hash::make($request->password);
        }
        try {
            $r = $user->update($p);
            if (!$r) throw new \Exception('Unable to update profile');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors($exception->getMessage());
        }
        return redirect()->back()->withSuccess('Profile updated successfully');
    }
}
