<?php

namespace App\Http\Controllers\Staff;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Yajra\DataTables\DataTableAbstract;
use App\Models\Subnotification;

class NotificationController extends Controller
{
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $query = Subnotification::query()->with('notification')->where([['notifiable_id',Auth::guard('staff')->id()],['read_at',NULL]]);
            /* @var DataTableAbstract $table */
            $table = datatables()->of($query);
            $table->editColumn('title', function (Subnotification $subnotification) {
                return $subnotification->notification->data['title'] ?? '' ;
            });
            $table->editColumn('message', function (Subnotification $subnotification) {
                return $subnotification->notification->data['message'] ?? '' ;
            });

            $table->addColumn('actions', function (Subnotification $subnotification) {
                return '<a class="btn btn-sm btn-warning mr-2" href="' . route('staff.view-notification', $subnotification->id) . '"><i class="fa fa-eye"></i></a>';
            });
            $table->rawColumns(['title', 'message', 'actions']);
            return $table->make(true);
        }
        return view('staff.notification.index');
    }

    public function show($notificationID)
    {
        $subnotification = Subnotification::where([['id',$notificationID],['notifiable_id',Auth::guard('staff')->id()]])->firstOrfail();
        $subnotification->markAsRead();
        if (isset($subnotification->notification->data['action']) && !is_null($subnotification->notification->data['action'])){
            return redirect($subnotification->notification->data['action']);
        }
        return redirect()->back();
    }

    public function clearAll(){
        foreach (Auth::user()->unreadSubnotifications as $subnotification) {
            $subnotification->markAsRead();
        }
        return redirect()->back();
    }
}
