<?php

namespace App\Http\Controllers\Staff;

use App\Models\Currency;
use App\Http\Controllers\Controller;
use App\Models\Input;
use App\Models\PaymentMethod;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\DB;
use Yajra\DataTables\DataTableAbstract;

class PaymentMethodController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @param Request $request
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Http\JsonResponse|\Illuminate\Http\Response|\Illuminate\View\View
     * @throws \Exception
     */
    public function index(Request $request)
    {
        $currency = Currency::getDefaultCurrency();
        $query = PaymentMethod::query();
        if (!(clone $query)->count()) {
            // Insert Into table
            PaymentMethod::generateMethods();
        }
        if ($request->ajax()) {
            /* @var DataTableAbstract $table */
            $table = datatables()->of($query);
            $table->editColumn('min', function (PaymentMethod $paymentMethod) use ($currency) {
                return $paymentMethod->min == -1 ? '<span class="badge badge-info">no limit</span>' : '<span class="badge badge-info">' . $paymentMethod->min . ' ' . $currency->code . '</span>';
            });
            $table->editColumn('max', function (PaymentMethod $paymentMethod) use ($currency) {
                return $paymentMethod->max == -1 ? '<span class="badge badge-info">no limit</span>' : '<span class="badge badge-info">' . $paymentMethod->max . ' ' . $currency->code . '</span>';
            });
            $table->addColumn('charge', function (PaymentMethod $paymentMethod) use ($currency) {
                return sprintf('<span class="badge badge-info">%s%% + %s %s</span>', $paymentMethod->percent_charge, $paymentMethod->fixed_charge, $currency->code);
            });
            $table->editColumn('status', function (PaymentMethod $paymentMethod) use ($currency) {
                return $paymentMethod->status == 1 ? '<span class="badge badge-success">Enabled</span>' : '<span class="badge badge-danger">Disabled</span>';
            });
            $table->addColumn('actions', function (PaymentMethod $paymentMethod) {
                if ($paymentMethod->type == 'manual') {
                    return '<a href="' . route('staff.setting.payment-method.edit', $paymentMethod->id) . '" class="btn btn-warning nimmu-btn nimmu-btn-warning"><i class="fa fa-edit"></i></a>';
                }
                return '<button class="btn btn-warning btn-edit nimmu-btn nimmu-btn-warning"
                                                            data-id="' . $paymentMethod->id . '"
                                                            data-name="' . $paymentMethod->name . '"
                                                            data-description="' . $paymentMethod->description . '"
                                                            data-min="' . $paymentMethod->min . '"
                                                            data-max="' . $paymentMethod->max . '"
                                                            data-cred1="' . $paymentMethod->cred1 . '"
                                                            data-cred2="' . $paymentMethod->cred2 . '"
                                                            data-percent_charge="' . $paymentMethod->percent_charge . '"
                                                            data-fixed_charge="' . $paymentMethod->fixed_charge . '"
                                                            data-status="' . $paymentMethod->status . '"><i
                                                            class="fa fa-edit"></i></button>';
            });
            $table->rawColumns(['min', 'max', 'charge', 'status', 'actions']);
            return $table->make(true);
        }
        return view('staff.setting.payment-method.index', compact('currency'));
    }

    function create()
    {
        $currency = Currency::getDefaultCurrency();
        return view('staff.setting.payment-method.create', compact('currency'));
    }

    function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:191',
            'description' => 'nullable',
            'min' => 'nullable|numeric',
            'max' => 'nullable|numeric',
            'percent_charge' => 'nullable|numeric',
            'fixed_charge' => 'nullable|numeric',
            'status' => 'nullable',
            'fields' => 'nullable|array',
            'fields.*' => 'nullable|array',
            'fields.*.title' => 'required|string|max:191',
            'fields.*.input_type' => 'required',
            'fields.*.placeholder' => 'nullable|string|max:191',
            'fields.*.is_required' => 'nullable',
            'fields.*.sort' => 'nullable|numeric',
        ]);
        $methodParams = $request->only(['name', 'description', 'min', 'max', 'percent_charge', 'fixed_charge', 'status']);
        if ($request->min && $request->min >= 0) {
            $methodParams['min'] = $request->min;
        } else {
            $methodParams['min'] = -1;
        }
        if ($request->max && $request->max >= 0) {
            $methodParams['max'] = $request->max;
        } else {
            $methodParams['max'] = -1;
        }
        if ($request->percent_charge) {
            $methodParams['percent_charge'] = $request->percent_charge;
        } else {
            $methodParams['percent_charge'] = 0;
        }
        if ($request->fixed_charge) {
            $methodParams['fixed_charge'] = $request->fixed_charge;
        } else {
            $methodParams['fixed_charge'] = 0;
        }
        if ($request->status) {
            $methodParams['status'] = 1;
        } else {
            $methodParams['status'] = 0;
        }
        $methodParams['type'] = 'manual';
        $inputs = [];
        if (is_array($request->fields)) {
            $inputs = array_map(function ($input) {
                $params = Arr::only($input, ['title', 'input_type', 'placeholder', 'is_required', 'sort']);
                if (isset($params['input_type'])) {
                    $params['type'] = $params['input_type'];
                }
                if (isset($params['is_required'])) {
                    $params['is_required'] = 1;
                } else {
                    $params['is_required'] = 0;
                }
                if (!isset($params['sort'])) {
                    $params['sort'] = 0;
                }
                if (isset($input['options']) && is_array($input['options'])) {
                    $params['options'] = array_map(function ($option) {
                        $p = Arr::only($option, ['title', 'sort']);
                        if (!isset($p['sort'])) $p['sort'] = 0;
                        return $p;
                    }, $input['options']);
                } else {
                    $params['options'] = [];
                }
                return $params;
            }, $request->fields);
        }
        try {
            DB::beginTransaction();
            /* @var PaymentMethod $paymentMethod */
            $paymentMethod = PaymentMethod::create($methodParams);
            if (!$paymentMethod) throw new \Exception(__('Unable to add new payment method'));
            foreach ($inputs as $input) {
                /* @var Input $in */
                $in = $paymentMethod->inputs()->create(Arr::except($input, ['options']));
                if (!$in) throw new \Exception(__('Unable to add input'));
                if (is_array($input['options'])) {
                    $in->options()->createMany($input['options']);
                }
            }
            DB::commit();
            return redirect()->route('staff.setting.payment-method.edit', $paymentMethod->id)->withSuccess(__('Method added successfully'));
        } catch (\Exception $exception) {
            DB::rollBack();
            return redirect()->back()->withErrors($exception->getMessage());
        }
    }

    public function edit(PaymentMethod $paymentMethod)
    {
        if (!$paymentMethod) return abort(404);
        $paymentMethod->load(['inputs' => function($q) {
            $q->with('options');
        }]);
        $currency = Currency::getDefaultCurrency();
        return view('staff.setting.payment-method.edit', compact('currency', 'paymentMethod'));
    }

    function updateMethod(Request $request, PaymentMethod $paymentMethod)
    {
        $request->validate([
            'name' => 'required|string|max:191',
            'description' => 'nullable',
            'min' => 'nullable|numeric',
            'max' => 'nullable|numeric',
            'percent_charge' => 'nullable|numeric',
            'fixed_charge' => 'nullable|numeric',
            'status' => 'nullable',
            'fields' => 'nullable|array',
            'fields.*' => 'nullable|array',
            'fields.*.title' => 'required|string|max:191',
            'fields.*.input_type' => 'required',
            'fields.*.placeholder' => 'nullable|string|max:191',
            'fields.*.is_required' => 'nullable',
            'fields.*.sort' => 'nullable|numeric',
        ]);
        $methodParams = $request->only(['name', 'description', 'min', 'max', 'percent_charge', 'fixed_charge', 'status']);
        if ($request->min && $request->min >= 0) {
            $methodParams['min'] = $request->min;
        } else {
            $methodParams['min'] = -1;
        }
        if ($request->max && $request->max >= 0) {
            $methodParams['max'] = $request->max;
        } else {
            $methodParams['max'] = -1;
        }
        if ($request->percent_charge) {
            $methodParams['percent_charge'] = $request->percent_charge;
        } else {
            $methodParams['percent_charge'] = 0;
        }
        if ($request->fixed_charge) {
            $methodParams['fixed_charge'] = $request->fixed_charge;
        } else {
            $methodParams['fixed_charge'] = 0;
        }
        if ($request->status) {
            $methodParams['status'] = 1;
        } else {
            $methodParams['status'] = 0;
        }
        $inputs = [];
        if (is_array($request->fields)) {
            $inputs = array_map(function ($input) {
                $params = Arr::only($input, ['title', 'input_type', 'placeholder', 'is_required', 'sort']);
                if (isset($params['input_type'])) {
                    $params['type'] = $params['input_type'];
                }
                if (isset($params['is_required'])) {
                    $params['is_required'] = 1;
                } else {
                    $params['is_required'] = 0;
                }
                if (!isset($params['sort'])) {
                    $params['sort'] = 0;
                }
                if (isset($input['options']) && is_array($input['options'])) {
                    $params['options'] = array_map(function ($option) {
                        $p = Arr::only($option, ['title', 'sort']);
                        if (!isset($p['sort'])) $p['sort'] = 0;
                        return $p;
                    }, $input['options']);
                } else {
                    $params['options'] = [];
                }
                return $params;
            }, $request->fields);
        }
        try {
            DB::beginTransaction();
            $res = $paymentMethod->update($methodParams);
            if (!$res) throw new \Exception(__('Unable to add new payment method'));
            $paymentMethod->inputs()->delete();
            foreach ($inputs as $input) {
                /* @var Input $in */
                $in = $paymentMethod->inputs()->create(Arr::except($input, ['options']));
                if (!$in) throw new \Exception(__('Unable to add input'));
                if (is_array($input['options'])) {
                    $in->options()->createMany($input['options']);
                }
            }
            DB::commit();
            return redirect()->route('staff.setting.payment-method.edit', $paymentMethod->id)->withSuccess(__('Method updated successfully'));
        } catch (\Exception $exception) {
            DB::rollBack();
            return redirect()->back()->withErrors($exception->getMessage());
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param \App\Models\PaymentMethod $paymentMethod
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response|void
     */
    public function update(Request $request, PaymentMethod $paymentMethod)
    {
        if (!$paymentMethod) return abort(404);
        $v = [
            'name' => 'required|max:191',
            'description' => 'required',
            'min' => 'required|numeric|min:-1',
            'max' => 'required|numeric|min:-1',
            'cred1' => 'required',
            'cred2' => 'nullable',
            'percent_charge' => 'required|numeric|min:0',
            'fixed_charge' => 'required|numeric|min:0',
            'status' => 'nullable|in:0,1',
        ];
        if ($paymentMethod->id == 5) {
            $v['cred1'] = 'nullable';
        }
        $request->validate($v);
        $p = $request->only(['name', 'description', 'min', 'max', 'cred1', 'cred2', 'percent_charge', 'fixed_charge', 'status']);
        if ($request->status != 1) {
            $p['status'] = 0;
        }
        $res = $paymentMethod->update($p);
        if (!$res) return redirect()->back()->withErrors(__('Unable to update payment method'));
        return redirect()->back()->withSuccess(__('Payment Method updated successfully'));
    }
}
