<?php

namespace App\Http\Controllers\Staff;

use App\Http\Controllers\Controller;
use App\Models\Role;
use App\Models\Staff;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTableAbstract;

class StaffRoleController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $query = Role::query()->where('for','staff');
            /* @var DataTableAbstract $table */
            $table = datatables()->of($query);
            $table->addColumn('caps', function (Role $role) {
                $allCaps = '';
                foreach ($role->caps as $key){
                    $allCaps=$allCaps .config('caps.staff.' . $key) .' , ';
                }
                return $allCaps;
            });
            $table->addColumn('action', function (Role $role) {
                return '<button class="btn btn-warning btn-edit nimmu-btn nimmu-btn-warning btn-xs" data-id="' . $role->id . '"
                                                    data-name="' . $role->name . '" data-caps=' . json_encode($role->caps) . '><i
                                                    class="fa fa-edit"></i></button>
                                            <button class="btn btn-danger btn-delete nimmu-btn nimmu-btn-danger btn-xs" data-id="' . $role->id . '"><i
                                                    class="fa fa-trash"></i></button>';
            });
            $table->rawColumns(['caps','action']);
            return $table->make(true);
        }
        return view('staff.roles.staff');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'caps' => 'required',
            'caps.*' => 'required'
        ]);
        $role = Role::create($request->only(['name', 'caps']));
        if (!$role) return redirect()->back()->withErrors('Unable to create role');
        return redirect()->back()->withSuccess('Role created successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Role $role)
    {
        if (!$role) return abort(404);
        $request->validate([
            'name' => 'required|string|max:199',
            'caps' => 'required',
            'caps.*' => 'required'
        ]);
        $res = $role->update($request->only(['name', 'caps']));
        if (!$res) return redirect()->back()->withErrors('Unable to update role');
        return redirect()->back()->withSuccess('Role updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Role $role)
    {
        if (!$role) return abort(404);
        $assignStaffs = Staff::where('role_id',$role->id)->count();
        if ($assignStaffs>0){
            return redirect()->back()->withErrors("You can't delete this role, it's already been used");
        }
        $res = $role->delete();
        if (!$res) return redirect()->back()->withErrors('Unable to update role. Maybe one or more staff exists in this role');
        return redirect()->back()->withSuccess('Role deleted successfully');
    }
}
