<?php

namespace App\Http\Controllers\Staff;

use App\Http\Controllers\Controller;
use App\Models\Subscriber;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Yajra\DataTables\DataTableAbstract;
use Illuminate\Validation\Rule;

class SubscriberController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $query = Subscriber::query();
            /* @var DataTableAbstract $table */
            $table = datatables()->of($query);
            $table->editColumn('status', function (Subscriber $subscriber) {
                if ($subscriber->status == 1) {
                    return '<span class="badge badge-success">Enabled</span>';
                } else {
                    return '<span class="badge badge-danger">Disabled</span>';
                }
            });
            $table->addColumn('action', function (Subscriber $subscriber) {
                return '<a href="' . route('staff.subscribers.edit', $subscriber->id) . '" class="btn btn-warning btn-edit nimmu-btn nimmu-btn-warning btn-xs"><i class="fa fa-edit"></i></a><button class="btn btn-danger btn-delete nimmu-btn nimmu-btn-danger btn-xs ml-1" data-id="' . $subscriber->id . '"><i class="fa fa-trash"></i></button>';
            });
            $table->rawColumns(['status','action']);
            return $table->make(true);
        }
        return view('staff.subscriber.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('staff.subscriber.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'email' => 'required|email|unique:subscribers',
            'phone_no' => 'nullable|unique:subscribers',
        ]);
        DB::beginTransaction();
        try {
            /* @var Subscriber|null $subscriber */
            $subscriber = Subscriber::create($request->all());
            if (!$subscriber) throw new \Exception('Unable to add new subscriber');
        } catch (\Exception $exception) {
            DB::rollBack();
            return redirect()->back()->withErrors($exception->getMessage());
        }
        DB::commit();
        return redirect()->route('staff.subscribers.index')->withSuccess('New subscriber added successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Subscriber $subscriber)
    {
        if ($subscriber == null) return abort(404);
        return view('staff.subscriber.edit', compact('subscriber'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Subscriber $subscriber)
    {
        if ($subscriber == null) return abort(404);
        $request->validate([
            'email' => [
                'required',
                Rule::unique('subscribers')->ignore($subscriber->id),
            ],
            'phone_no' => [
                'nullable',
                Rule::unique('subscribers')->ignore($subscriber->id),
            ],
            'status' => [
                'numeric',
                Rule::in([0,1]),
            ]
        ]);
        DB::beginTransaction();
        try {
            $res = $subscriber->update($request->only(['name', 'email', 'phone_no', 'status']));
            if (!$res) throw new \Exception('Unable to update subscriber info.');
        } catch (\Exception $exception) {
            DB::rollBack();
            return redirect()->back()->withErrors($exception->getMessage());
        }
        DB::commit();
        return redirect()->back()->withSuccess('Subscriber info updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Subscriber $subscriber)
    {
        if ($subscriber == null) return abort(404);
        DB::beginTransaction();
        try {
            $res = $subscriber->delete();
            if (!$res) throw new \Exception('Unable to delete subscriber');
        } catch (\Exception $exception) {
            DB::rollBack();
            return redirect()->back()->withErrors($exception->getMessage());
        }
        DB::commit();
        return redirect()->back()->withSuccess('Subscriber deleted successfully');
    }
}
