<?php

namespace App\Http\Controllers\Staff;

use App\Http\Controllers\Controller;
use App\Models\Option;
use GuzzleHttp\Client;
use Illuminate\Auth\Access\AuthorizationException;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Str;
use RecursiveCallbackFilterIterator;
use RecursiveDirectoryIterator;
use RecursiveIteratorIterator;
use SplFileInfo;
use Symfony\Component\Console\Output\BufferedOutput;
use ZipArchive;

class UpdateController extends Controller
{
    private $updateServer = 'http://149.28.199.74';
    private $url;
    private $data;

    function __construct()
    {
        set_time_limit(0);
        ignore_user_abort(true);
        $this->data = json_decode(file_get_contents(storage_path('.envato')));
        $this->url = url('/');
    }

    function index()
    {
        $step = get_option('update-step', 0);
        $release = get_option('update-release', null);
        if ($release) {
            $release = json_decode($release, true);
            if (!is_array($release)) {
                $step = 0;
            }
        }
        return view('staff.setting.update', compact('step', 'release'));
    }

    function checkUpdate(Request $request)
    {
        $httpClient = new Client();
        try {
            $url = $this->updateServer . '/check-update?' . http_build_query(['app' => 'azzoa', 'domain' => $this->url, 'license' => $this->data->license, 'current_version' => config('app.version')]);
            $response = $httpClient->get($url);
            if ($response->getStatusCode() != 200) throw new \Exception('Unable to connect update service');
            $d = json_decode($response->getBody(), true);
            if (isset($d['release'])) {
                Option::updateOption('update-release', json_encode($d['release']));
                Option::updateOption('update-step', 1);
            }
            return $d;
        } catch (\Exception $exception) {
            return response()->json(['success' => false, 'message' => $exception->getMessage()]);
        }
    }

    function makeBackup()
    {
        $step = get_option('update-step', 0);
        if ($step != 2) throw new AuthorizationException;

        try {
            // Get real path for our folder
            $rootPath = str_replace('/core', '', base_path());
            $excludeDirs = [storage_path(), $rootPath . '/.idea', $rootPath . '/.git', base_path('.idea')];
            $excludeFiles = [base_path('.env'), $rootPath . '/robots.txt'];
            foreach ($excludeDirs as $excludeDir) {
                if (is_dir($excludeDir)) {
                    /** @var SplFileInfo[] $files */
                    $excludeDirFiles = new RecursiveIteratorIterator(
                        new RecursiveDirectoryIterator($excludeDir),
                        RecursiveIteratorIterator::LEAVES_ONLY
                    );
                    foreach ($excludeDirFiles as $na => $fi) {
                        if (!is_dir($fi)) {
                            $excludeFiles[] = $fi->getRealPath();
                        }
                    }
                }
            }

            // Initialize archive object
            $zip = new ZipArchive();
            $zip->open(storage_path('app/update/backup-file.zip'), ZipArchive::CREATE | ZipArchive::OVERWRITE);

            // Create recursive directory iterator
            /** @var SplFileInfo[] $files */
            $files = new RecursiveIteratorIterator(
                new RecursiveDirectoryIterator($rootPath),
                RecursiveIteratorIterator::LEAVES_ONLY
            );

            foreach ($files as $name => $file) {
                // Skip directories (they would be added automatically)
                if (!$file->isDir()) {
                    // Get real and relative path for current file
                    $filePath = $file->getRealPath();
                    if (!in_array($filePath, $excludeFiles)) {
                        $relativePath = substr($filePath, strlen($rootPath) + 1);
                        $zip->addFile($filePath, $relativePath);
                    }
                }
            }

            // Zip archive will be created only after closing object
            $zip->close();

            Option::updateOption('update-step', 3);
            return response()->json(['success' => true]);
        } catch (\Exception $exception) {
            return response()->json(['success' => false, 'message' => $exception->getMessage()]);
        }
    }

    function downloadFile()
    {

        $step = get_option('update-step', 0);
        if ($step != 1) throw new AuthorizationException;

        if (!file_exists(storage_path('app/update'))) {
            mkdir(storage_path('app/update'));
        }

        $httpClient = new Client();
        try {
            $this->clear();
            $url = $this->updateServer . '/download-update?' . http_build_query(['app' => 'azzoa', 'domain' => $this->url, 'license' => $this->data->license, 'current_version' => config('app.version')]);
            $response = $httpClient->get($url, [
                'sink' => storage_path('app/update/updated-file.zip')
            ]);
            if ($response->getStatusCode() != 200) {
                $this->clear();
                throw new \Exception('Unable to download update service');
            }
            Option::updateOption('update-step', 2);
            return response()->json(['success' => true]);
        } catch (\Exception $exception) {
            return response()->json(['success' => false, 'message' => $exception->getMessage()]);
        }
    }

    private function clear()
    {
        @unlink(storage_path('app/update/updated-file.zip'));
        @unlink(storage_path('app/update/backup-file.zip'));
    }

    function update()
    {
        $step = get_option('update-step', 0);
        $release = get_option('update-release', null);
        if ($release) {
            $release = json_decode($release, true);
            if (!is_array($release)) {
                $step = 0;
            }
        }
        if ($step != 3) throw new AuthorizationException;
        if (!isset($release['tag'])) throw new AuthorizationException;

        // Update & Rollback
        $rootPath = str_replace('/core', '', base_path());
        try {
            $releaseZip = new ZipArchive;
            $backupZip = new ZipArchive;
            $releaseZipOpen = $releaseZip->open(storage_path('app/update/updated-file.zip'));
            if ($releaseZipOpen !== TRUE) throw new \Exception('Unable to open Update ZIP');
            $backupZipOpen = $backupZip->open(storage_path('app/update/backup-file.zip'));
            if ($backupZipOpen !== TRUE) throw new \Exception('Unable to open Backup ZIP');
        } catch (\Exception $exception) {
            return response()->json(['success' => false, 'message' => $exception->getMessage()]);
        }

        try {
            $r = $releaseZip->extractTo($rootPath);
            if ($r === FALSE) throw new \Exception('Unable to extract update files');
        } catch (\Exception $exception) {
            $backupZip->extractTo($rootPath);
            $backupZip->close();
            $releaseZip->close();
            return response()->json(['success' => false, 'message' => $exception->getMessage()]);
        }
        $backupZip->close();
        $releaseZip->close();

        // Assume: Extraction Is Completed. Finalizing installation
        $outputLog = new BufferedOutput;
        try {
            // Change To Latest Tag Name
            $envPath = base_path('.env');
            if (file_exists($envPath)) {
                if (Str::contains(file_get_contents($envPath), 'APP_VERSION') === false) {
                    // create new entry
                    file_put_contents($envPath, PHP_EOL . 'APP_VERSION=' . $release['tag'] . PHP_EOL, FILE_APPEND);
                } else {
                    file_put_contents($envPath, str_replace(
                        'APP_VERSION=' . env('APP_VERSION', 'v2.2.0'), 'APP_VERSION=' . $release['tag'], file_get_contents($envPath)
                    ));
                }
            }
            Artisan::call('migrate', ['--force' => true], $outputLog);
            Artisan::call('azzoa:update', [], $outputLog);
        } catch (\Exception $exception) {
            return response()->json(['success' => false, 'message' => $outputLog->fetch()]);
        }
        Option::updateOption('update-step', 0);
        Option::updateOption('update-release', null);
        return response()->json(['success' => true, 'release' => $release, 'message' => $outputLog->fetch()]);
    }
}
