<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use App\Models\Currency;
use App\Models\PaymentRequest;
use App\Models\Transaction;
use App\Models\Wallet;
use App\Models\Withdraw;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class DashboardController extends Controller
{
    public function index(){
        $user = Auth::user();
        $pending_withdraw_requests = Withdraw::where([['user_id',$user->id],['status',0]])->count();
        $pending_payment_requests = PaymentRequest::where([['by_id',$user->id],['status','pending']])->count();
        $transactions=Transaction::where([['user_type',get_class($user)],['user_id',$user->id]])->paginate(10);
        $total_balance = Wallet::query()
            ->selectRaw("SUM(wallets.balance*currencies.rate) as t")
            ->join('currencies', 'wallets.currency_id', '=', 'currencies.id')
            ->where('user_id', $user->id)
            ->first();

        $total_balance = $total_balance?number_format($total_balance->t, config('iwallet.decimals', 2)):0;
        $total_balance = (Currency::getDefaultCurrency()->symbol ?? '') . ' ' .$total_balance;
        return view('user.dashboard',compact('transactions','pending_withdraw_requests','pending_payment_requests','total_balance'));
    }
}
