<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class SettingsController extends Controller
{
    public function index(Request $request)
    {
        return view('user.settings.index');
    }

    public function profile(){
        return view('user.settings.profile');
    }

    public function updateProfile(Request $request){
        $request->validate([
            'first_name' => 'required|string|max:100',
            'last_name' => 'required|string|max:100',
            'username' => 'required|alpha_dash|max:191|unique:users,username,' . Auth::id(),
            'email' => 'required|email|max:191|unique:users,email,' . Auth::id(),
            'phone' => 'required|numeric|unique:users,phone,' . Auth::id(),
            'avatar' => 'nullable|string|max:191',
            'password' => 'nullable|min:6|max:191|confirmed'
        ]);
        $params=$request->only('first_name','last_name','username','email','phone','avatar');
        if (isset($request->password)){
            $params['password']=Hash::make($request->password);
        }
        $profileUpdate = Auth::user()->update($params);
        if (!$profileUpdate) throw new \Exception('Unable to update profile info');
        return redirect()->back()->withSuccess('Profile Updated Successfully');
    }
}
