<?php

namespace App\Http\Controllers\User;

use App\Events\TransactionAdded;
use App\Http\Controllers\Controller;
use App\Models\Currency;
use App\Models\Transaction;
use App\Models\User;
use App\Models\Wallet;
use App\Models\WithdrawMethod;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Validation\ValidationException;

class WalletController extends Controller
{
    public function index(){
        $wallets = Wallet::with('currency')->where('user_id',Auth::id())->get();
        $users = User::where([['id','<>',Auth::id()],['status',1]])->get();
        $methods = WithdrawMethod::query()->where('status', 1)->get();
        return view('user.wallet.index',compact('wallets','users','methods'));
    }

    public function send_money(Request $request){
        $request->validate([
            'wallet_id' => 'required|exists:wallets,id',
            'send_to' => 'required|exists:users,id',
            'amount' => 'required|numeric|min:0',
            'message' => 'required|string|max:190',
        ]);

        /* @var User $user */
        $user = Auth::user();
        $sendTo = User::findorFail($request->send_to);
        /* @var WithdrawMethod $withdrawMethod */
        $userWallet = Wallet::query()->where([['id', $request->wallet_id],['user_id',$user->id]])->firstOrFail();
        if ($request->amount > $userWallet->balance) throw ValidationException::withMessages(['error' => "You don't have enough balance"]);
        $senderWallet = Wallet::query()->where([['currency_id', $userWallet->currency_id],['user_id',$request->send_to]])->firstOrFail();
        if ($request->amount == 0) throw ValidationException::withMessages(['error' => 'Amount must be greater then 0']);

        try {
            DB::beginTransaction();
            $r = $userWallet->update([
                'balance' => ($userWallet->balance-$request->amount)
            ]);

            $s = $senderWallet->update([
                'balance' => ($senderWallet->balance+$request->amount)
            ]);
            if (!$r || !$s) throw new \Exception('Unable to update balance');

            /* @var Transaction $transaction */
            $sendMoneyTransaction = $user->transactions()->create([
                'track' => Transaction::generateTrack(),
                'wallet_id' => $userWallet->id,
                'title' => "Send Money",
                'ref_type' => get_class($userWallet),
                'ref_id' => $userWallet->id,
                'type' => '-',
                'amount' => $request->amount,
                'matter' => 'send_money',
                'creator_type' => get_class($user),
                'creator_id' => $user->id,
            ]);
            $transaction = $sendTo->transactions()->create([
                'track' => Transaction::generateTrack(),
                'wallet_id' => $senderWallet->id,
                'title' => $request->message,
                'ref_type' => get_class($senderWallet),
                'ref_id' => $senderWallet->id,
                'type' => '+',
                'amount' => $request->amount,
                'matter' => 'receive_money',
                'creator_type' => get_class($user),
                'creator_id' => $user->id,
            ]);
            if (!$transaction || !$sendMoneyTransaction) throw new \Exception('Unable to create transaction');

            event(new TransactionAdded($transaction));
            DB::commit();
            return redirect()->route('dashboard.wallet')->withSuccess('Money Send Successfully');
        } catch (\Exception $exception) {
            DB::rollBack();
            throw ValidationException::withMessages(['error' => $exception->getMessage()]);
        }
    }
}
