<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;

class Currency extends Model
{
    protected $guarded = ['id'];

    protected static function boot()
    {
        parent::boot();
        if (request() && !request()->is('staff*')) {
            static::addGlobalScope('security', function (Builder $builder) {
                $builder->where('status', '!=', 0);
            });
        }
    }

    function gateways()
    {
        return $this->hasMany(PaymentGateway::class, 'currency_id', 'id');
    }

    public function format($value)
    {
        return currency_format($value, $this);
    }

    static function getDefaultCurrency()
    {
        return self::query()->where('is_default', 1)->where('status', 1)->first();
    }

    public static function generateDefaultCurrency(){
        $defaultCurrency = Currency::where([['status',1],['is_default',1]])->first();
        if (!$defaultCurrency){
            Currency::firstOrCreate(
                ['code' => html_entity_decode('USD')],
                [
                    'name' => html_entity_decode('United States (US) dollar'),
                    'symbol' => html_entity_decode('&#36;'),
                    'is_default' => 1,
                    'status' => 1
                ]
            );
        }
    }
}
