<?php

namespace App\Models;

use GuzzleHttp\Client;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Payment extends Model
{
    protected $guarded = ['id'];

    function user()
    {
        return $this->belongsTo(User::class, 'user_id', 'id');
    }

    function payment_gateway()
    {
        return $this->belongsTo(PaymentGateway::class, 'payment_gateway_id', 'id');
    }

    function store()
    {
        return $this->belongsTo(Store::class, 'store_id', 'id');
    }

    function currency()
    {
        return $this->belongsTo(Currency::class, 'currency_id', 'id');
    }

    function sendFailedIPNAndRedirectToFailed($message = 'unable to proceed')
    {
        $client = new Client;
        try {
            $client->post($this->status_url, [
                'form_params' => [
                    'amount' => $this->amount,
                    'currency' => $this->currency->code,
                    'custom' => $this->custom,
                    'payment_track' => encrypt($this->id),
                    'status' => 'failed',
                    'message' => $message
                ]
            ]);
        } catch (\Exception $exception) {
        }
        return redirect($this->failed_url);
    }

    function sendSuccessIPNAndRedirectToSuccess($trx_id = null)
    {
        $client = new Client;
        try {
            $client->post($this->status_url, [
                'form_params' => [
                    'amount' => $this->amount,
                    'currency' => $this->currency->code,
                    'custom' => $this->custom,
                    'payment_track' => encrypt($this->id),
                    'status' => 'completed',
                    'trx_id' => $trx_id
                ]
            ]);
        } catch (\Exception $exception) {
        }
        return redirect($this->success_url);
    }
}
