<?php

namespace App\Models;

use App\Helpers\HasTransaction;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;

class User extends Authenticatable implements MustVerifyEmail
{
    use Notifiable, HasTransaction;

    protected $guarded = ['id'];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    function getAvatarAttribute($avatar)
    {
        if (empty($avatar)) {
            $avatar = 'https://www.gravatar.com/avatar/' . md5(strtolower($this->email)) . '.jpg?s=200&d=mm';
        }
        return $avatar;
    }

    public function getFullNameAttribute()
    {
        return "{$this->first_name} {$this->last_name}";
    }

    function role()
    {
        return $this->belongsTo(Role::class, 'role_id', 'id');
    }

    /**
     * @param mixed $cap
     * @param bool $and
     * @return bool
     */
    public function hasCap($cap, $and = true)
    {
        if (!isset($this->role)) return false;
        if (!is_array($this->role->caps)) return false;

        if (is_array($cap)) {
            if ($and) {
                $intersection = array_intersect($this->role->caps, $cap);
                if (count($intersection) == count($cap)) return true;
            } else {
                return (bool)array_intersect($this->role->caps, $cap);
            }
        } else {
            if (in_array($cap, $this->role->caps)) return true;
        }

        return false;
    }

    public function wallets(){
        return $this->hasMany(Wallet::class,'user_id');
    }

    public function stores(){
        return $this->hasMany(Store::class,'user_id');
    }

    public function withdraws()
    {
        return $this->morphMany(Withdraw::class, 'user');
    }

    public function deposits()
    {
        return $this->hasMany(Deposit::class, 'user_id', 'id');
    }
}
