<?php

namespace App\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use NotificationChannels\Twilio\TwilioChannel;
use App\Channels\SubnotificationsChannel;
use App\Helpers\TemplateBuilder;

class NotifyStaff extends Notification
{
    use Queueable;

    private $type;
    private $title='Doctor Visiting Done';
    private $message;
    private $action;
    /**
     * @var null
     */
    private $signature;

    /**
     * Create a new notification instance.
     *
     * @return void
     */
    public function __construct($title='', $message = '', $action='', $type = 'multi-user', $signature = null)
    {
        $this->title = $title;
        $this->type = $type;
        $this->message = $message;
        $this->action = $action;
        $this->signature = $signature;
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function via($notifiable)
    {
        if ($this->type == 'email') {
            if (config('project.email_notification')) {
                return ['mail'];
            }
        }
        elseif ($this->type == 'sms') {
            if (config('project.sms_notification')) {
                if (config('project.sms_via') == 'twilio') {
                    return [TwilioChannel::class];
                } else {
                    return ['itech'];
                }
            }
        }
        elseif ($this->type == 'multi-user') {
            $via = [];
            $via[] = SubnotificationsChannel::class;
//            $via[] = 'mail';
            return $via;
        }

        return [];
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        $data =  (new TemplateBuilder)->fetch('notify_admin', 'email')->parse(['title'=>$this->title, 'message' => $this->message, 'action' => $this->action])->get();
        dd($data);
    }

    /**
     * Get the array representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function toArray($notifiable)
    {
        return [
            'title' => $this->title,
            'message' => $this->message,
            'action' => $this->action,
        ];
    }
}
