<?php

namespace App\PaymentMethods;

use App\Events\TransactionAdded;
use App\Models\Currency;
use App\Models\Deposit;
use App\Models\Payment;
use App\Models\PaymentGateway;
use App\Models\Transaction;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class PayPal extends PaymentMethod
{
    public $supported_currencies = ['AUD', 'BRL', 'CAD', 'CNY', 'CZK', 'DKK', 'EUR', 'HKD', 'HUF', 'ILS', 'JPY', 'MYR', 'MXN', 'TWD', 'NZD', 'NOK', 'PHP', 'PLN', 'GBP', 'RUB', 'SGD', 'SEK', 'CHF', 'THB', 'USD'];
    public $credentials = ['paypal_email'];

    public function process(\App\Models\PaymentGateway $dbMethod, $payment)
    {
        if ($payment instanceof Deposit) {
            $currency = $payment->currency;
            $title = 'Deposit #' . $payment->id;
            $amount = $payment->amount + $payment->charge;
            $ipn_url = route('payment.ipn', ['type' => 'deposit', 'track' => encrypt($payment->id)]);
            $success_url = route('payment.success', ['type' => 'deposit', 'track' => encrypt($payment->id)]);
            $cancel_url = route('payment.failed', ['type' => 'deposit', 'track' => encrypt($payment->id)]);
        }
        if ($payment instanceof Payment) {
            $currency = $payment->currency;
            $title = $payment->title;
            $amount = $payment->amount;
            $ipn_url = route('payment.ipn', ['type' => 'store_payment', 'track' => encrypt($payment->id)]);
            $success_url = route('payment.success', ['type' => 'store_payment', 'track' => encrypt($payment->id)]);
            $cancel_url = route('payment.failed', ['type' => 'store_payment', 'track' => encrypt($payment->id)]);
        }
        $paypalUrl = config('app.env') != 'production' ? 'https://www.sandbox.paypal.com/cgi-bin/webscr' : 'https://secure.paypal.com/cgi-bin/webscr';
        $params = [
            'cmd' => '_xclick',
            'business' => $dbMethod->credentials['paypal_email'],
            'cbt' => config('app.name'),
            'currency_code' => $currency->code,
            'quantity' => 1,
            'item_name' => $title,
            'custom' => $payment->id,
            'amount' => $amount,
            'return' => $success_url,
            'cancel_return' => $cancel_url,
            'notify_url' => $ipn_url,
        ];
        return redirect($paypalUrl . '?' . http_build_query($params));
    }

    public function ipn(Request $request, PaymentGateway $dbMethod, $payment)
    {
        $raw_post_data = $request->getContent();
        $raw_post_array = explode('&', $raw_post_data);
        $myPost = array();
        foreach ($raw_post_array as $keyval) {
            $keyval = explode('=', $keyval);
            if (count($keyval) == 2)
                $myPost[$keyval[0]] = urldecode($keyval[1]);
        }

        $req = 'cmd=_notify-validate';
        if (function_exists('get_magic_quotes_gpc')) {
            $get_magic_quotes_exists = true;
        }
        foreach ($myPost as $key => $value) {
            if ($get_magic_quotes_exists == true && get_magic_quotes_gpc() == 1) {
                $value = urlencode(stripslashes($value));
            } else {
                $value = urlencode($value);
            }
            $req .= "&$key=$value";
        }


        $paypalURL = config('app.env') != 'production' ? "https://www.sandbox.paypal.com/cgi-bin/webscr" : "https://secure.paypal.com/cgi-bin/webscr";
        $ch = curl_init($paypalURL);
        if ($ch == FALSE) {
            return FALSE;
        }
        curl_setopt($ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $req);
        curl_setopt($ch, CURLOPT_SSLVERSION, 6);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 1);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
        curl_setopt($ch, CURLOPT_FORBID_REUSE, 1);

        // Set TCP timeout to 30 seconds
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 30);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Connection: Close', 'User-Agent: ItechSoftSolution'));
        $res = curl_exec($ch);
        $tokens = explode("\r\n\r\n", trim($res));
        $res = trim(end($tokens));

        if (strcmp($res, "VERIFIED") == 0 || strcasecmp($res, "VERIFIED") == 0) {

            if ($payment instanceof Deposit) {
                $currency = $payment->currency;
            }
            if ($payment instanceof Payment) {
                $currency = $payment->currency;
            }

            $receiver_email = $request->receiver_email;
            $mc_currency = $request->mc_currency;
            $mc_gross = $request->mc_gross;
            $track = $request->custom;
            if ($receiver_email == $dbMethod->credentials['paypal_email']) {
                try {
                    DB::beginTransaction();
                    if ($payment instanceof Deposit && $payment->status < 1) {
                        $payment->update([
                            'status' => 1
                        ]);
                        /* @var User $user */
                        $user = $payment->user;
                        /* @var \App\Models\Wallet $wallet */
                        $wallet = $user->wallets()->firstOrCreate(['currency_id' => $payment->currency_id]);
                        $wallet->update([
                            'balance' => ($payment->amount + $wallet->balance)
                        ]);
                        /* @var Transaction $transaction */
                        $transaction = $user->transactions()->create([
                            'wallet_id' => $wallet->id,
                            'track' => Transaction::generateTrack(),
                            'title' => 'Deposited via ' . optional($payment->payment_gateway)->name,
                            'ref_type' => get_class($payment),
                            'ref_id' => $payment->id,
                            'type' => '+',
                            'amount' => $payment->amount,
                            'matter' => 'deposit'
                        ]);
                        event(new TransactionAdded($transaction));
                    }
                    if ($payment instanceof Payment && $payment->status == 'initialized') {
                        $payment->update([
                            'status' => 'completed'
                        ]);
                        /* @var User $user */
                        $user = $payment->user;
                        /* @var \App\Models\Wallet $wallet */
                        $wallet = $user->wallets()->firstOrCreate(['currency_id' => $payment->currency_id]);
                        $wallet->update([
                            'balance' => ($payment->amount + $wallet->balance)
                        ]);
                        /* @var Transaction $transaction */
                        $transaction = $user->transactions()->create([
                            'wallet_id' => $wallet->id,
                            'track' => Transaction::generateTrack(),
                            'title' => 'Store Payment Received',
                            'ref_type' => get_class($payment->store),
                            'ref_id' => $payment->store_id,
                            'type' => '+',
                            'amount' => $payment->amount,
                            'matter' => 'store_payment',
                            'creator_type' => get_class($payment),
                            'creator_id' => $payment->id
                        ]);
                        event(new TransactionAdded($transaction));
                    }
                    DB::commit();
                    if ($payment instanceof Payment) {
                        return $payment->sendSuccessIPNAndRedirectToSuccess();
                    }
                } catch (\Exception $exception) {
                    DB::rollBack();
                }
            }
        }
    }
}
