<?php

namespace App\PaymentMethods;

use App\Events\TransactionAdded;
use App\Models\Currency;
use App\Models\Deposit;
use App\Models\Payment;
use App\Models\PaymentGateway;
use App\Models\Transaction;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class PerfectMoney extends PaymentMethod
{
    public $supported_currencies = ['USD'];
    public $credentials = ['member_id', 'passphrase'];

    function process(PaymentGateway $dbMethod, $payment)
    {
        $currency = $payment->currency;
        if ($payment instanceof Deposit) {
            $amount = $payment->amount + $payment->charge;
            $type = 'deposit';
        }
        if ($payment instanceof Payment) {
            $amount = $payment->amount;
            $type = 'store_payment';
        }
        return view('payment.perfect-money', compact('currency', 'dbMethod', 'payment', 'amount', 'type'));
    }

    public function ipn(Request $request, PaymentGateway $dbMethod, $payment)
    {
        $passphrase = strtoupper(md5($dbMethod->credentials['passphrase']));

        $string =
            $request->post('PAYMENT_ID') . ':' . $request->post('PAYEE_ACCOUNT') . ':' .
            $request->post('PAYMENT_AMOUNT') . ':' . $request->post('PAYMENT_UNITS') . ':' .
            $request->post('PAYMENT_BATCH_NUM') . ':' .
            $request->post('PAYER_ACCOUNT') . ':' . $passphrase . ':' .
            $request->post('TIMESTAMPGMT');

        $hash = strtoupper(md5($string));
        $hash2 = $request->post('V2_HASH');

        if ($hash == $hash2) {

            $amo = $request->post('PAYMENT_AMOUNT');
            $unit = $request->post('PAYMENT_UNITS');
            $track = $request->post('PAYMENT_ID');

            if ($request->post('PAYEE_ACCOUNT') == $dbMethod->credentials['member_id']) {

                try {
                    DB::beginTransaction();
                    if ($payment instanceof Deposit && $payment->status < 1) {
                        $payment->update([
                            'status' => 1
                        ]);
                        /* @var User $user */
                        $user = $payment->user;
                        /* @var \App\Models\Wallet $wallet */
                        $wallet = $user->wallets()->firstOrCreate(['currency_id' => $payment->currency_id]);
                        $wallet->update([
                            'balance' => ($payment->amount + $wallet->balance)
                        ]);
                        /* @var Transaction $transaction */
                        $transaction = $user->transactions()->create([
                            'wallet_id' => $wallet->id,
                            'track' => Transaction::generateTrack(),
                            'title' => 'Deposited via ' . optional($payment->payment_gateway)->name,
                            'ref_type' => get_class($payment),
                            'ref_id' => $payment->id,
                            'type' => '+',
                            'amount' => $payment->amount,
                            'matter' => 'deposit'
                        ]);
                        event(new TransactionAdded($transaction));
                    }
                    if ($payment instanceof Payment && $payment->status == 'initialized') {
                        $payment->update([
                            'status' => 'completed'
                        ]);
                        /* @var User $user */
                        $user = $payment->user;
                        /* @var \App\Models\Wallet $wallet */
                        $wallet = $user->wallets()->firstOrCreate(['currency_id' => $payment->currency_id]);
                        $wallet->update([
                            'balance' => ($payment->amount + $wallet->balance)
                        ]);
                        /* @var Transaction $transaction */
                        $transaction = $user->transactions()->create([
                            'wallet_id' => $wallet->id,
                            'track' => Transaction::generateTrack(),
                            'title' => 'Store Payment Received',
                            'ref_type' => get_class($payment->store),
                            'ref_id' => $payment->store_id,
                            'type' => '+',
                            'amount' => $payment->amount,
                            'matter' => 'store_payment',
                            'creator_type' => get_class($payment),
                            'creator_id' => $payment->id
                        ]);
                        event(new TransactionAdded($transaction));
                    }
                    DB::commit();
                    if ($payment instanceof Payment) {
                        return $payment->sendSuccessIPNAndRedirectToSuccess();
                    }
                } catch (\Exception $exception) {
                    DB::rollBack();
                }

            }
        }
    }
}
