<?php

namespace App\PaymentMethods;

use App\Events\TransactionAdded;
use App\Models\Currency;
use App\Models\Deposit;
use App\Models\Payment;
use App\Models\PaymentGateway;
use App\Models\Transaction;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class Skrill extends PaymentMethod
{
    public $supported_currencies = ['USD'];
    public $credentials = ['pay_to_email', 'secret_key'];

    public function process(PaymentGateway $dbMethod, $payment)
    {
        $currency = $payment->currency;
        if ($payment instanceof Deposit) {
            $amount = $payment->amount + $payment->charge;
            $type = 'deposit';
            $desc = "Deposit #" . $payment->id;
        }
        if ($payment instanceof Payment) {
            $amount = $payment->amount;
            $type = 'store_payment';
            $desc = "Payment #" . $payment->id;
        }
        return view('payment.skrill', compact('currency', 'dbMethod', 'payment', 'amount', 'type', 'desc'));
    }

    public function ipn(Request $request, PaymentGateway $dbMethod, $payment)
    {
        $concatFields = $request->post('merchant_id')
            . $request->post('transaction_id')
            . strtoupper(md5($dbMethod->credentials['secret_key']))
            . $request->post('mb_amount')
            . $request->post('mb_currency')
            . $request->post('status');

        if (strtoupper(md5($concatFields)) == $request->post('md5sig') && $request->post('status') == 2 && $request->post('pay_to_email') == $dbMethod->credentials['pay_to_email']) {
            try {
                DB::beginTransaction();
                if ($payment instanceof Deposit && $payment->status < 1) {
                    $payment->update([
                        'status' => 1
                    ]);
                    /* @var User $user */
                    $user = $payment->user;
                    /* @var \App\Models\Wallet $wallet */
                    $wallet = $user->wallets()->firstOrCreate(['currency_id' => $payment->currency_id]);
                    $wallet->update([
                        'balance' => ($payment->amount + $wallet->balance)
                    ]);
                    /* @var Transaction $transaction */
                    $transaction = $user->transactions()->create([
                        'wallet_id' => $wallet->id,
                        'track' => Transaction::generateTrack(),
                        'title' => 'Deposited via ' . optional($payment->payment_gateway)->name,
                        'ref_type' => get_class($payment),
                        'ref_id' => $payment->id,
                        'type' => '+',
                        'amount' => $payment->amount,
                        'matter' => 'deposit'
                    ]);
                    event(new TransactionAdded($transaction));
                }
                if ($payment instanceof Payment && $payment->status == 'initialized') {
                    $payment->update([
                        'status' => 'completed'
                    ]);
                    /* @var User $user */
                    $user = $payment->user;
                    /* @var \App\Models\Wallet $wallet */
                    $wallet = $user->wallets()->firstOrCreate(['currency_id' => $payment->currency_id]);
                    $wallet->update([
                        'balance' => ($payment->amount + $wallet->balance)
                    ]);
                    /* @var Transaction $transaction */
                    $transaction = $user->transactions()->create([
                        'wallet_id' => $wallet->id,
                        'track' => Transaction::generateTrack(),
                        'title' => 'Store Payment Received',
                        'ref_type' => get_class($payment->store),
                        'ref_id' => $payment->store_id,
                        'type' => '+',
                        'amount' => $payment->amount,
                        'matter' => 'store_payment',
                        'creator_type' => get_class($payment),
                        'creator_id' => $payment->id
                    ]);
                    event(new TransactionAdded($transaction));
                }
                DB::commit();
                if ($payment instanceof Payment) {
                    $payment->sendSuccessIPNAndRedirectToSuccess();
                }
            } catch (\Exception $exception) {
                DB::rollBack();
            }
        }
    }
}
