<?php

namespace App\Providers;

use App\Events\PaymentRequestAccepted;
use App\Events\TransactionAdded;
use App\Events\UserRegistered;
use App\Events\WithdrawAccepted;
use App\Listeners\AppInstalledEventListener;
use App\Listeners\PaymentRequestAcceptedNotification;
use App\Listeners\SendNewTransactionNotification;
use App\Listeners\SendWithdrawAcceptedNotification;
use App\Listeners\UserRegisteredEventListener;
use Illuminate\Auth\Events\Registered;
use Illuminate\Auth\Listeners\SendEmailVerificationNotification;
use Illuminate\Foundation\Support\Providers\EventServiceProvider as ServiceProvider;
use Illuminate\Support\Facades\Event;
use RachidLaasri\LaravelInstaller\Events\LaravelInstallerFinished;

class EventServiceProvider extends ServiceProvider
{
    /**
     * The event listener mappings for the application.
     *
     * @var array
     */
    protected $listen = [
        Registered::class => [
            SendEmailVerificationNotification::class,
        ],
        UserRegistered::class => [
            UserRegisteredEventListener::class,
        ],
        TransactionAdded::class => [
            SendNewTransactionNotification::class
        ],
        WithdrawAccepted::class => [
            SendWithdrawAcceptedNotification::class
        ],
        PaymentRequestAccepted::class => [
            PaymentRequestAcceptedNotification::class
        ],
        LaravelInstallerFinished::class => [
            AppInstalledEventListener::class
        ],
    ];

    /**
     * Register any events for your application.
     *
     * @return void
     */
    public function boot()
    {
        //
    }
}
