<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateUsersTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('users', function (Blueprint $table) {
            $table->id();
            $table->unsignedBigInteger('role_id');
            $table->string('first_name');
            $table->string('last_name')->nullable();

            $table->string('username')->unique();
            $table->string('email')->unique();
            $table->string('phone')->unique();
            $table->string('avatar')->nullable();

            $table->timestamp('email_verified_at')->nullable();
            $table->string('email_otp')->nullable();
            $table->timestamp('phone_verified_at')->nullable();
            $table->string('sms_otp')->nullable();

            $table->boolean('enabled_2fa')->default(false)->comment('1=show 2fa on login, 0=disabled'); // if true then show 2fa on login
            $table->boolean('verified_2fa')->default(false)->comment('1=enabled, 0=disabled'); // set it false upon login if enabled_2fa is true
            $table->text('secret_2fa')->nullable();
            $table->boolean('push_notification')->default(1)->comment('1=enabled, 0=disabled');

            $table->string('password');
            $table->boolean('status')->default(0)->comment('0=disabled, 1=enabled');
            $table->rememberToken();
            $table->timestamps();

            $table->foreign('role_id')->references('id')->on('roles')->onUpdate('CASCADE')->onDelete('RESTRICT');
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('users');
    }
}
