@extends('staff.layouts.master')

@section('title', __('Edit Blog Post'))

@section('css_libs')
    <link href="{{ asset('assets/libs/select2/css/select2.min.css') }}" rel="stylesheet" type="text/css"/>
    <link rel="stylesheet" href="{{ asset('assets/css/select2-bootstrap.css') }}">
@endsection

@section('css')
    <style>
        [v-cloak] {
            display: none;
        }

        .accordion {
            min-height: unset;
            cursor: pointer;
        }

        .cursor-pointer {
            cursor: pointer;
            float: right;
        }
    </style>
@endsection

@section('content')
    <!-- Start Content-->
    <div class="container-fluid">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a>
                            </li>
                            <li class="breadcrumb-item"><a
                                    href="{{ route('staff.blog-post.index') }}">@lang('Blog Posts')</a></li>
                            <li class="breadcrumb-item active">@lang('Edit Blog Post')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('Edit Blog Post')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <form action="{{ route('staff.blog-post.update', $blogPost->id) }}" method="post">
            @csrf
            @method('PUT')
            @include('layouts.partials.flash-alert')
            <div class="row" id="app">
                <div class="col-md-12">
                    <div class="card-box">
                        <div class="nimmu-default-card">
                            <div
                                class="nimmu-default-card-header nimmu-mb-30 d-flex justify-content-between align-content-center">
                                <div class="nimmu-header-left">
                                    <h5>General Info</h5>
                                </div>
                                <div>
                                    <button type="submit" class="btn btn-primary btn-lg nimmu-btn nimmu-btn-primary">
                                        Update
                                    </button>
                                    <button type="reset" class="btn btn-danger btn-lg nimmu-btn nimmu-btn-danger">
                                        Reset
                                    </button>
                                </div>
                            </div>
                            <div class="nimmu-default-card-body">
                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label class="control-label">Title</label>
                                                    <input type="text" name="title"
                                                           class="form-control" v-model="title" required>
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label class="control-label">Slug</label>
                                                    <input type="text" name="slug"
                                                           class="form-control" v-model="slug" required>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="tags" class="control-label">Tags</label>
                                                    <select name="tags[]" class="form-control" id="tags" multiple>
                                                        @foreach($tags as $tag)
                                                            <option
                                                                value="{{ $tag->id }}" {{ (is_array($blog_post_tag_ids) && in_array($tag->id, $blog_post_tag_ids))?'selected':'' }}>{{ $tag->name }}</option>
                                                        @endforeach
                                                    </select>
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label class="control-label">Summery</label>
                                                    <textarea name="summery" class="form-control" v-model="summery"
                                                              required></textarea>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-lg-6">
                                                <div class="form-group">
                                                    <label class="control-label">Status</label>
                                                    <select name="status" class="form-control select2">
                                                        <option value="0" {{ $blogPost->status == 0?'selected':'' }}>
                                                            Pending
                                                        </option>
                                                        <option value="1" {{ $blogPost->status == 1?'selected':'' }}>
                                                            Enable
                                                        </option>
                                                        <option value="2" {{ $blogPost->status == 2?'selected':'' }}>
                                                            Disabled
                                                        </option>
                                                    </select>
                                                </div>
                                            </div>
                                            <div class="col-lg-6">
                                                <div class="form-group">
                                                    <label class="control-label d-block">Feature Image</label>
                                                    <img :src="feature_image" class="img-fluid">
                                                    <button class="btn btn-success nimmu-btn nimmu-btn-success mt-1"
                                                        @click.prevent="selectImage">
                                                        Select Image
                                                    </button>
                                                    <input type="hidden" name="feature_image" v-model="feature_image">
                                                </div>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-md-12">
                                                <div class="form-group">
                                                    <label class="control-label">Details</label>
                                                    <textarea name="details"
                                                              class="form-control editor">{!! $blogPost->details !!}</textarea>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    @foreach($languages as $language)
                        <div class="card-box">
                            <div class="nimmu-default-card accordion">
                                <div
                                    class="nimmu-default-card-header d-flex justify-content-between align-content-center"
                                    data-toggle="collapse" data-target="#translation-{{ $language->code }}"
                                    aria-expanded="false" aria-controls="translation-{{ $language->code }}">
                                    <div class="nimmu-header-left">
                                        <h5>Translation ({{ $language->code }}) &nbsp;<i class="fas fa-angle-down"></i>
                                        </h5>
                                    </div>
                                </div>
                                <div class="nimmu-default-card-body mt-3 collapse"
                                     id="translation-{{ $language->code }}">
                                    <div class="col-lg-12">
                                        <div class="form-group">
                                            <label class="control-label">Title</label>
                                            <input type="text" name="lang[{{ $language->code }}][title]"
                                                   value="{{ (is_array($translations) && is_array($translations[$language->code]))?$translations[$language->code]['title']:'' }}"
                                                   class="form-control">
                                        </div>
                                        <div class="form-group">
                                            <label class="control-label">Details</label>
                                            <textarea name="lang[{{ $language->code }}][details]"
                                                      class="form-control editor">{!!(is_array($translations) && is_array($translations[$language->code])?$translations[$language->code]['details']:'') !!}</textarea>
                                        </div>
                                        <div class="form-group">
                                            <label class="control-label">Summery</label>
                                            <textarea name="lang[{{ $language->code }}][summery]" rows="3"
                                                      class="form-control">{{ (is_array($translations) && is_array($translations[$language->code]))?$translations[$language->code]['summery']:'' }}</textarea>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    @endforeach

                </div>
            </div>
            <!-- end row -->
        </form>


    </div> <!-- container -->
@endsection

@section('js_libs')
    <script src="{{ asset('assets/js/vue.js') }}"></script>
    <script src="{{ asset('assets/js/select2.full.min.js') }}"></script>
    <script src="{{ asset('assets/libs/tinymce/tinymce.min.js') }}"></script>
    <script src="{{ asset('assets/js/select2.vue.js') }}"></script>
@endsection

@section('js')
    <script>
        var editor_config = {
            path_absolute: "{{ url('/') }}/",
            selector: ".editor",
            plugins: [
                "advlist autolink lists link image charmap print preview hr anchor pagebreak",
                "searchreplace wordcount visualblocks visualchars code fullscreen",
                "insertdatetime media nonbreaking save table contextmenu directionality",
                "emoticons template paste textcolor colorpicker textpattern"
            ],
            toolbar: "insertfile undo redo | styleselect | bold italic | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent | link image media",
            relative_urls: false,
            file_browser_callback: function (field_name, url, type, win) {
                var x = window.innerWidth || document.documentElement.clientWidth || document.getElementsByTagName('body')[0].clientWidth;
                var y = window.innerHeight || document.documentElement.clientHeight || document.getElementsByTagName('body')[0].clientHeight;

                var cmsURL = editor_config.path_absolute + 'staff/media?field_name=' + field_name;
                if (type == 'image') {
                    cmsURL = cmsURL + "&type=Images";
                    var title = 'Select Images'
                } else {
                    cmsURL = cmsURL + "&type=Files";
                    var title = 'Select FIles'
                }
                tinyMCE.activeEditor.windowManager.open({
                    file: cmsURL,
                    title: title,
                    width: x * 0.8,
                    height: y * 0.8,
                    resizable: "yes",
                    close_previous: "no"
                });
            }
        };

        tinymce.init(editor_config);
    </script>
    <script>
        (function ($) {
            $.fn.select2.defaults.set("theme", "bootstrap");
            $(document).ready(function () {
                // $('.select2').select2();
                $('#tags').select2({
                    tags: true,
                    tokenSeparators: [','],
                    createTag: function (params) {
                        var term = $.trim(params.term);
                        if (term === '') {
                            return null;
                        }
                        return {
                            id: term,
                            text: term
                        }
                    }
                }).on('change', function (e) {
                    var isNew = $(this).find('[data-select2-tag="true"]');
                    if (isNew.length && $.inArray(isNew.val(), $(this).val()) !== -1) {
                        $.post('{{ route('staff.tag.store') }}', {
                            _token: '{{ csrf_token() }}',
                            name: isNew.val()
                        }).done(tag => {
                            isNew.replaceWith('<option selected value="' + tag.id + '">' + tag.name + '</option>');
                        })
                    }
                })
                var counts = 1;
            })

            $(document).on('click', '.btn-select', function (e) {
                e.preventDefault()
                var input = $($(this).data('input'))
                var preview = $($(this).data('preview'))
                var title = $(this).data('title')
                var prop = $(this).data('prop')
                openMediaManager(items => {
                    if (items[0] && items[0].hasOwnProperty(prop)) {
                        preview.attr('src', items[0][prop])
                        input.val(items[0][prop])
                    }
                }, 'image', title || 'Select Icon')
            })
        })(jQuery)
    </script>
    <script>
        window.makeSlug = function (str) {
            if (!str) return;
            const a = 'àáäâãåăæçèéëêǵḧìíïîḿńǹñòóöôœøṕŕßśșțùúüûǘẃẍÿź·/_,:;'
            const b = 'aaaaaaaaceeeeghiiiimnnnooooooprssstuuuuuwxyz------'
            const p = new RegExp(a.split('').join('|'), 'g')

            return str.toString().toLowerCase()
                .replace(/\s+/g, '-') // Replace spaces with -
                .replace(p, c => b.charAt(a.indexOf(c))) // Replace special characters
                .replace(/&/g, '-and-') // Replace & with ‘and’
                .replace(/[^\w\-]+/g, '') // Remove all non-word characters
                .replace(/\-\-+/g, '-') // Replace multiple - with single -
                .replace(/^-+/, '') // Trim - from start of text
                .replace(/-+$/, '') // Trim - from end of text
        }
        window.app = new Vue({
            el: '#app',
            components: {
                select2Vue
            },
            data: {
                title: '{{ $blogPost->title ??'' }}',
                summery: '{{ $blogPost->summery ??'' }}',
                feature_image: '{{ $blogPost->feature_image ??'https://via.placeholder.com/200' }}',
                slug: '{{ $blogPost->slug ??'' }}',
            },
            methods: {
                removeGalleryImage(index) {
                    this.gallery.splice(index, 1);
                },
                makeSlug(str) {
                    return window.makeSlug(str)
                },
                selectImage() {
                    openMediaManager(items => {
                        if (items[0] && items[0].hasOwnProperty('thumb_url')) {
                            this.feature_image = items[0].url
                        }
                    }, 'image', 'Select Image')
                }
            },
            watch: {
                title: {
                    handler: function (newValue) {
                        this.slug = window.makeSlug(newValue)
                    },
                    deep: true
                }
            }
        })
    </script>
@endsection


