@extends('staff.layouts.master')

@section('title', __('Edit Page'))

@section('css_libs')
    <link href="{{ asset('assets/libs/select2/css/select2.min.css') }}" rel="stylesheet" type="text/css"/>
@endsection

@section('css')
    <style>
        .accordion {
            min-height: unset;
            cursor: pointer;
        }
    </style>
@endsection

@section('content')
    <!-- Start Content-->
    <div class="container-fluid">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a>
                            </li>
                            <li class="breadcrumb-item"><a
                                    href="{{ route('staff.page.index') }}">@lang('Pages')</a></li>
                            <li class="breadcrumb-item active">@lang('Edit Page')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('Edit Page')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <form action="{{ route('staff.page.update', $page->id) }}" method="post">
            @csrf
            @method('PUT')
            @include('layouts.partials.flash-alert')
            <div class="row">
                <div class="col-md-12">
                    <div class="card-box">
                        <div class="nimmu-default-card">
                            <div
                                class="nimmu-default-card-header nimmu-mb-30 d-flex justify-content-between align-content-center">
                                <div class="nimmu-header-left">
                                    <h5>General Info</h5>
                                </div>
                                <div>
                                    <button type="submit"
                                            class="btn btn-primary btn-lg nimmu-btn nimmu-btn-primary">Update
                                    </button>
                                    <button type="reset"
                                            class="btn btn-danger btn-lg nimmu-btn nimmu-btn-danger">Reset</button>
                                </div>
                            </div>
                            <div class="nimmu-default-card-body">
                                <div class="form-group">
                                    <label class="control-label">Title</label>
                                    <input type="text" name="title" id="title"
                                           class="form-control form-control-lg" value="{{ $page->title }}" required>
                                </div>
                                <div class="row">
                                    <div class="col-md-4">
                                        <div class="form-group">
                                            <label class="control-label">Slug</label>
                                            <input type="text" name="slug" id="slug"
                                                   class="form-control" value="{{ $page->slug }}" required>
                                        </div>
                                    </div>
                                    <div class="col-md-4">
                                        <div class="form-group">
                                            <label class="control-label">Type</label>
                                            <select name="type" class="form-control select2">
                                                @foreach(config('theme.settings.page_templates') as $name=>$title)
                                                    <option value="{{ $name }}" {{ $page->type == $name ? 'selected':'' }}>{{ ucfirst($title) }}</option>
                                                @endforeach
                                            </select>
                                        </div>
                                    </div>
                                    <div class="col-md-4">
                                        <div class="form-group">
                                            <label class="control-label">Status</label>
                                            <select name="status" class="form-control select2">
                                                <option value="1" {{ $page->status == 1?'selected':'' }}>Published</option>
                                                <option value="0" {{ $page->status == 0?'selected':'' }}>Draft</option>
                                            </select>
                                        </div>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="control-label" for="summery">Summery</label>
                                    <textarea name="summery" id="summery"
                                              class="form-control">{{ $page->summery }}</textarea>
                                </div>
                                <div class="form-group">
                                    <label class="control-label">Content</label>
                                    <textarea name="content" id="content"
                                              class="form-control editor">{!! $page->content !!}</textarea>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card-box">
                        <div class="nimmu-default-card accordion">
                            <div
                                class="nimmu-default-card-header d-flex justify-content-between align-content-center"
                                data-toggle="collapse" data-target="#meta-info" aria-expanded="false"
                                aria-controls="meta-info">
                                <div class="nimmu-header-left">
                                    <h5>Meta Info &nbsp;<i class="fas fa-angle-down"></i></h5>
                                </div>
                            </div>
                            <div class="nimmu-default-card-body mt-3 collapse" id="meta-info">
                                <div class="col-lg-12">
                                    <div class="form-group">
                                        <label class="control-label">Meta title</label>
                                        <input type="text" name="meta[title]" value="{{ isset($metas['title'])?$metas['title']:null }}"
                                               class="form-control">
                                    </div>
                                    <div class="form-group">
                                        <label class="control-label">Meta description</label>
                                        <textarea name="meta[description]"
                                                  class="form-control">{{ isset($metas['description'])?$metas['description']:null }}</textarea>
                                    </div>
                                    <div class="form-group">
                                        <label class="control-label">Meta keywords</label>
                                        <input type="text" name="meta[keywords]"
                                               value="{{ isset($metas['keywords'])?$metas['keywords']:null }}"
                                               class="form-control tags">
                                    </div>
                                    <div class="form-group col-md-4 pl-0">
                                        <label class="control-label">Meta image</label>
                                        <img src="{{ isset($metas['og_image'])?$metas['og_image']:null }}"
                                             id="og-image-preview" class="w-100">
                                        <input type="hidden" id="og-image-input" name="meta[og_image]"
                                               value="{{ isset($metas['og_image'])?$metas['og_image']:null }}"
                                               class="form-control">
                                        <button class="btn btn-success btn-block nimmu-btn nimmu-btn-success btn-select"
                                                data-input="#og-image-input" data-preview="#og-image-preview"
                                                data-prop="url"
                                                data-title="Select Image">Select Image
                                        </button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    @foreach($languages as $language)
                        <div class="card-box">
                            <div class="nimmu-default-card accordion">
                                <div
                                    class="nimmu-default-card-header d-flex justify-content-between align-content-center"
                                    data-toggle="collapse" data-target="#translation-{{ $language->code }}"
                                    aria-expanded="false" aria-controls="translation-{{ $language->code }}">
                                    <div class="nimmu-header-left">
                                        <h5>Transaction ({{ $language->code }}) &nbsp;<i class="fas fa-angle-down"></i></h5>
                                    </div>
                                </div>
                                <div class="nimmu-default-card-body mt-3 collapse" id="translation-{{ $language->code }}">
                                    <div class="form-group">
                                        <label class="control-label">Title</label>
                                        <input type="text" name="lang[{{ $language->code }}][title]"
                                               value="{{ (isset($translations[$language->code]) && is_array($translations[$language->code]))?$translations[$language->code]['title']:'' }}"
                                               class="form-control">
                                    </div>
                                    <div class="form-group">
                                        <label class="control-label">Summery</label>
                                        <textarea name="lang[{{ $language->code }}][summery]" class="form-control">{!! (isset($translations[$language->code]) && is_array($translations[$language->code])?$translations[$language->code]['summery']:'') !!}</textarea>
                                    </div>
                                    <div class="form-group">
                                        <label class="control-label">Content</label>
                                        <textarea name="lang[{{ $language->code }}][content]"
                                                  class="form-control editor">{!! (isset($translations[$language->code]) && is_array($translations[$language->code])?$translations[$language->code]['content']:'') !!}</textarea>
                                    </div>
                                </div>
                            </div>
                        </div>
                    @endforeach
                </div>
            </div>
            <!-- end row -->
        </form>


    </div> <!-- container -->
@endsection

@section('js_libs')
    <script src="{{ asset('assets/libs/select2/js/select2.min.js') }}"></script>
    <script src="{{ asset('assets/libs/tinymce/tinymce.min.js') }}"></script>
@endsection

@section('js')
    <script>
        var editor_config = {
            path_absolute: "{{ url('/') }}/",
            selector: ".editor",
            plugins: [
                "advlist autolink lists link image charmap print preview hr anchor pagebreak",
                "searchreplace wordcount visualblocks visualchars code fullscreen",
                "insertdatetime media nonbreaking save table contextmenu directionality",
                "emoticons template paste textcolor colorpicker textpattern"
            ],
            toolbar: "insertfile undo redo | styleselect | bold italic | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent | link image media",
            relative_urls: false,
            file_browser_callback: function (field_name, url, type, win) {
                var x = window.innerWidth || document.documentElement.clientWidth || document.getElementsByTagName('body')[0].clientWidth;
                var y = window.innerHeight || document.documentElement.clientHeight || document.getElementsByTagName('body')[0].clientHeight;

                var cmsURL = editor_config.path_absolute + 'staff/media?field_name=' + field_name;
                if (type == 'image') {
                    cmsURL = cmsURL + "&type=Images";
                    var title = 'Select Images'
                } else {
                    cmsURL = cmsURL + "&type=Files";
                    var title = 'Select FIles'
                }
                tinyMCE.activeEditor.windowManager.open({
                    file: cmsURL,
                    title: title,
                    width: x * 0.8,
                    height: y * 0.8,
                    resizable: "yes",
                    close_previous: "no"
                });
            }
        };

        tinymce.init(editor_config);
    </script>
    <script>
        window.slugfy = function slug(str) {
            if (!str) return;
            const a = 'àáäâãåăæçèéëêǵḧìíïîḿńǹñòóöôœøṕŕßśșțùúüûǘẃẍÿź·/_,:;'
            const b = 'aaaaaaaaceeeeghiiiimnnnooooooprssstuuuuuwxyz------'
            const p = new RegExp(a.split('').join('|'), 'g')

            return str.toString().toLowerCase()
                .replace(/\s+/g, '-') // Replace spaces with -
                .replace(p, c => b.charAt(a.indexOf(c))) // Replace special characters
                .replace(/&/g, '-and-') // Replace & with ‘and’
                .replace(/[^\w\-]+/g, '') // Remove all non-word characters
                .replace(/\-\-+/g, '-') // Replace multiple - with single -
                .replace(/^-+/, '') // Trim - from start of text
                .replace(/-+$/, '') // Trim - from end of text
        };
        (function ($) {
            $(document).on('click', '.btn-select', function (e) {
                e.preventDefault()
                var input = $($(this).data('input'))
                var preview = $($(this).data('preview'))
                var title = $(this).data('title')
                var prop = $(this).data('prop')
                openMediaManager(items => {
                    if (items[0] && items[0].hasOwnProperty(prop)) {
                        preview.attr('src', items[0][prop])
                        input.val(items[0][prop])
                    }
                }, 'image', title || 'Select Icon')
            })
            $(document).on('input', '#title', function (e) {
                var slug = slugfy($(this).val())
                $('#slug').val(slug)
            })
        })(jQuery)
    </script>
@endsection
