@extends('staff.layouts.master')

@section('title', 'Staff Role Management')

@section('css_libs')
    <link href="{{ asset('assets/libs/datatables.net-bs4/css/dataTables.bootstrap4.min.css') }}" rel="stylesheet"
          type="text/css"/>
    <link href="{{ asset('assets/libs/datatables.net-responsive-bs4/css/responsive.bootstrap4.min.css') }}"
          rel="stylesheet" type="text/css"/>
    <link href="{{ asset('assets/libs/datatables.net-buttons-bs4/css/buttons.bootstrap4.min.css') }}" rel="stylesheet"
          type="text/css"/>
@endsection

@section('content')
    <!-- Start Content-->
    <div class="container-fluid">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a></li>
                            <li class="breadcrumb-item">@lang('Role')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('All Staff Roles')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <div class="row">
            <div class="col-md-6 col-sm-6">
                <ul class="nav nav-tabs">
                    <li class="nav-item">
                        <a class="nav-link active" href="{{ route('staff.staff-role.index') }}">Staff Role</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="{{ route('staff.user-role.index') }}">User Role</a>
                    </li>
                </ul>
            </div>
            <div class="offset-md-4 col-md-2 col-sm-6 justify-content-center justify-content-md-end">
                <button class="btn btn-success btn-block" data-toggle="modal"
                        data-target="#new-modal"><i
                        class="fa fa-plus"></i> Add New Staff Role
                </button>
            </div>
        </div>

        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">
                        @include('layouts.partials.flash-alert')
                        @if($errors->any())
                            @foreach($errors->all() as $error)
                                <div class="alert alert-danger alert-dismissable fade show" role="alert">
                                    {{ $error }}
                                    <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                        <span aria-hidden="true">&times;</span>
                                    </button>
                                </div>
                            @endforeach
                        @endif
                        <table id="data-table" class="table table-bordered dt-responsive nowrap w-100 text-center">
                            <thead>
                            <tr>
                                <th>@lang('Name')</th>
                                <th>@lang('Capabilities')</th>
                                <th>@lang('Actions')</th>
                            </tr>
                            </thead>
                        </table>

                    </div> <!-- end card body-->
                </div> <!-- end card -->
            </div><!-- end col-->
        </div>
        <!-- end row-->
    </div> <!-- container -->

    <div class="modal fade" id="new-modal">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title">Add New Role</h4>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">×</span></button>
                </div>
                <form action="{{ route('staff.staff-role.store') }}" method="post" id="addNewRole">
                    @csrf
                    <div class="modal-body">
                        <div class="form-group">
                            <label class="control-label">Role Name</label>
                            <input type="text" name="name" class="form-control" value="{{ old('name') }}">
                        </div>
                        <div class="form-group row">
                            @foreach(array_chunk(config('caps.staff'), 3, true) as $caps)
                                <div class="col-md-4">
                                    @foreach($caps as $key => $value)
                                        <div class="form-group">
                                            <label>
                                                <input type="checkbox" class="flat-red" name="caps[]"
                                                       value="{{ $key }}" {{ old('caps') && in_array($key, old('caps'))?'checked':'' }}> {{ $value }}
                                            </label>
                                        </div>
                                    @endforeach
                                </div>
                            @endforeach
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-default pull-left" data-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary">Save</button>
                    </div>
                </form>
            </div>
            <!-- /.modal-content -->
        </div>
        <!-- /.modal-dialog -->
    </div>

    <div class="modal fade" id="edit-modal">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title">Edit Role</h4>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">×</span></button>
                </div>
                <form method="post">
                    @csrf
                    @method('PUT')
                    <div class="modal-body">
                        <div class="form-group">
                            <label class="control-label">Role Name</label>
                            <input type="text" name="name" id="name" class="form-control">
                        </div>
                        <div class="form-group row">
                            @foreach(array_chunk(config('caps.staff'), 3, true) as $caps)
                                <div class="col-md-4">
                                    @foreach($caps as $key => $value)
                                        <div class="form-group">
                                            <label>
                                                <input type="checkbox" class="flat-red cap-checkbox"
                                                       id="{{ $key }}"
                                                       name="caps[]" value="{{ $key }}"> {{ $value }}
                                            </label>
                                        </div>
                                    @endforeach
                                </div>
                            @endforeach
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-default pull-left" data-dismiss="modal">Close
                        </button>
                        <button type="submit" class="btn btn-primary">Update</button>
                    </div>
                </form>
            </div>
            <!-- /.modal-content -->
        </div>
        <!-- /.modal-dialog -->
    </div>

    <div class="modal fade" id="delete-modal">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title">Delete Role</h4>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">×</span></button>
                </div>
                <form method="post">
                    @csrf
                    @method('DELETE')
                    <div class="modal-body">
                        <h3 class="text-center">Are you sure to delete this role?</h3>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-default pull-left" data-dismiss="modal">Close
                        </button>
                        <button type="submit" class="btn btn-danger">Delete</button>
                    </div>
                </form>
            </div>
            <!-- /.modal-content -->
        </div>
        <!-- /.modal-dialog -->
    </div>
@endsection

@section('js_libs')
    <script src="{{ asset('assets/libs/datatables.net/js/jquery.dataTables.min.js') }}"></script>
    <script src="{{ asset('assets/libs/datatables.net-bs4/js/dataTables.bootstrap4.min.js') }}"></script>
    <script src="{{ asset('assets/libs/datatables.net-responsive/js/dataTables.responsive.min.js') }}"></script>
    <script src="{{ asset('assets/libs/datatables.net-responsive-bs4/js/responsive.bootstrap4.min.js') }}"></script>
@endsection

@section('js')
    <script>
        (function ($) {
            $(document).ready(function () {
                $('#data-table').DataTable({
                    processing: true,
                    serverSide: true,
                    ajax: '{{ route('staff.staff-role.index') }}',
                    columns: [
                        {data: 'name', name: 'name'},
                        {data: 'caps', name: 'caps'},
                        {data: 'action', name: 'action', orderable: false, searchable: false}
                    ],
                    language: {
                        paginate: {
                            previous: "<i class='mdi mdi-chevron-left'>",
                            next: "<i class='mdi mdi-chevron-right'>",
                        },
                    },
                    drawCallback: function () {
                        $(".dataTables_paginate > .pagination").addClass("pagination-rounded");
                    },
                });
            })

            $(document).on("submit", "#addNewRole", function() {
                $(this).submit(function() {
                    return false;
                });
                return true;
            });
            $(document).on('click', '.btn-edit', function (e) {
                e.preventDefault()

                var datas = [];
                [].forEach.call(this.attributes, function (attr) {
                    if (/^data-/.test(attr.name)) {
                        var camelCaseName = attr.name.substr(5).replace(/-(.)/g, function ($0, $1) {
                            return $1.toUpperCase()
                        })
                        datas.push({
                            name: camelCaseName,
                            value: attr.value
                        })
                    }
                })
                datas.forEach(function (data) {
                    if (data.name == 'id') {
                        var url = '{{ url('staff/staff-role') }}/' + data.value
                        $('#edit-modal form').prop('action', url)
                    } else if (data.name == 'caps') {
                        $('.cap-checkbox').prop('checked', false)
                        JSON.parse(data.value).forEach((cap) => {
                            $('#' + cap).prop('checked', true)
                        })
                    }
                    $('#' + data.name).val(data.value)
                })

                $('#edit-modal').modal('show')
            })
            $(document).on('click', '.btn-delete', function (e) {
                e.preventDefault()
                var id = $(this).data('id')
                var url = '{{ url('staff/staff-role') }}/' + id
                $('#delete-modal form').prop('action', url)
                $('#delete-modal').modal()
            })
        })(jQuery)
    </script>
@endsection
