@extends('staff.layouts.master')

@section('title', __('Edit Currency'))

@section('css_libs')
    <link href="{{ asset('assets/libs/select2/css/select2.min.css') }}" rel="stylesheet" type="text/css"/>
@endsection

@section('content')
    <!-- Start Content-->
    <div class="container-fluid">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a>
                            </li>
                            <li class="breadcrumb-item">@lang('Setting')</li>
                            <li class="breadcrumb-item"><a href="{{ route('staff.setting.currency.index') }}">@lang('Currency')</a></li>
                            <li class="breadcrumb-item active">@lang('Edit')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('Edit Currency')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <form action="{{ route('staff.setting.currency.update', $currency->id) }}" method="post">
            @csrf
            @method('PUT')
            @include('layouts.partials.flash-alert')
            <div class="row">
                <div class="col-lg-6">
                    <div class="card-box">
                        <h3 class="text-uppercase bg-light p-2 mt-0 mb-3">@lang('Details')</h3>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label for="name">@lang('Name') <span class="text-danger">*</span></label>
                                    <input type="text" placeholder="US Dollar"
                                           class="form-control @error('name') is-invalid @enderror" id="name"
                                           name="name"
                                           value="{{ $currency->name }}" required autofocus>
                                    @error('name')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label for="code">@lang('Code') <span class="text-danger">*</span></label>
                                    <input type="text" placeholder="USD"
                                           class="form-control @error('code') is-invalid @enderror" id="code"
                                           name="code"
                                           value="{{ $currency->code }}" style="text-transform: uppercase;" required>
                                    @error('code')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label for="symbol">@lang('Symbol')<span class="text-danger">*</span></label>
                                    <input type="text" placeholder="$"
                                           class="form-control @error('symbol') is-invalid @enderror" id="symbol"
                                           name="symbol"
                                           value="{{ $currency->symbol }}" required>
                                    @error('symbol')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label for="rate">@lang('Rate')<span class="text-danger">*</span></label>
                                    <div class="input-group">
                                        <input type="number" step="0.01" placeholder="0.8"
                                               class="form-control @error('rate') is-invalid @enderror" id="rate"
                                               name="rate"
                                               value="{{ $currency->rate }}" required>
                                        <div class="input-group-append">
                                            <span class="input-group-text">{{ $default->code }}</span>
                                        </div>
                                    </div>
                                    @error('rate')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label for="symbol_position">@lang('Symbol Position') <span
                                            class="text-danger">*</span></label>
                                    <select class="form-control select2 @error('symbol_position') is-invalid @enderror"
                                            id="symbol_position" name="symbol_position" required>
                                        @foreach(config('currencies.formats') as $code => $format)
                                            <option
                                                value="{{ $code }}" {{ $currency->symbol_position == $code?'selected':'' }}>{{ ucwords(str_replace('_', ' ', $code)) }}</option>
                                        @endforeach
                                    </select>
                                    @error('symbol_position')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label for="precision">@lang('Precision') <span
                                            class="text-danger">*</span></label>
                                    <input type="number" step="1" placeholder="2"
                                           class="form-control @error('precision') is-invalid @enderror" id="precision"
                                           name="precision"
                                           value="{{ $currency->precision??2 }}" min="1" required>
                                    @error('precision')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label for="decimal_separator">@lang('Thousand Separator') <span
                                            class="text-danger">*</span></label>
                                    <input type="text" placeholder="."
                                           class="form-control @error('decimal_separator') is-invalid @enderror" id="decimal_separator"
                                           name="decimal_separator"
                                           value="{{ $currency->decimal_separator??'.' }}" required>
                                    @error('decimal_separator')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label for="thousand_separator">@lang('Thousand Separator') <span
                                            class="text-danger">*</span></label>
                                    <input type="text" placeholder=","
                                           class="form-control @error('thousand_separator') is-invalid @enderror" id="thousand_separator"
                                           name="thousand_separator"
                                           value="{{ $currency->thousand_separator??',' }}" required>
                                    @error('thousand_separator')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label>@lang('Is Default?') <span class="text-danger">*</span></label>
                                    <br>
                                    <div class="radio form-check-inline mr-4">
                                        <input type="radio" id="is-default-yes" value="1"
                                               name="is_default" {{ $currency->is_default == 1?'checked':'' }}>
                                        <label for="is-default-yes"> @lang('YES') </label>
                                    </div>
                                    <div class="radio form-check-inline mr-4">
                                        <input type="radio" id="is-default-no" value="0"
                                               name="is_default" {{ $currency->is_default == 0?'checked':'' }}>
                                        <label for="is-default-no"> @lang('NO') </label>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label>@lang('Status') <span class="text-danger">*</span></label>
                                    <br>
                                    <div class="radio form-check-inline mr-4">
                                        <input type="radio" id="status-enabled" value="1"
                                               name="status" {{ $currency->status == 1?'checked':'' }}>
                                        <label for="status-enabled"> @lang('Enabled') </label>
                                    </div>
                                    <div class="radio form-check-inline mr-4">
                                        <input type="radio" id="status-disabled" value="0"
                                               name="status" {{ $currency->status == 0?'checked':'' }}>
                                        <label for="status-disabled"> @lang('Disabled') </label>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="form-group text-center mb-3">
                            <button type="submit"
                                    class="btn w-sm btn-success waves-effect waves-light">@lang('Update Currency')</button>
                            <a href="{{ route('staff.setting.currency.index') }}"
                               onclick="return confirm('{{ __('Are you sure to leave this page?') }}')" type="button"
                               class="btn w-sm btn-light waves-effect">@lang('Cancel')</a>
                        </div>
                    </div> <!-- end card-box -->
                </div> <!-- end col -->
            </div>
            <!-- end row -->
        </form>


    </div> <!-- container -->
@endsection

@section('js_libs')
    <script src="{{ asset('assets/libs/select2/js/select2.min.js') }}"></script>
@endsection

@section('js')
    <script>
        (function ($) {
            $(document).ready(function () {
                $('.select2').select2();
            })
        })(jQuery)
    </script>
@endsection
