@extends('staff.layouts.master')

@section('title', __('All Currencies'))

@section('css_libs')
    <link href="{{ asset('assets/libs/datatables.net-bs4/css/dataTables.bootstrap4.min.css') }}" rel="stylesheet"
          type="text/css"/>
    <link href="{{ asset('assets/libs/datatables.net-responsive-bs4/css/responsive.bootstrap4.min.css') }}"
          rel="stylesheet" type="text/css"/>
    <link href="{{ asset('assets/libs/datatables.net-buttons-bs4/css/buttons.bootstrap4.min.css') }}" rel="stylesheet"
          type="text/css"/>
@endsection

@section('content')
    <!-- Start Content-->
    <div class="container-fluid">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a></li>
                            <li class="breadcrumb-item">@lang('Setting')</li>
                            <li class="breadcrumb-item">@lang('Currency')</li>
                            <li class="breadcrumb-item active">@lang('All')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('All Currencies')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <div class="row justify-content-center justify-content-md-end">
            <div class="col-md-2 col-sm-6">
                <button class="btn btn-block btn-primary" onclick="event.preventDefault();document.getElementById('refresh-form').submit();">
                    <i class="fas fa-sync-alt"></i> Update Rates
                </button>
            </div>
            <div class="col-md-2 col-sm-6">
                <a href="{{ route('staff.setting.currency.create') }}" class="btn btn-block btn-success">New Currency</a>
            </div>
        </div>

        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">
                        <form action="{{ route('staff.setting.currency.refresh') }}" method="post" id="refresh-form"
                              class="d-none">
                            @csrf
                            @method('PUT')
                        </form>
                        @include('layouts.partials.flash-alert')
                        <table id="data-table" class="table table-bordered dt-responsive nowrap w-100">
                            <thead>
                            <tr>
                                <th>ID</th>
                                <th>Name</th>
                                <th>Code</th>
                                <th>Rate</th>
                                <th>Default</th>
                                <th>Status</th>
                                <th>Actions</th>
                            </tr>
                            </thead>
                        </table>

                    </div> <!-- end card body-->
                </div> <!-- end card -->
            </div><!-- end col-->
        </div>
        <!-- end row-->


    </div> <!-- container -->

    <div id="delete-modal" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="delete-modalLabel"
         aria-modal="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <form action="" method="post">
                    @csrf
                    @method('DELETE')
                    <div class="modal-header">
                        <h4 class="modal-title" id="delete-modalLabel">@lang('Delete Currency')</h4>
                        <button type="button" class="close" data-dismiss="modal" aria-hidden="true">×</button>
                    </div>
                    <div class="modal-body">
                        <h4>@lang('Are you sure to delete this currency?')</h4>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-light" data-dismiss="modal">@lang('Close')</button>
                        <button type="submit" class="btn btn-danger">@lang('Delete')</button>
                    </div>
                </form>
            </div><!-- /.modal-content -->
        </div><!-- /.modal-dialog -->
    </div>
@endsection

@section('js_libs')
    <script src="{{ asset('assets/libs/datatables.net/js/jquery.dataTables.min.js') }}"></script>
    <script src="{{ asset('assets/libs/datatables.net-bs4/js/dataTables.bootstrap4.min.js') }}"></script>
    <script src="{{ asset('assets/libs/datatables.net-responsive/js/dataTables.responsive.min.js') }}"></script>
    <script src="{{ asset('assets/libs/datatables.net-responsive-bs4/js/responsive.bootstrap4.min.js') }}"></script>
@endsection

@section('js')
    <script>
        $(document).ready(function () {
            $('#data-table').DataTable({
                processing: true,
                serverSide: true,
                ajax: '{{ route('staff.setting.currency.index') }}',
                columns: [
                    {data: 'id', name: 'id'},
                    {data: 'name', name: 'name'},
                    {data: 'code', name: 'code'},
                    {data: 'rate', name: 'rate'},
                    {data: 'is_default', name: 'is_default'},
                    {data: 'status', name: 'status'},
                    {data: 'actions', name: 'actions', orderable: false, searchable: false}
                ],
                language: {
                    paginate: {
                        previous: "<i class='mdi mdi-chevron-left'>",
                        next: "<i class='mdi mdi-chevron-right'>",
                    },
                },
                drawCallback: function () {
                    $(".dataTables_paginate > .pagination").addClass("pagination-rounded");
                },
            });
        })
        $(document).on('click', '.btn-delete', function (e) {
            e.preventDefault()
            const url = '{{ url('staff/setting/currency') }}/' + $(this).data('id')
            $('#delete-modal form').attr('action', url)
            $('#delete-modal').modal('show')
        })
    </script>
@endsection
