@extends('staff.layouts.master')

@section('title', __('New Key Feature'))

@section('css_libs')
    <link href="{{ asset('assets/libs/select2/css/select2.min.css') }}" rel="stylesheet" type="text/css"/>
    <link rel="stylesheet" href="{{ asset('assets/css/select2-bootstrap.css') }}">
@endsection

@section('content')
    <!-- Start Content-->
    <div class="container-fluid">

        <div class="col-12">
            <div class="page-title-box">
                <div class="page-title-right">
                    <ol class="breadcrumb m-0">
                        <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a>
                        </li>
                        <li class="breadcrumb-item"><a
                                href="{{ route('staff.setting.key-features.index') }}">@lang('Key Features')</a></li>
                        <li class="breadcrumb-item active">@lang('New Key Feature')</li>
                    </ol>
                </div>
                <h4 class="page-title">@lang('New Key Feature')</h4>
            </div>
        </div>

        <!-- start page title -->
        <form action="{{ route('staff.setting.key-features.store') }}" method="post">
            @csrf
            @include('layouts.partials.flash-alert')
            @if ($errors->any())
                <div class="alert alert-danger">
                    <ul>
                        @foreach ($errors->all() as $error)
                            <li>{{ $error }}</li>
                        @endforeach
                    </ul>
                </div>
            @endif
            <div class="row">
                <div class="col-md-4">
                    <div class="card-box">
                        <div class="nimmu-default-card nimmu-buttons avatar-pro">
                            <div class="nimmu-default-card-body">
                                <div class="form-group text-center">
                                    <img class="img-thumbnail" style="width: 200px;height: 200px;"
                                         src="https://picsum.photos/200" id="avatar-preview">
                                    <input type="hidden" name="image" value="https://picsum.photos/200" id="avatar">
                                    <button class="btn btn-outline-info nimmu-btn nimmu-btn-outline-info btn-select">Change Image</button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-md-8">
                    <div class="card-box">
                        <div class="nimmu-default-card nimmu-buttons">
                            <div
                                class="nimmu-default-card-header nimmu-mb-30 d-flex justify-content-between align-content-center">
                                <div class="nimmu-header-left">
                                    <h3>Key Feature Info</h3>
                                </div>
                            </div>
                            <div class="nimmu-default-card-body">
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label class="control-label">Title</label>
                                            <input type="text" name="title" class="form-control" required>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label class="control-label">URL</label>
                                            <input type="text" name="action" class="form-control" required>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label class="control-label">Details</label>
                                            <textarea name="details" class="form-control" required></textarea>
                                        </div>
                                    </div>
                                </div>

                                @foreach($languages as $language)
                                    <div class="card-box">
                                        <div class="nimmu-default-card accordion">
                                            <div
                                                class="nimmu-default-card-header d-flex justify-content-between align-content-center"
                                                data-toggle="collapse" data-target="#translation-{{ $language->code }}"
                                                aria-expanded="false" aria-controls="translation-{{ $language->code }}">
                                                <div class="nimmu-header-left">
                                                    <h5>Translation ({{ $language->code }}) &nbsp;<i class="fas fa-angle-down"></i>
                                                    </h5>
                                                </div>
                                            </div>
                                            <div class="nimmu-default-card-body mt-3 collapse"
                                                 id="translation-{{ $language->code }}">
                                                <div class="col-lg-12">
                                                    <div class="form-group">
                                                        <label class="control-label">Title</label>
                                                        <input type="text" name="lang[{{ $language->code }}][title]"
                                                               value="{{ (is_array(old('lang')) && is_array(old('lang')[$language->code]))?old('lang')[$language->code]['title']:'' }}"
                                                               class="form-control">
                                                    </div>
                                                    <div class="form-group">
                                                        <label class="control-label">Details</label>
                                                        <textarea name="lang[{{ $language->code }}][details]"
                                                                  class="form-control">{!! (is_array(old('lang')) && is_array(old('lang')[$language->code])?old('lang')[$language->code]['details']:'') !!}</textarea>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                @endforeach
                                <div class="form-group">
                                    <button class="btn btn-primary btn-block btn-lg nimmu-btn nimmu-btn-primary" type="submit">Save</button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </form>
    </div> <!-- container -->
@endsection

@section('js')
    <script>
        (function ($) {
            $(document).on('click', '.btn-select', function (e) {
                e.preventDefault()
                openMediaManager(items => {
                    if (items[0] && items[0].hasOwnProperty('url')) {
                        $('#avatar').val(items[0].url)
                    }
                    if (items[0] && items[0].hasOwnProperty('thumb_url')) {
                        $('#avatar-preview').attr('src', items[0].thumb_url)
                    }
                }, 'image', 'Select Avatar')
            })
        })(jQuery)
    </script>
@endsection

