@extends('staff.layouts.master')

@section('page_title', 'Logo Settings')

@section('content')
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a></li>
                            <li class="breadcrumb-item">@lang('Setting')</li>
                            <li class="breadcrumb-item">@lang('Logo Settings')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('Logo Settings')</h4>
                </div>
            </div>
        </div>
        <div class="row" id="app">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">
                        @include('layouts.partials.flash-alert')
                        @if($errors->any())
                            @foreach($errors->all() as $error)
                                <div class="alert alert-danger alert-dismissable fade show" role="alert">
                                    {{ $error }}
                                    <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                        <span aria-hidden="true">&times;</span>
                                    </button>
                                </div>
                            @endforeach
                        @endif
                        <form action="{{ route('staff.setting.logo.update') }}" method="post">
                            @csrf
                            @method('PUT')
                            <div class="container-fluid nimmu-buttons">
                                <div class="nimmu-default-card nimmu-buttons">
                                    <div class="nimmu-default-card-body">
                                        <div class="row">
                                            <div class="col-md-4">
                                                <div class="form-group text-center">
                                                    <div>
                                                        <img class="img-thumbnail" src="{{ get_option('large_logo', config('ui.logo.large')) }}" id="large-logo" alt="Large Logo">
                                                    </div>
                                                    <input type="hidden" name="large_logo" id="large_logo" value="{{ get_option('large_logo', config('ui.logo.large')) }}">
                                                    <button class="btn btn-outline-info btn-lg nimmu-btn nimmu-btn-outline-info btn-select" data-input="#large_logo" data-preview="#large-logo" data-prop="url" data-title="Select Large Logo">Change Large Logo</button>
                                                </div>
                                            </div>
                                            <div class="col-md-4">
                                                <div class="form-group text-center mt-auto">
                                                    <div>
                                                        <img class="img-thumbnail" src="{{ get_option('small_logo', config('ui.logo.small')) }}" id="small-logo" alt="Small Logo">
                                                    </div>
                                                    <input type="hidden" name="small_logo" id="small_logo" value="{{ get_option('small_logo', config('ui.logo.small')) }}">
                                                    <button class="btn btn-outline-info btn-lg nimmu-btn nimmu-btn-outline-info btn-select" data-input="#small_logo" data-preview="#small-logo" data-prop="url" data-title="Select Small Logo">Change Small Logo</button>
                                                </div>
                                            </div>
                                            <div class="col-md-4">
                                                <div class="form-group text-center mt-auto">
                                                    <div>
                                                        <img class="img-thumbnail" src="{{ get_option('favicon', config('ui.favicon')) }}" id="favicon" alt="favicon">
                                                    </div>
                                                    <input type="hidden" name="favicon" id="favicon-input" value="{{ get_option('ui.favicon') }}">
                                                    <button class="btn btn-outline-info btn-lg nimmu-btn nimmu-btn-outline-info btn-select" data-input="#favicon-input" data-preview="#favicon" data-prop="url" data-title="Select Favicon">Change Favicon</button>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="form-group">
                                            <button class="btn btn-primary btn-block btn-lg nimmu-btn nimmu-btn-primary"
                                                    type="submit">Update Settings
                                            </button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </form>
                    </div> <!-- end card body-->
                </div> <!-- end card -->
            </div><!-- end col-->
        </div>
    </div>
@endsection

@section('js')
    <script>
        (function ($) {
            $(document).on('click', '.btn-select', function (e) {
                e.preventDefault()
                const preview = $($(this).data('preview'))
                const input = $($(this).data('input'))
                const title = $(this).data('title')
                const prop = $(this).data('prop')
                openMediaManager(items => {
                    if (items[0] && items[0].hasOwnProperty(prop)) {
                        input.val(items[0][prop])
                        preview.attr('src', items[0][prop])
                    }
                }, 'image', title)
            })
        })(jQuery)
    </script>
@endsection
