
@extends('staff.layouts.master')

@section('title', __('Menus'))

@section('css_libs')
    <link href="{{ asset('assets/libs/datatables.net-bs4/css/dataTables.bootstrap4.min.css') }}" rel="stylesheet"
          type="text/css"/>
    <link href="{{ asset('assets/libs/datatables.net-responsive-bs4/css/responsive.bootstrap4.min.css') }}"
          rel="stylesheet" type="text/css"/>
    <link href="{{ asset('assets/libs/datatables.net-buttons-bs4/css/buttons.bootstrap4.min.css') }}" rel="stylesheet"
          type="text/css"/>
@endsection

@section('content')
    <!-- Start Content-->
    <div class="container-fluid">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a>
                            </li>
                            <li class="breadcrumb-item active">@lang('Menus')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('Menus')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <div class="row">
            <div class="col-xl-3 col-lg-12">
                <div class="card-box">
                    <form id="attribute-form" action="{{ route('staff.setting.menu.store') }}" method="post">
                        @csrf
                        @method('POST')
                        <div class="nimmu-default-card">
                            <div class="nimmu-default-card-header nimmu-mb-30 d-flex justify-content-between">
                                <h4>New Menu</h4>
                            </div>
                            <div class="nimmu-default-card-body">
                                <div class="form-group">
                                    <label for="title">Title</label>
                                    <input id="title" value="{{ old('title') }}" name="title"
                                           class="form-control input-lg @error('title') is-invalid @enderror"
                                           type="text" required>
                                    @error('title')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                                <div class="form-group">
                                    <label class="control-label" for="location">Location</label>
                                    <select id="location" name="location"
                                            class="form-control input-lg @error('location') is-invalid @enderror" required>
                                        @foreach(config('theme.settings.menu.locations') as $key => $text)
                                            <option value="{{ $key }}">{{ $text }}</option>
                                        @endforeach
                                    </select>
                                    @error('location')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                                <div class="form-group">
                                    <button class="btn btn-success" type="submit">Save</button>
                                    <button class="btn btn-outline-danger" type="reset">Reset</button>
                                </div>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
            <div class="col-xl-9 col-lg-12">
                    <div class="card-box">
                        @include('layouts.partials.flash-alert')
                        <table id="data-table" class="table table-bordered dt-responsive nowrap w-100 text-center">
                            <thead>
                            <tr>
                                <th>#</th>
                                <th>@lang('Title')</th>
                                <th>@lang('Location')</th>
                                <th>@lang('Action')</th>
                            </tr>
                            </thead>
                        </table>
                    </div> <!-- end card body-->
            </div><!-- end col-->
        </div>
        <!-- end row-->


    </div> <!-- container -->

    <div id="delete-modal" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="delete-modalLabel"
         aria-modal="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <form action="" method="post">
                    @csrf
                    @method('DELETE')
                    <div class="modal-header">
                        <h4 class="modal-title" id="delete-modalLabel">@lang('Delete Menu')</h4>
                        <button type="button" class="close" data-dismiss="modal" aria-hidden="true">×</button>
                    </div>
                    <div class="modal-body">
                        <h4>@lang('Are you sure to delete this menu ?')</h4>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-light" data-dismiss="modal">@lang('Close')</button>
                        <button type="submit" class="btn btn-danger">@lang('Delete')</button>
                    </div>
                </form>
            </div><!-- /.modal-content -->
        </div><!-- /.modal-dialog -->
    </div>
@endsection

@section('js_libs')
    <script src="{{ asset('assets/libs/datatables.net/js/jquery.dataTables.min.js') }}"></script>
    <script src="{{ asset('assets/libs/datatables.net-bs4/js/dataTables.bootstrap4.min.js') }}"></script>
    <script src="{{ asset('assets/libs/datatables.net-responsive/js/dataTables.responsive.min.js') }}"></script>
    <script src="{{ asset('assets/libs/datatables.net-responsive-bs4/js/responsive.bootstrap4.min.js') }}"></script>
@endsection

@section('js')
    <script>
        $(document).ready(function () {
            $('[data-toggle="tooltip"]').tooltip()
            $('#data-table').DataTable({
                processing: true,
                serverSide: true,
                ajax: '{{ route('staff.setting.menu.index') }}',
                columns: [
                    {data: 'id', name: 'id'},
                    {data: 'title', name: 'title'},
                    {data: 'location', name: 'location'},
                    {data: 'action', name: 'action', searchable: false, orderable: false}
                ]
            });
        })
        $(document).on('click', '.btn-edit', function (e) {
            e.preventDefault()
            var form = $('#attribute-form')
            form.find('.nimmu-default-card-header h4').text('Edit')
            form.find('[name="_method"]').val('PUT')
            form.find('[type="submit"]').text('Update')
            var datas = [];
            [].forEach.call(this.attributes, function (attr) {
                if (/^data-/.test(attr.name)) {
                    var camelCaseName = attr.name.substr(5).replace(/-(.)/g, function ($0, $1) {
                        return $1.toUpperCase();
                    });
                    datas.push({
                        name: camelCaseName,
                        value: attr.value
                    });
                }
            });
            datas.forEach(data => {
                if (data.name == 'id') {
                    var url = '{{ url('staff/setting/menu') }}/' + data.value;
                    form.attr('action', url);
                } else {
                    $('#' + data.name).val(data.value);
                }
            })

        })
        $(document).on('reset', '#menu-form', function (e) {
            var form = $(this)
            form.find('.nimmu-default-card-header h4').text('New Menu')
            form.find('[name="_method"]').val('POST')
            form.find('[type="submit"]').text('Save')
            form.attr('action', '{{ route('staff.setting.menu.store') }}')
        })
        $(document).on('click', '.btn-delete', function (e) {
            e.preventDefault();
            var id = $(this).data('id');
            var url = '{{ url('staff/setting/menu') }}/' + id
            $('#delete-modal form').prop('action', url);
            $('#delete-modal').modal();
        })
    </script>
@endsection


