
@extends('staff.layouts.master')

@section('title', __('Menus'))

@section('css')
    <style>
        .form-group.records {
            max-height: 200px;
            overflow-y: scroll;
        }

        .relative {
            position: relative;
        }

        .overlay {
            position: absolute;
            width: 100%;
            height: 100%;
            top: 0;
            left: 0;
            background: rgba(0, 0, 0, 0.3);
            color: #fff;
        }

        .menu-lang-card {
            background: #ffffff;
            border-radius: 9px;
            transition: all 0.4s ease-in-out 0s;
            box-shadow: 0px 14px 60px rgb(0 0 0 / 6%);
        }

        ul {
            list-style-type: none;
        }
    </style>
@endsection

@section('content')
    <!-- Start Content-->
    <div class="container-fluid" id="app">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a>
                            </li>
                            <li class="breadcrumb-item active">@lang('Menus')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('Menus')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <div class="row">
            <div class="col-xl-3 col-lg-12">
                <div class="card-box">
                    @foreach($cards as $card)
                        <div class="nimmu-default-card nimmu-mt-30">
                            <div class="nimmu-default-card-header nimmu-mb-30 d-flex justify-content-between">
                                <h4>{{ $card['name'] }}</h4>
                            </div>
                            <div class="nimmu-default-card-body">
                                <div class="form-group records">
                                    @if($card['records']->count())
                                        @foreach($card['records'] as $record)
                                            <div class="form-check">
                                                <input type="checkbox" class="form-check-input"
                                                       id="{{ $record->getItemId() }}"
                                                       v-model="tempItems['{{ $card['id'] }}']"
                                                       :value='{text: @json($record->getItemText()), url: @json($record->getItemUrl())}'>
                                                <label class="form-check-label"
                                                       for="{{ $record->getItemId() }}">{{ $record->getItemText() }}</label>
                                            </div>
                                        @endforeach
                                    @else
                                        <h6 class="text-center">No Records</h6>
                                    @endif
                                </div>
                                <div class="form-group">
                                    <button class="btn btn-success" type="button"
                                            @click.prevent="addItems('{{ $card['id'] }}')">Add To Menu
                                    </button>
                                </div>
                            </div>
                        </div>
                    @endforeach
                    <div class="nimmu-default-card nimmu-mt-30">
                        <div class="nimmu-default-card-header nimmu-mb-30 d-flex justify-content-between">
                            <h4>Custom Link</h4>
                        </div>
                        <div class="nimmu-default-card-body">
                            <div class="form-group">
                                <label for="custom_text">Link Text</label>
                                <input type="text" class="form-control" id="custom_text" placeholder="Home"
                                       v-model="custom.text">
                            </div>
                            <div class="form-group">
                                <label for="custom_url">Link URL</label>
                                <input type="url" class="form-control" id="custom_url" placeholder="#"
                                       v-model="custom.url">
                            </div>
                            <div class="form-group">
                                <label for="custom_target">Link Target</label>
                                <select class="form-control" id="custom_target" v-model="custom.target">
                                    <option value="_blank">Blank</option>
                                    <option value="_self">Self</option>
                                    <option value="_parent">Parent</option>
                                    <option value="_top">Top</option>
                                </select>
                            </div>
                            <div class="form-group">
                                <button class="btn btn-success" type="button" @click.prevent="addCustom">Add To Menu
                                </button>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-xl-9 col-lg-12">
                <div class="card-box">
                    @include('layouts.partials.flash-alert')
                    <div class="nimmu-default-card nimmu-mt-30 relative">
                        <div class="overlay d-flex justify-content-center align-items-center" v-if="loading">
                            <i class="fa fa-spinner fa-spin fa-3x"></i>
                        </div>
                        <div class="nimmu-default-card-header nimmu-mb-30">
                            <h4>Menu Items</h4>
                        </div>
                        <div class="nimmu-default-card-body">
                            <nested-draggable :items="items" :parent="null"/>
                        </div>
                        <div class="nimmu-default-card-footer mt-2">
                            <button @click.prevent="saveMenu"
                                    class="btn btn-success nimmu-btn nimmu-btn-success btn-lg">
                                Update
                            </button>
                        </div>
                    </div>
                </div> <!-- end card body-->
            </div><!-- end col-->
        </div>
        <!-- end row-->

        <div class="modal fade" id="edit-modal">
            <div class="modal-dialog">
                <div class="modal-content" v-if="temp">
                    <div class="modal-header">
                        <h4 class="modal-title">Edit</h4>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">×</span></button>
                    </div>
                    <div class="modal-body">
                        <div class="form-group">
                            <label for="text">Text</label>
                            <input type="text" id="text" class="form-control" v-model="temp.text">
                        </div>
                        <div class="form-group" v-if="temp.type == 'custom'">
                            <label for="url">URL</label>
                            <input type="text" id="url" class="form-control" v-model="temp.url">
                        </div>
                        <div class="form-group">
                            <label for="target">Link target</label>
                            <select class="form-control" id="target" v-model="temp.target">
                                <option value="_blank">Blank</option>
                                <option value="_self">Self</option>
                                <option value="_parent">Parent</option>
                                <option value="_top">Top</option>
                            </select>
                        </div>
                        <div class="menu-lang-card accordion py-1 my-1" v-for="(language, index) in languages" :key="index">
                            <div
                                class="nimmu-default-card-header pl-2 d-flex justify-content-between align-content-center"
                                data-toggle="collapse" :data-target="`#translation-`+language.code"
                                aria-expanded="false" :aria-controls="`translation-`+language.code">
                                <div class="nimmu-header-left">
                                    <h5>Translation (@{{ language.code }}) &nbsp;<i class="fas fa-angle-down"></i></h5>
                                </div>
                            </div>
                            <div class="nimmu-default-card-body mt-1 collapse" :id="`translation-`+language.code">
                                <div class="col-lg-12">
                                    <div class="form-group">
                                        <input type="text" :name="`lang[`+ language.code +`][text]`" placeholder="text"
                                               {{--                                               value="{{ (is_array($translations) && isset($translations[$language->code]) && is_array($translations[$language->code]))?$translations[$language->code]['text']:'' }}"--}}
                                               v-model="temp.translation[language.code]['text']"
                                               class="form-control">
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-default pull-left"
                                data-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary"
                                @click.prevent="closeEdit">update</button>
                    </div>
                </div>
                <!-- /.modal-content -->
            </div>
            <!-- /.modal-dialog -->
        </div>
    </div> <!-- container -->
@endsection

@section('js_libs')
    <script src="{{ asset('assets/js/vue.js') }}"></script>
    <script src="{{ asset('assets/js/Sortable.min.js') }}"></script>
    <script src="{{ asset('assets/js/vuedraggable.umd.min.js') }}"></script>
    <script src="{{ asset('assets/js/menu-item.js') }}"></script>
@endsection

@section('js')
    <script>
        window.app = new Vue({
            el: '#app',
            components: {
                draggable: window.vuedraggable,
                'nested-draggable': window.MenuItem
            },
            data: {
                loading: true,
                {{--items: @json(is_array($menu->data)?$menu->data:[]),--}}
                items: [],
                tempItems: {},
                temp: null,
                custom: {
                    text: null,
                    url: null,
                    target: '_blank'
                },
                languages : @json(is_array($languages)?$languages:[])
            },
            beforeMount() {
                this.tempItems['page'] = []
                @foreach($cards as $card)
                    this.tempItems['{{ $card['id'] }}'] = []
                @endforeach
                $.get('{{ route('staff.setting.menu.getItem', $menu->id) }}').done(response => {
                    var cb = (item) => {
                        if (!item.hasOwnProperty('children')) {
                            item.children = []
                        } else {
                            item.children && item.children.forEach(cb);
                        }
                    }
                    response.forEach(cb);
                    this.items = response
                }).always(() => {
                    this.loading = false
                })
                this.$on('edit', this.editItem)
                this.$on('delete', this.deleteItem)
            },
            methods: {
                editItem(item) {
                    this.temp = item
                    $('#edit-modal').modal('show')
                },
                closeEdit(item) {
                    $('#edit-modal').modal('hide')
                    this.temp = null
                },
                deleteItem(parent, index) {
                    if (parent) {
                        parent.children.splice(index, 1)
                    } else {
                        this.items.splice(index, 1)
                    }
                },
                addItems(cardSlug) {
                    if (this.tempItems[cardSlug].length) {
                        var items = this.tempItems[cardSlug].map(it => {
                            return {
                                id: Math.floor(Math.random() * Math.floor(Math.random() * Date.now())),
                                text: it.text,
                                url: it.url,
                                target: it.hasOwnProperty('target') ? it.target : '_blank',
                                type: 'auto',
                                translation: this.langList,
                                children: []
                            }
                        })
                        this.items.push(...items)
                    }
                },
                addCustom() {
                    var cus = {
                        id: Math.floor(Math.random() * Math.floor(Math.random() * Date.now())),
                        text: this.custom.text,
                        url: this.custom.url,
                        target: this.custom.hasOwnProperty('target') ? this.custom.target : '_blank',
                        type: 'custom',
                        translation: this.langList,
                        children: []
                    }
                    this.items.push(cus)
                },
                saveMenu() {
                    this.loading = true
                    $.post('{{ route('staff.setting.menu.itemupdate', $menu->id) }}', {
                        _token: @json(csrf_token()),
                        _method: 'PUT',
                        data: this.items
                    }).done(res => {
                        console.log(res)
                    }).fail(err => {
                        alert('Unable to update menu')
                    }).always(() => {
                        this.loading = false
                    })
                }
            },
            computed: {
                langList: function () {
                    let transItems = {};
                    this.languages.forEach((lang, index) => {
                        transItems[lang.code]={};
                        transItems[lang.code]['text']='';
                    });
                    return transItems;
                }
            }
        })
    </script>
@endsection
