@extends('staff.layouts.master')

@section('title', __('New Manual Payment Method'))

@section('css_libs')
    <link href="https://cdn.jsdelivr.net/gh/gitbrent/bootstrap4-toggle@3.6.1/css/bootstrap4-toggle.min.css" rel="stylesheet">
    <link href="{{ asset('assets/libs/select2/css/select2.min.css') }}" rel="stylesheet" type="text/css"/>
@endsection

@section('css')
    <style>
        [v-cloak] {
            display: none;
        }

        .toggle.btn {
            width: 100% !important;
        }
    </style>
@endsection

@section('content')
    <!-- Start Content-->
    <div class="container-fluid" id="app">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a>
                            </li>
                            <li class="breadcrumb-item">@lang('Setting')</li>
                            <li class="breadcrumb-item"><a
                                    href="{{ route('staff.setting.payment-method.index') }}">@lang('Payment Method')</a>
                            </li>
                            <li class="breadcrumb-item active">@lang('Edit')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('New Manual Payment Method')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <form action="{{ route('staff.setting.payment-method.store') }}" method="post">
            @csrf
            @include('layouts.partials.flash-alert')
            <div class="row">
                <div class="col-md-12">
                    <div class="card-box">
                        <h3 class="text-uppercase bg-light p-2 mt-0 mb-3">@lang('Manual Payment Method Details')</h3>

                        <div class="nimmu-default-card-body" v-cloak>
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="name">@lang('Name')</label>
                                        <input id="name" type="text"
                                               class="form-control @error('name') is-invalid @enderror" name="name"
                                               value="{{ old('name') }}" required>
                                        @error('name')
                                        <div class="invalid-feedback">
                                            {{ $message }}
                                        </div>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="status">@lang('Status')</label>
                                        <input id="status" name="status" type="checkbox"
                                               {{ old('status')?'checked':'' }} data-toggle="toggle"
                                               data-on="Enabled" data-off="Disabled" data-onstyle="success"
                                               data-offstyle="danger">
                                        @error('status')
                                        <div class="invalid-feedback">
                                            {{ $message }}
                                        </div>
                                        @enderror
                                    </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="min">@lang('Minimum amount (-1 for not limit)')</label>
                                        <div class="input-group">
                                            <input id="min" type="number" step="0.01"
                                                   class="form-control @error('min') is-invalid @enderror"
                                                   name="min" value="{{ old('min') }}">
                                            <div class="input-group-append">
                                                <span class="input-group-text">{{ $currency->code }}</span>
                                            </div>
                                        </div>
                                        @error('min')
                                        <div class="invalid-feedback">
                                            {{ $message }}
                                        </div>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="max">@lang('Maximum amount (-1 for not limit)')</label>
                                        <div class="input-group">
                                            <input id="max" type="number" step="0.01"
                                                   class="form-control @error('max') is-invalid @enderror"
                                                   name="max" value="{{ old('max') }}">
                                            <div class="input-group-append">
                                                <span class="input-group-text">{{ $currency->code }}</span>
                                            </div>
                                        </div>
                                        @error('max')
                                        <div class="invalid-feedback">
                                            {{ $message }}
                                        </div>
                                        @enderror
                                    </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="percent_charge">@lang('Percent Charge')</label>
                                        <div class="input-group">
                                            <input id="percent_charge" type="number" step="0.01"
                                                   class="form-control @error('percent_charge') is-invalid @enderror"
                                                   name="percent_charge" value="{{ old('percent_charge') }}">
                                            <div class="input-group-append">
                                                <span class="input-group-text">%</span>
                                            </div>
                                        </div>
                                        @error('percent_charge')
                                        <div class="invalid-feedback">
                                            {{ $message }}
                                        </div>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="fixed_charge">@lang('Fixed Charge')</label>
                                        <div class="input-group">
                                            <input id="fixed_charge" type="number" step="0.01"
                                                   class="form-control @error('fixed_charge') is-invalid @enderror"
                                                   name="fixed_charge" value="{{ old('fixed_charge') }}">
                                            <div class="input-group-append">
                                                <span class="input-group-text">{{ $currency->code }}</span>
                                            </div>
                                        </div>
                                        @error('fixed_charge')
                                        <div class="invalid-feedback">
                                            {{ $message }}
                                        </div>
                                        @enderror
                                    </div>
                                </div>
                            </div>

                            <div class="form-group">
                                <label for="description">@lang('Description')</label>
                                <textarea name="description" id="description"
                                          class="form-control editor @error('description') is-inavlid @enderror">{!! clean(old('description')) !!}</textarea>
                                @error('description')
                                <div class="inavlid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="nimmu-default-card mt-5" v-for="(field, index) in fields" :key="index" v-cloak>
                            <div class="nimmu-default-card-header d-flex justify-content-between align-items-center">
                                <h4>@lang('Field') - @{{ index+1 }} (@{{ field.title }})</h4>
                                <button class="btn btn-danger btn-sm nimmu-btn nimmu-btn-danger" @click.prevent="removeField(index)"><i
                                        class="fa fa-times"></i> @lang('Remove')</button>
                            </div>
                            <div class="nimmu-default-card-body">
                                <div class="row justify-content-between align-items-center">
                                    <div class="col-md">
                                        <div class="form-group">
                                            <label :for="'title-' + index">@lang('Title') <span
                                                    class="text-danger">*</span></label>
                                            <input :id="'title-' + index" type="text" v-model="field.title"
                                                   :name="'fields['+index+'][title]'"
                                                   class="form-control" required>
                                        </div>
                                    </div>
                                    <div class="col-md">
                                        <div class="form-group">
                                            <label :for="'input_type-' + index">@lang('Input Type') <span
                                                    class="text-danger">*</span></label>
                                            <select :id="'input_type-' + index" v-model="field.input_type"
                                                    :name="'fields['+index+'][input_type]'"
                                                    class="form-control" required>
                                                <option value="text">Text</option>
                                                <option value="file">File Input</option>
                                                <option value="textarea">Textarea</option>
                                                <option value="select">Select</option>
                                                <option value="multiple">Multiple Select</option>
                                                <option value="radio">Radio</option>
                                                <option value="checkbox">Checkbox</option>
                                            </select>
                                        </div>
                                    </div>
                                    <div class="col-md"
                                         v-if="field.input_type == 'text' || field.input_type == 'textarea'">
                                        <div class="form-group">
                                            <label :for="'placeholder-' + index">@lang('Placeholder')</label>
                                            <input :id="'placeholder-' + index" type="text" v-model="field.placeholder"
                                                   :name="'fields['+index+'][placeholder]'"
                                                   class="form-control">
                                        </div>
                                    </div>
                                    <div class="col-md">
                                        <div class="form-group">
                                            <label :for="'sort-' + index">@lang('Sort')</label>
                                            <input :id="'sort-' + index" type="number" min="0" step="1" v-model="field.sort"
                                                   :name="'fields['+index+'][sort]'"
                                                   class="form-control">
                                        </div>
                                    </div>
                                    <div class="col-md">
                                        <div class="form-group">
                                            <label>@lang('Is Required?') <span class="text-danger">*</span></label>
                                            <br>
                                            <div class="radio form-check-inline mr-4">
                                                <input type="radio" :id="'is-required-yes-' + index" value="1"
                                                       :name="'fields['+index+'][is_required]'"
                                                       v-model="field.is_required">
                                                <label :for="'is-required-yes-' + index"> @lang('YES') </label>
                                            </div>
                                            <div class="radio form-check-inline">
                                                <input type="radio" id="'is-required-no-' + index" value="0"
                                                       :name="'fields['+index+'][is_required]'"
                                                       v-model="field.is_required">
                                                <label :for="'is-required-no-' + index"> @lang('NO') </label>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md">
                                        <div class="form-group">
                                            <button v-if="field.input_type != 'text' && field.input_type != 'file' && field.input_type != 'textarea'"
                                                    class="btn btn-success mt-3" @click.prevent="addOption(index)"><i
                                                    class="fa fa-plus"></i> @lang('Add Option')</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="card-footer"
                                 v-if="field.input_type != 'text' && field.input_type != 'file' && field.input_type != 'textarea' && field.options.length">
                                <div class="row justify-content-between align-items-center"
                                     v-for="(option, index2) in field.options" :key="index2" v-cloak>
                                    <div class="col-md">
                                        <div class="form-group">
                                            <label :for="'field-' + index + '-title-' + index2">@lang('Title')</label>
                                            <input :id="'field-' + index + '-title-' + index2" type="text"
                                                   v-model="field.options[index2].title"
                                                   :name="'fields['+index+'][options]['+index2+'][title]'"
                                                   class="form-control">
                                        </div>
                                    </div>
                                    <div class="col-md">
                                        <div class="form-group">
                                            <label :for="'field-' + index + '-sort-' + index2">@lang('Sort')</label>
                                            <input :id="'field-' + index + '-sort-' + index2" type="number" step="1" min="0"
                                                   v-model="field.options[index2].sort"
                                                   :name="'fields['+index+'][options]['+index2+'][sort]'"
                                                   class="form-control">
                                        </div>
                                    </div>
                                    <div class="col-md">
                                        <div class="form-group">
                                            <button class="btn btn-danger mt-3"
                                                    @click.prevent="removeOption(index, index2)"><i
                                                    class="fa fa-times"></i> @lang('Remove')</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="form-group my-3 text-md-right text-center">
                            <button class="btn btn-lg btn-outline-primary nimmu-btn nimmu-btn-outline-primary"
                                    @click.prevent="addField">
                                <i class="fa fa-plus"></i> @lang('Add Field')
                            </button>
                        </div>

                        <div class="form-group text-center mb-3">
                            <button type="submit"
                                    class="btn w-sm btn-success waves-effect waves-light">@lang('Add Payment Method')</button>
                            <a href="{{ route('staff.setting.payment-method.index') }}"
                               onclick="return confirm('{{ __('Are you sure to leave this page?') }}')" type="button"
                               class="btn w-sm btn-light waves-effect">@lang('Cancel')</a>
                        </div>
                    </div> <!-- end card-box -->
                </div> <!-- end col -->
            </div>
            <!-- end row -->
        </form>


    </div> <!-- container -->
@endsection

@section('js_libs')
    <script src="https://cdn.jsdelivr.net/gh/gitbrent/bootstrap4-toggle@3.6.1/js/bootstrap4-toggle.min.js"></script>
{{--    <script src="{{ asset('assets/staff/js/select2.full.min.js') }}"></script>--}}
    <script src="{{ asset('assets/js/vue.js') }}"></script>
    <script src="{{ asset('assets/js/select2.vue.js') }}"></script>
    <script src="{{ asset('assets/libs/tinymce/tinymce.min.js') }}"></script>
@endsection

@section('js')
    <script>
        var editor_config = {
            path_absolute: "{{ url('/') }}/",
            selector: ".editor",
            convert_urls: false,
            plugins: [
                "advlist autolink lists link image charmap print preview hr anchor pagebreak",
                "searchreplace wordcount visualblocks visualchars code fullscreen",
                "insertdatetime media nonbreaking save table contextmenu directionality",
                "emoticons template paste textcolor colorpicker textpattern"
            ],
            toolbar: "insertfile undo redo | styleselect | bold italic | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent | link image media",
            relative_urls: false,
            file_browser_callback: function (field_name, url, type, win) {
                var x = window.innerWidth || document.documentElement.clientWidth || document.getElementsByTagName('body')[0].clientWidth;
                var y = window.innerHeight || document.documentElement.clientHeight || document.getElementsByTagName('body')[0].clientHeight;

                var cmsURL = editor_config.path_absolute + 'staff/media?field_name=' + field_name;
                if (type == 'image') {
                    cmsURL = cmsURL + "&type=Images";
                    var title = 'Select Images'
                } else {
                    cmsURL = cmsURL + "&type=Files";
                    var title = 'Select FIles'
                }

                tinyMCE.activeEditor.windowManager.open({
                    file: cmsURL,
                    title: title,
                    width: x * 0.8,
                    height: y * 0.8,
                    resizable: "yes",
                    close_previous: "no"
                });
            }
        };

        tinymce.init(editor_config);
    </script>
    <script>
        // $.fn.select2.defaults.set("theme", "bootstrap");
        window.app = new Vue({
            el: '#app',
            data: {
                fields: @json(old('fields')??[])
            },
            beforeMount() {
                this.fields = this.fields.map(field => {
                    if (!field.hasOwnProperty('options')) {
                        field.options = []
                    }
                    return field;
                })
            },
            methods: {
                addField() {
                    this.fields.push({
                        title: null,
                        input_type: 'text',
                        placeholder: null,
                        options: [],
                        sort: 0,
                        is_required: 0
                    })
                },
                removeField(index) {
                    this.fields.splice(index, 1)
                },
                addOption(index) {
                    this.fields[index].options.push({
                        title: null,
                        sort: 0
                    })
                },
                removeOption(index, index2) {
                    this.fields[index].options.splice(index2, 1)
                }
            }
        })
    </script>
@endsection
