@extends('staff.layouts.master')

@section('title', __('Payment Methods'))

@section('css_libs')
    <link href="{{ asset('assets/libs/datatables.net-bs4/css/dataTables.bootstrap4.min.css') }}" rel="stylesheet"
          type="text/css"/>
    <link href="{{ asset('assets/libs/datatables.net-responsive-bs4/css/responsive.bootstrap4.min.css') }}"
          rel="stylesheet" type="text/css"/>
    <link href="{{ asset('assets/libs/datatables.net-buttons-bs4/css/buttons.bootstrap4.min.css') }}" rel="stylesheet"
          type="text/css"/>
@endsection

@section('content')
    <!-- Start Content-->
    <div class="container-fluid">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a></li>
                            <li class="breadcrumb-item">@lang('Setting')</li>
                            <li class="breadcrumb-item">@lang('Payment Methods')</li>
                            <li class="breadcrumb-item active">@lang('All')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('Payment Methods')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <div class="row justify-content-center justify-content-md-end">
            <div class="col-md-2 col-sm-6">
                <a href="{{ route('staff.setting.payment-method.create') }}" class="btn btn-block btn-primary">Add Manual Method</a>
            </div>
        </div>

        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">
                        @include('layouts.partials.flash-alert')
                        <table id="data-table" class="table table-bordered dt-responsive nowrap w-100">
                            <thead>
                            <tr>
                                <th>@lang('ID')</th>
                                <th>@lang('Name')</th>
                                <th>@lang('Type')</th>
                                <th>@lang('Minimum')</th>
                                <th>@lang('Maximum')</th>
                                <th>@lang('Charge')</th>
                                <th>@lang('Status')</th>
                                <th>@lang('Actions')</th>
                            </tr>
                            </thead>
                        </table>

                    </div> <!-- end card body-->
                </div> <!-- end card -->
            </div><!-- end col-->
        </div>
        <!-- end row-->

        <div class="modal fade" id="edit-modal">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h4 class="modal-title">@lang('Edit Payment Method')</h4>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">×</span></button>
                    </div>
                    <form method="post">
                        @csrf
                        @method('PUT')
                        <div class="modal-body">
                            <div class="form-group">
                                <label class="control-label">@lang('Name')</label>
                                <input type="text" name="name" id="name" value="{{ old('name') }}"
                                       class="form-control" required>
                            </div>
                            <div class="form-group">
                                <label class="control-label">@lang('Description')</label>
                                <textarea name="description" id="description" class="form-control"
                                          required>{{ old('description') }}</textarea>
                            </div>
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="control-label">@lang('Minimum')</label>
                                        <input type="number" min="-1" step="0.01" name="min" id="min"
                                               value="{{ old('min')??-1 }}"
                                               class="form-control" required>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="control-label">@lang('Maximum')</label>
                                        <input type="number" min="-1" step="0.01" name="max" id="max"
                                               value="{{ old('max')??-1 }}"
                                               class="form-control" required>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="control-label">@lang('Percent Charge')</label>
                                        <div class="input-group">
                                            <input type="number" min="0" step="0.01" name="percent_charge"
                                                   id="percent_charge"
                                                   value="{{ old('percent_charge')??0 }}"
                                                   class="form-control" required>
                                            <div class="input-group-append">
                                                <span class="input-group-text">%</span>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="control-label">@lang('Fixed Charge')</label>
                                        <div class="input-group">
                                            <input type="number" min="0" step="0.01" name="fixed_charge"
                                                   id="fixed_charge"
                                                   value="{{ old('fixed_charge')??0 }}"
                                                   class="form-control" required>
                                            <div class="input-group-append">
                                                <span class="input-group-text">{{ $currency->code }}</span>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="form-group form-group-cred1">
                                <label class="control-label" id="control-label-cred1"></label>
                                <input type="text" name="cred1" id="cred1" value="{{ old('cred1') }}"
                                       class="form-control">
                            </div>
                            <div class="form-group form-group-cred2">
                                <label class="control-label" id="control-label-cred2"></label>
                                <input type="text" name="cred2" id="cred2" value="{{ old('cred2') }}"
                                       class="form-control">
                            </div>
                            <div class="custom-control custom-checkbox mr-sm-2">
                                <input type="checkbox" class="custom-control-input"
                                       id="status" name="status" value="1">
                                <label class="custom-control-label"
                                       for="status">@lang('Status (Enabled/Disabled)')</label>
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-default pull-left"
                                    data-dismiss="modal">@lang('Close')
                            </button>
                            <button type="submit" class="btn btn-primary">@lang('Update')</button>
                        </div>
                    </form>
                </div>
                <!-- /.modal-content -->
            </div>
            <!-- /.modal-dialog -->
        </div>

    </div> <!-- container -->
@endsection

@section('js_libs')
    <script src="{{ asset('assets/libs/datatables.net/js/jquery.dataTables.min.js') }}"></script>
    <script src="{{ asset('assets/libs/datatables.net-bs4/js/dataTables.bootstrap4.min.js') }}"></script>
    <script src="{{ asset('assets/libs/datatables.net-responsive/js/dataTables.responsive.min.js') }}"></script>
    <script src="{{ asset('assets/libs/datatables.net-responsive-bs4/js/responsive.bootstrap4.min.js') }}"></script>
@endsection

@section('js')
    <script>
        (function ($) {
            $(document).ready(function () {
                $('#data-table').DataTable({
                    responsive: true,
                    processing: true,
                    serverSide: true,
                    ajax: '{{ route('staff.setting.payment-method.index') }}',
                    columns: [
                        {data: 'id', name: 'id'},
                        {data: 'name', name: 'name'},
                        {data: 'type', name: 'type'},
                        {data: 'min', name: 'min', orderable: false, searchable: false},
                        {data: 'max', name: 'max', orderable: false, searchable: false},
                        {data: 'charge', name: 'charge', orderable: false, searchable: false},
                        {data: 'status', name: 'status'},
                        {data: 'actions', name: 'actions', orderable: false, searchable: false}
                    ]
                });
            })

            $(document).on('click', '.btn-edit', function (e) {
                e.preventDefault();

                var datas = [];
                [].forEach.call(this.attributes, function (attr) {
                    if (/^data-/.test(attr.name)) {
                        var camelCaseName = attr.name.substr(5).replace(/-(.)/g, function ($0, $1) {
                            return $1.toUpperCase();
                        });
                        datas.push({
                            name: camelCaseName,
                            value: attr.value
                        });
                    }
                });
                datas.forEach(function (data) {
                    if (data.name == 'id') {
                        var url = '{{ url('staff/setting/payment-method') }}/' + data.value;
                        $('.form-group-cred1').show();
                        $('.form-group-cred2').show();
                        switch (parseInt(data.value)) {
                            case 1:
                                // It is paypal
                                $('.form-group-cred2').hide();
                                $('#control-label-cred1').text('Paypal Email');
                                break;
                            case 2:
                                $('#control-label-cred1').text('Member ID');
                                $('#control-label-cred2').text('Passphrase');
                                break;
                            case 3:
                                $('#control-label-cred1').text('Publishable Key');
                                $('#control-label-cred2').text('Secret Key');
                                break;
                            case 4:
                                $('#control-label-cred1').text('Email');
                                $('#control-label-cred2').text('Secret Key');
                                break;
                            case 5:
                                $('.form-group-cred1').hide();
                                $('.form-group-cred2').hide();
                                break;
                            case 6:
                                $('#control-label-cred1').text('Key ID');
                                $('#control-label-cred2').text('Key Secret');
                                break;
                            case 7:
                                $('.form-group-cred1').hide();
                                $('.form-group-cred2').hide();
                                break;
                        }
                        $('#edit-modal form').prop('action', url);
                    } else if (data.name == 'status') {
                        if (parseInt(data.value) == 1) {
                            $('#' + data.name).prop('checked', true)
                        } else {
                            $('#' + data.name).prop('checked', false)
                        }
                    } else {
                        $('#' + data.name).val(data.value);
                    }
                })
                $('#edit-modal').modal('show');
            })
            $(document).on('click', '.btn-delete', function (e) {
                e.preventDefault();
                var id = $(this).data('id');
                var url = '{{ url('staff/setting/language') }}/' + id
                $('#delete-modal form').prop('action', url);
                $('#delete-modal').modal();
            })
        })(jQuery)
    </script>
@endsection
