@extends('staff.layouts.master')

@section('title', __('New Payment Gateway'))

@section('css_libs')
    <link href="{{ asset('assets/libs/select2/css/select2.min.css') }}" rel="stylesheet" type="text/css"/>
@endsection

@section('content')
    <!-- Start Content-->
    <div class="container-fluid">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a>
                            </li>
                            <li class="breadcrumb-item">@lang('Setting')</li>
                            <li class="breadcrumb-item"><a href="{{ route('staff.setting.payment-gateway.index') }}">@lang('Payment Gateway')</a></li>
                            <li class="breadcrumb-item active">@lang('Add New')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('New Payment Gateway')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <form action="{{ route('staff.setting.payment-gateway.store') }}" method="post">
            @csrf
            @include('layouts.partials.flash-alert')
            @if($errors->any())
                @foreach($errors->all() as $error)
                    <div class="alert alert-danger alert-dismissable fade show" role="alert">
                        {{ $error }}
                        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                @endforeach
            @endif
            <div class="row" id="app">
                <div class="col-lg-6">
                    <div class="card-box">
                        <h3 class="text-uppercase bg-light p-2 mt-0 mb-3">@lang('Details')</h3>

                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-group">
                                    <label for="avatar-preview" class="d-block">@lang('Image')</label>
                                    <img class="img-thumbnail d-block" style="width: 150px;height: 150px;"
                                         src="https://picsum.photos/150" id="avatar-preview">
                                    <input type="hidden" name="image" value="https://picsum.photos/150" id="avatar">
                                    <button class="btn btn-outline-info nimmu-btn nimmu-btn-outline-info btn-select"
                                            style="width: 150px;">Change Image
                                    </button>
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-group mb-3">
                                    <label for="name">@lang('Name') <span class="badge badge-info">unique</span>  <span class="text-danger">*</span></label>
                                    <input type="text" placeholder="Gateway Name"
                                           class="form-control @error('name') is-invalid @enderror" id="name"
                                           name="name"
                                           value="{{ old('name') }}" required autofocus>
                                    @error('name')
                                        <div class="invalid-feedback" role="alert">
                                            {{ $message }}
                                        </div>
                                    @enderror
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-group mb-3">
                                    <label for="payment_method">@lang('Payment Method') <span class="text-danger">*</span></label>
                                    <input type="hidden" name="payment_method" v-model="selectedMethod.calssName" required>
                                    <select class="form-control" id="payment_method" required v-model="selectedMethod">
                                        <option disabled value="">Please select one</option>
                                        <option :value="paymentMethod" v-for="(paymentMethod, index) in paymentMethods" :key="index">@{{ paymentMethod.name }}</option>
                                    </select>
                                    @error('payment_method')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-group mb-3">
                                    <label for="supported_currency">@lang('Supported Currency') <span
                                            class="text-danger">*</span></label>
                                    <select class="form-control" id="supported_currency" name="supported_currency" v-model="supportedCurrency" required>
                                        <option disabled value="">Please select one</option>
                                        <option :value="supportedCurrency" v-for="(supportedCurrency, index) in selectedMethod.supported_currencies" :key="index">@{{ supportedCurrency }}</option>
                                    </select>
                                    @error('supported_currency')
                                        <div class="invalid-feedback" role="alert">
                                            {{ $message }}
                                        </div>
                                    @enderror
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="min">@lang('Minimum amount (-1 for not limit)')</label>
                                    <div class="input-group">
                                        <input id="min" type="number" step="0.01"
                                               class="form-control @error('min') is-invalid @enderror"
                                               name="min" value="{{ old('min') ?? -1 }}">
                                        <div class="input-group-append">
                                            <span class="input-group-text">@{{ supportedCurrency }}</span>
                                        </div>
                                    </div>
                                    @error('min')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="max">@lang('Maximum amount (-1 for not limit)')</label>
                                    <div class="input-group">
                                        <input id="max" type="number" step="0.01"
                                               class="form-control @error('max') is-invalid @enderror"
                                               name="max" value="{{ old('max') ?? -1 }}">
                                        <div class="input-group-append">
                                            <span class="input-group-text">@{{ supportedCurrency }}</span>
                                        </div>
                                    </div>
                                    @error('max')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="percent_charge">@lang('Percent Charge')</label>
                                    <div class="input-group">
                                        <input id="percent_charge" type="number" step="0.01"
                                               class="form-control @error('percent_charge') is-invalid @enderror"
                                               name="percent_charge" value="{{ old('percent_charge') }}">
                                        <div class="input-group-append">
                                            <span class="input-group-text">%</span>
                                        </div>
                                    </div>
                                    @error('percent_charge')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="fixed_charge">@lang('Fixed Charge')</label>
                                    <div class="input-group">
                                        <input id="fixed_charge" type="number" step="0.01"
                                               class="form-control @error('fixed_charge') is-invalid @enderror"
                                               name="fixed_charge" value="{{ old('fixed_charge') }}">
                                        <div class="input-group-append">
                                            <span class="input-group-text">@{{ supportedCurrency }}</span>
                                        </div>
                                    </div>
                                    @error('fixed_charge')
                                    <div class="invalid-feedback">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label>@lang('Status') <span class="text-danger">*</span></label>
                                    <br>
                                    <div class="radio form-check-inline mr-4">
                                        <input type="radio" id="status-enabled" value="1"
                                               name="status" {{ old('status') == 1?'checked':'' }}>
                                        <label for="status-enabled"> @lang('Enabled') </label>
                                    </div>
                                    <div class="radio form-check-inline mr-4">
                                        <input type="radio" id="status-disabled" value="0"
                                               name="status" {{ old('status') == 0?'checked':'' }}>
                                        <label for="status-disabled"> @lang('Disabled') </label>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="form-group text-center mb-3">
                            <button type="submit"
                                    class="btn w-sm btn-success waves-effect waves-light">@lang('Save Payment Gateway')</button>
                            <a href="{{ route('staff.setting.currency.index') }}"
                               onclick="return confirm('{{ __('Are you sure to leave this page?') }}')" type="button"
                               class="btn w-sm btn-light waves-effect">@lang('Cancel')</a>
                        </div>
                    </div> <!-- end card-box -->
                </div>
                <div class="col-lg-6">
                    <div class="card-box" v-if="selectedMethod.credentials.length>0">
                        <h3 class="text-uppercase bg-light p-2 mt-0 mb-3">@lang('Credentials')</h3>

                        <div class="row">
                            <div class="col-md-12" v-for="(credential, index) in selectedMethod.credentials" :key="index">
                                <div class="form-group mb-3">
                                    <label>@{{ credential.replaceAll('_',' ') }}<span class="text-danger">*</span></label>
                                    <input type="text" class="form-control" :name="`credentials[`+credential+`]`" required>
                                </div>
                            </div>
                        </div>
                    </div> <!-- end card-box -->
                </div>
            </div>
            <!-- end row -->
        </form>


    </div> <!-- container -->
@endsection

@section('js_libs')
    <script src="{{ asset('assets/libs/select2/js/select2.min.js') }}"></script>
    <script src="{{ asset('assets/js/vue.js') }}"></script>
@endsection

@section('js')
    <script>
        (function ($) {
            $(document).ready(function () {
                $('.select2').select2();
            })
        })(jQuery)
    </script>
    <script>
        $(document).on('click', '.btn-select', function (e) {
            e.preventDefault()
            openMediaManager(items => {
                if (items[0] && items[0].hasOwnProperty('url')) {
                    $('#avatar').val(items[0].url)
                }
                if (items[0] && items[0].hasOwnProperty('thumb_url')) {
                    $('#avatar-preview').attr('src', items[0].thumb_url)
                }
            }, 'image', 'Select Avatar')
        })
    </script>
    <script>
        window.app = new Vue({
            el: '#app',
            data: {
                paymentMethods: @json($paymentMethods??[]),
                selectedMethod: {name:'',calssName:'',supported_currencies:[],credentials:[]},
                supportedCurrency:''
            },
            methods: {
                selectGateway(gatewayIndex) {

                }
            }
        })
    </script>
@endsection
