@extends('staff.layouts.master')

@section('page_title', 'Service Settings')

@section('content')
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a></li>
                            <li class="breadcrumb-item">@lang('Setting')</li>
                            <li class="breadcrumb-item">@lang('Service Settings')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('Service Settings')</h4>
                </div>
            </div>
        </div>
        <div class="row" id="app">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">
                        @include('layouts.partials.flash-alert')
                        @if($errors->any())
                            @foreach($errors->all() as $error)
                                <div class="alert alert-danger alert-dismissable fade show" role="alert">
                                    {{ $error }}
                                    <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                        <span aria-hidden="true">&times;</span>
                                    </button>
                                </div>
                            @endforeach
                        @endif
                        <form action="{{ route('staff.setting.service.update') }}" method="post">
                            @csrf
                            @method('PUT')
                            <div class="container-fluid nimmu-buttons">
                                <div class="nimmu-default-card nimmu-buttons">
                                    <div class="nimmu-default-card-body">
                                        <div class="form-group">
                                            <label for="currencylayer_access_key">Currencylayer Access Key <a
                                                    href="https://currencylayer.com/" target="_blank">Details</a></label>
                                            <input type="text" name="currencylayer_access_key" id="currencylayer_access_key"
                                                   class="form-control"
                                                   value="{{ get_option('currencylayer_access_key', config('services.currencylayer.access_key')) }}"
                                                   required>
                                        </div>
                                        @if(config('iwallet.sms_via') == 'twilio')
                                            <div class="row">
                                                <div class="col-md-4">
                                                    <div class="form-group">
                                                        <label for="twilio_auth_token">Twilio Auth Token</label>
                                                        <input type="text" name="twilio_auth_token" id="twilio_auth_token"
                                                               class="form-control"
                                                               value="{{ get_option('twilio_auth_token', config('twilio-notification-channel.auth_token')) }}"
                                                               required>
                                                    </div>
                                                </div>
                                                <div class="col-md-4">
                                                    <div class="form-group">
                                                        <label for="twilio_account_sid">Twilio Account SID</label>
                                                        <input type="text" name="twilio_account_sid" id="twilio_account_sid"
                                                               class="form-control"
                                                               value="{{ get_option('twilio_account_sid', config('twilio-notification-channel.account_sid')) }}"
                                                               required>
                                                    </div>
                                                </div>
                                                <div class="col-md-4">
                                                    <div class="form-group">
                                                        <label for="twilio_from">Twilio SMS From</label>
                                                        <input type="text" name="twilio_from" id="twilio_from" class="form-control"
                                                               value="{{ get_option('twilio_from', config('twilio-notification-channel.from')) }}"
                                                               required>
                                                    </div>
                                                </div>
                                            </div>
                                        @else
                                            <div class="form-group">
                                                <label for="sms_api">SMS API (Get Request)</label>
                                                <ul class="list-group">
                                                    <li class="list-group-item"><code>[to]</code> - Destination Phone Number</li>
                                                    <li class="list-group-item"><code>[message]</code> - SMS Message</li>
                                                </ul>
                                                <input type="text" name="sms_api" id="sms_api" class="form-control"
                                                       value="{{ get_option('sms_api', config('services.itech.sms.endpoint')) }}"
                                                       required>
                                            </div>
                                        @endif

                                        <div class="form-group">
                                            <div class="form-group">
                                                <label for="firebase_credentials">firebase_credentials.json contents <span
                                                        class="text-info">(FCM Service Credentials exported from firebase <a
                                                            href="https://firebase.google.com/docs/admin/setup#initialize-sdk"
                                                            target="_blank">Details</a>)</span></label>
                                                <textarea id="firebase_credentials" class="form-control" name="firebase_credentials"
                                                          required>@php echo $firebase_credentials; @endphp</textarea>
                                            </div>
                                        </div>
                                        <div class="form-group">
                                            <button class="btn btn-primary btn-block btn-lg nimmu-btn nimmu-btn-primary"
                                                    type="submit">Update Settings
                                            </button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </form>
                    </div> <!-- end card body-->
                </div> <!-- end card -->
            </div><!-- end col-->
        </div>
    </div>
@endsection
