@extends('staff.layouts.master')

@section('title', __('Edit') .ucfirst($notificationTemplate->channel) . __(' Templates'))

@section('css_libs')
    <link href="{{ asset('assets/libs/bootstrap4-toggle/bootstrap4-toggle.min.css') }}" rel="stylesheet">
    <link href="{{ asset('assets/libs/select2/css/select2.min.css') }}" rel="stylesheet" type="text/css"/>
@endsection

@section('content')
    <div class="container-fluid">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a></li>
                            <li class="breadcrumb-item">@lang('Setting')</li>
                            <li class="breadcrumb-item">{{ ucfirst($notificationTemplate->channel) }} @lang('Template')</li>
                            <li class="breadcrumb-item active">Edit</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('Edit Template')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <form action="{{ route('staff.setting.template.update', $notificationTemplate->id) }}" method="post" id="app">
            @csrf
            @method('PUT')
            @include('layouts.partials.flash-alert')
            <div class="row">
                <div class="col-lg-12">
                    <div class="card-box">
                        <div class="row">
                            <div class="col-md-12">
                                @if(is_array($notificationTemplate->params) && count($notificationTemplate->params))
                                    <div class="nimmu-default-card nimmu-buttons mb-3">
                                        <div
                                            class="nimmu-default-card-header nimmu-mb-30 d-flex justify-content-between align-content-center">
                                            <div class="nimmu-header-left">
                                                <h5>All Shortcodes For This Template</h5>
                                            </div>
                                        </div>
                                        <div class="nimmu-default-card-body">
                                            <ul class="list-group">
                                                @foreach($notificationTemplate->params as $k => $m)
                                                    <li class="list-group-item"><code>[{{ $k }}]</code> - {{ $m }}</li>
                                                @endforeach
                                            </ul>
                                        </div>
                                    </div>
                                @endif

                                <div class="nimmu-default-card nimmu-buttons">
                                    <div class="nimmu-default-card-body">
                                        <div class="form-group">
                                            <label for="auto_trigger" class="d-block">Auto Trigger</label>
                                            <input id="auto_trigger" name="auto_trigger" type="checkbox" value="1"
                                                   {{  ($notificationTemplate->auto_trigger == 1) ? 'checked':'' }} data-toggle="toggle"
                                                   data-on="Enabled" data-off="Disabled" data-onstyle="success"
                                                   data-offstyle="danger">
                                        </div>
                                    </div>
                                </div>

                                <div class="nimmu-default-card nimmu-buttons">
                                    <div class="nimmu-default-card-body">
                                        <div class="form-group">
                                            <label for="title">{{ $notificationTemplate->channel == 'email'?'Subject':'Title' }}</label>
                                            <input type="text" id="title" name="title" class="form-control"
                                                   placeholder="{{ config($notificationTemplate->channel . '.' . $notificationTemplate->name . '.title') }}" value="{{ $notificationTemplate->title }}">
                                        </div>
                                        <div class="form-group">
                                            <label for="content">Content</label>
                                            <textarea name="content" id="content" class="form-control" placeholder="{{ config($notificationTemplate->channel . '.' . $notificationTemplate->name . '.content') }}"><?php echo $notificationTemplate->content; ?></textarea>
                                        </div>

                                        <div class="form-group">
                                            <button class="btn btn-block btn-success nimmu-btn nimmu-btn-success" type="submit">
                                                UPDATE TEMPLATE
                                            </button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <!-- end row -->
        </form>
    </div>
@endsection

@section('js_libs')
    <script src="{{ asset('assets/libs/tinymce/tinymce.min.js') }}"></script>
    <script src="{{ asset('assets/libs/bootstrap4-toggle/bootstrap4-toggle.min.js') }}"></script>
@endsection

@section('js')
    @if($notificationTemplate->channel == 'email')
    <script>
        var editor_config = {
            path_absolute: "{{ url('/') }}/",
            selector: "#content",
            convert_urls: false,
            plugins: [
                "advlist autolink lists link image charmap print preview hr anchor pagebreak",
                "searchreplace wordcount visualblocks visualchars code fullscreen",
                "insertdatetime media nonbreaking save table contextmenu directionality",
                "emoticons template paste textcolor colorpicker textpattern",
                "fullpage"
            ],
            toolbar: "fullpage | insertfile undo redo | styleselect | bold italic | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent | link image media",
            relative_urls: false,
            file_browser_callback: function (field_name, url, type, win) {
                var x = window.innerWidth || document.documentElement.clientWidth || document.getElementsByTagName('body')[0].clientWidth;
                var y = window.innerHeight || document.documentElement.clientHeight || document.getElementsByTagName('body')[0].clientHeight;

                var cmsURL = editor_config.path_absolute + 'staff/media?field_name=' + field_name;
                if (type == 'image') {
                    cmsURL = cmsURL + "&type=Images";
                    var title = 'Select Images'
                } else {
                    cmsURL = cmsURL + "&type=Files";
                    var title = 'Select FIles'
                }

                tinyMCE.activeEditor.windowManager.open({
                    file: cmsURL,
                    title: title,
                    width: x * 0.8,
                    height: y * 0.8,
                    resizable: "yes",
                    close_previous: "no"
                });
            }
        };

        tinymce.init(editor_config);
    </script>
    @endif
@endsection
