@extends('staff.layouts.master')

@section('page_title', 'Update Manager')

@section('css')
    <style>
        [v-cloak] {
            display: none;
        }
    </style>
@endsection


@section('content')
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a></li>
                            <li class="breadcrumb-item">@lang('Setting')</li>
                            <li class="breadcrumb-item">@lang('Update Manager')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('Update Managers')</h4>
                </div>
            </div>
        </div>
        <div class="row" id="app">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">
                        @include('layouts.partials.flash-alert')
                        @if($errors->any())
                            @foreach($errors->all() as $error)
                                <div class="alert alert-danger alert-dismissable fade show" role="alert">
                                    {{ $error }}
                                    <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                        <span aria-hidden="true">&times;</span>
                                    </button>
                                </div>
                            @endforeach
                        @endif
                        <form action="{{ route('staff.setting.update.theme.setting') }}" method="post">
                            @csrf
                            @method('PUT')
                            <div class="container-fluid nimmu-buttons">
                                <div class="nimmu-default-card nimmu-buttons">
                                    <div class="jumbotron text-center" v-cloak>
                                        <template v-if="currentStep == 0">
                                            <h1 class="display-4">iWallet</h1>
                                            <p>{{ config('app.version') }}</p>
                                            <p class="lead" v-if="!isLoading && !responseText">Payment Gateway Management Admin Panel with Front End</p>
                                            <p class="lead" v-if="responseText">@{{ responseText }}</p>
                                            <hr class="my-4" v-if="!isLoading">
                                            <i v-if="isLoading" class="fa fa-spinner fa-3x fa-spin my-3" aria-hidden="true"></i>
                                            <p class="lead">
                                                <button @click.prevent="checkUpdate"
                                                        class="btn btn-primary btn-lg nimmu-btn nimmu-btn-primary" role="button"
                                                        :disabled="isLoading">@{{ isLoading?'Checking For Update':'Check Update' }}
                                                </button>
                                            </p>
                                        </template>
                                        <template v-else-if="currentStep == 1 && release">
                                            <h1 class="display-4">@{{ release.name }}</h1>
                                            <p>@{{ release.tag }}</p>
                                            <p class="lead" v-if="!isLoading && !responseText">@{{ release.instruction }}</p>
                                            <p class="lead" v-if="responseText">@{{ responseText }}</p>
                                            <hr class="my-4" v-if="!isLoading">
                                            <i v-if="isLoading" class="fa fa-spinner fa-3x fa-spin my-3" aria-hidden="true"></i>
                                            <p class="lead">
                                                <button @click.prevent="downloadRelease"
                                                        class="btn btn-primary btn-lg nimmu-btn nimmu-btn-primary" role="button"
                                                        :disabled="isLoading">@{{ isLoading?'Downloading Update':'Download Update' }}
                                                </button>
                                            </p>
                                        </template>
                                        <template v-else-if="currentStep == 2 && release">
                                            <h1 class="display-4">@{{ release.name }}</h1>
                                            <p>@{{ release.tag }}</p>
                                            <p class="lead" v-if="!isLoading && !responseText">@{{ release.instruction }}</p>
                                            <p class="lead">File Downloaded Successfully</p>
                                            <hr class="my-4" v-if="!isLoading">
                                            <i v-if="isLoading" class="fa fa-spinner fa-3x fa-spin my-3" aria-hidden="true"></i>
                                            <p class="lead">
                                                <button @click.prevent="makeBackup"
                                                        class="btn btn-primary btn-lg nimmu-btn nimmu-btn-primary" role="button"
                                                        :disabled="isLoading">@{{ isLoading?'Backing Up':'Make Backup' }}
                                                </button>
                                            </p>
                                        </template>
                                        <template v-else-if="currentStep == 3 && release">
                                            <h1 class="display-4">@{{ release.name }}</h1>
                                            <p>@{{ release.tag }}</p>
                                            <p class="lead" v-if="!isLoading && !responseText">@{{ release.instruction }}</p>
                                            <p class="lead">Backed Up Successfully</p>
                                            <hr class="my-4" v-if="!isLoading">
                                            <i v-if="isLoading" class="fa fa-spinner fa-3x fa-spin my-3" aria-hidden="true"></i>
                                            <p class="lead">
                                                <button @click.prevent="updateRelease"
                                                        class="btn btn-primary btn-lg nimmu-btn nimmu-btn-primary" role="button"
                                                        :disabled="isLoading">@{{ isLoading?'Updating':'Update' }}
                                                </button>
                                            </p>
                                        </template>
                                        <template v-else-if="currentStep == 4 && release">
                                            <h1 class="display-4">@{{ release.name }}</h1>
                                            <p>@{{ release.tag }}</p>
                                            <p class="lead" v-if="!isLoading && !responseText">@{{ release.instruction }}</p>
                                            <p class="lead" v-if="responseText">@{{ responseText }}</p>
                                            <hr class="my-4" v-if="!isLoading">
                                            <i v-if="isLoading" class="fa fa-spinner fa-3x fa-spin my-3" aria-hidden="true"></i>
                                            <p class="lead">
                                                <a href="{{ route('staff.dashboard') }}"
                                                   class="btn btn-success btn-lg nimmu-btn nimmu-btn-success"
                                                   :disabled="isLoading">Back To Home
                                                </a>
                                            </p>
                                        </template>
                                    </div>
                                </div>
                            </div>
                        </form>
                    </div> <!-- end card body-->
                </div> <!-- end card -->
            </div><!-- end col-->
        </div>
    </div>
@endsection

@section('js_libs')
    <script src="{{ asset('assets/js/vue.js') }}"></script>
@endsection

@section('js')
    <script>
        window.app = new Vue({
            el: '#app',
            data: {
                currentStep: @json($step??0),
                isLoading: false,
                responseText: null,
                release: @json($release??null)
            },
            methods: {
                checkUpdate() {
                    this.isLoading = true
                    $.get('{{ route('staff.setting.application.update.check') }}')
                        .done(response => {
                            if (response.success) {
                                if (typeof response.release == 'object') {
                                    this.release = response.release
                                    this.currentStep++;
                                }
                            } else {
                                if (response.message) {
                                    this.responseText = response.message
                                } else {
                                    this.responseText = 'Already up to date'
                                }
                                setTimeout(() => {
                                    this.responseText = null
                                }, 5000)
                            }
                        })
                        .fail(error => {
                            console.log(error)
                        })
                        .always(() => {
                            this.isLoading = false
                        })
                },
                downloadRelease() {
                    this.isLoading = true
                    $.get('{{ route('staff.setting.application.update.download') }}')
                        .done(response => {
                            // console.log(response)
                            if (response.success) {
                                this.currentStep++
                            } else {
                                if (response.message) {
                                    this.responseText = response.message
                                } else {
                                    this.responseText = 'Unable to download file'
                                }
                                setTimeout(() => {
                                    this.responseText = null
                                }, 5000)
                            }
                        })
                        .fail(error => {
                            console.log(error)
                        })
                        .always(() => {
                            this.isLoading = false
                        })
                },
                makeBackup() {
                    this.isLoading = true
                    $.get('{{ route('staff.setting.application.update.backup') }}')
                        .done(response => {
                            // console.log(response)
                            if (response.success) {
                                this.currentStep++
                            } else {
                                if (response.message) {
                                    this.responseText = response.message
                                } else {
                                    this.responseText = 'Unable to backup file'
                                }
                                setTimeout(() => {
                                    this.responseText = null
                                }, 5000)
                            }
                        })
                        .fail(error => {
                            console.log(error)
                        })
                        .always(() => {
                            this.isLoading = false
                        })
                },
                updateRelease() {
                    this.isLoading = true
                    $.get('{{ route('staff.setting.application.update.perform') }}')
                        .done(response => {
                            // console.log(response)
                            if (response.success) {
                                this.currentStep++
                                this.responseText = 'Updated Successfully'
                            } else {
                                if (response.message) {
                                    this.responseText = response.message
                                } else {
                                    this.responseText = 'Unable to update'
                                }
                            }
                        })
                        .fail(error => {
                            console.log(error)
                        })
                        .always(() => {
                            this.isLoading = false
                        })
                },
            }
        })
    </script>
@endsection
