@extends('staff.layouts.master')

@section('title', __('Edit Withdraw Method'))

@section('css_libs')
    <link href="{{ asset('assets/libs/select2/css/select2.min.css') }}" rel="stylesheet" type="text/css"/>
@endsection

@section('css')
    <style>
        [v-cloak] {
            display: none;
        }

        .toggle.btn {
            width: 100% !important;
        }
    </style>
@endsection

@section('content')
    <!-- Start Content-->
    <div class="container-fluid" id="app">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a>
                            </li>
                            <li class="breadcrumb-item">@lang('Setting')</li>
                            <li class="breadcrumb-item"><a href="{{ route('staff.setting.withdraw-method.index') }}">@lang('Withdraw Method')</a></li>
                            <li class="breadcrumb-item active">@lang('Edit')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('Edit Withdraw Method')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <form action="{{ route('staff.setting.withdraw-method.update', $withdrawMethod->id) }}" method="post">
            @csrf
            @method('PUT')
            @include('layouts.partials.flash-alert')
            @if ($errors->any())
                <div class="alert alert-danger">
                    <ul>
                        @foreach ($errors->all() as $error)
                            <li>{{ $error }}</li>
                        @endforeach
                    </ul>
                </div>
            @endif
            <div class="row">
                <div class="col-12">
                    <div class="card-box">
                        <h3 class="text-uppercase bg-light p-2 mt-0 mb-3">@lang('Withdraw Method Info')</h3>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label for="name">@lang('Name') <span class="text-danger">*</span></label>
                                    <input type="text" class="form-control @error('name') is-invalid @enderror"
                                           id="name"
                                           name="name"
                                           value="{{ $withdrawMethod->name }}" required autofocus>
                                    @error('name')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                            
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label for="min">@lang('Minimum')<span class="text-danger">*</span></label>
                                    <input type="number" min="-1" step="0.01"
                                           class="form-control @error('min') is-invalid @enderror" id="min"
                                           name="min"
                                           value="{{ $withdrawMethod->min??-1 }}" required>
                                    @error('min')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label for="max">@lang('Maximum')<span class="text-danger">*</span></label>
                                    <input type="number" min="-1" step="0.01"
                                           class="form-control @error('max') is-invalid @enderror" id="max"
                                           name="max"
                                           value="{{ $withdrawMethod->max??-1 }}" required>
                                    @error('max')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                            
                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label for="percent_charge">Percent Charge <span
                                            class="text-danger">*</span></label>
                                    <div class="input-group">
                                        <input type="number" min="0" step="0.01" name="percent_charge"
                                               id="percent_charge"
                                               value="{{ $withdrawMethod->percent_charge??0 }}"
                                               class="form-control @error('percent_charge') is-invalid @enderror"
                                               required>
                                        <div class="input-group-append">
                                            <span class="input-group-text">%</span>
                                        </div>
                                    </div>
                                    @error('percent_charge')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>

                            <div class="col-md-6">
                                <div class="form-group mb-3">
                                    <label for="description">@lang('Description') <span class="text-danger">*</span></label>
                                    <textarea name="description" id="description"
                                              class="form-control @error('code') is-invalid @enderror"
                                              required>{{ $withdrawMethod->description }}</textarea>
                                    @error('description')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                            
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="fixed_charge">Fixed Charge <span class="text-danger">*</span></label>
                                    <input type="number" min="0" step="0.01" name="fixed_charge"
                                           id="fixed_charge"
                                           value="{{ $withdrawMethod->fixed_charge??0 }}"
                                           class="form-control @error('fixed_charge') is-invalid @enderror"
                                           required>
                                    @error('fixed_charge')
                                    <div class="invalid-feedback" role="alert">
                                        {{ $message }}
                                    </div>
                                    @enderror
                                </div>
                            </div>
                            
                            <div class="col-md-12">
                                <div class="form-group mb-0">
                                    <label class="control-label"><b>@lang('Supported Currencies')</b></label>
                                    <div class="row">
                                        @foreach($all_currencies as $currency)
                                            <div class="col-md-4">
                                                <div class="form-group">
                                                    <label>
                                                        <input type="checkbox" class="flat-red" name="supported_currencies[]" value="{{ $currency->id }}" {{ in_array($currency->id,($withdrawMethod->currencies->pluck('id')->all() ?? [])) ? 'checked':'' }}> {{ $currency->name }}
                                                    </label>
                                                </div>
                                            </div>
                                        @endforeach
                                        @error('supported_currencies')
                                            <div class="invalid-feedback" role="alert">
                                                {{ $message }}
                                            </div>
                                        @enderror
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="form-group mb-3">
                            <label>@lang('Status') <span class="text-danger">*</span></label>
                            <br>
                            <div class="radio form-check-inline mr-4">
                                <input type="radio" id="status-enabled" value="1"
                                       name="status" {{ $withdrawMethod->status == 1?'checked':'' }}>
                                <label for="status-enabled"> @lang('Enabled') </label>
                            </div>
                            <div class="radio form-check-inline mr-4">
                                <input type="radio" id="status-disabled" value="0"
                                       name="status" {{ $withdrawMethod->status == 0?'checked':'' }}>
                                <label for="status-disabled"> @lang('Disabled') </label>
                            </div>
                        </div>

                        <div class="form-group text-center mb-3">
                            <button type="submit"
                                    class="btn w-sm btn-success waves-effect waves-light">@lang('Update Withdraw Method')</button>
                            <a href="{{ route('staff.setting.withdraw-method.index') }}"
                               onclick="return confirm('{{ __('Are you sure to leave this page?') }}')" type="button"
                               class="btn w-sm btn-light waves-effect">@lang('Cancel')</a>
                        </div>
                    </div>
                </div> <!-- end col -->
                <div class="col-12">
                    <div class="card-box">
                        <h3 class="text-uppercase bg-light p-2 mt-0 mb-3">@lang('Form Generator')</h3>

                        <div class="nimmu-default-card mt-5" v-for="(field, index) in fields" :key="index" v-cloak>
                            <div class="nimmu-default-card-header d-flex justify-content-between align-items-center">
                                <h4>@lang('Field') - @{{ index+1 }} (@{{ field.title }})</h4>
                                <button class="btn btn-danger btn-sm nimmu-btn nimmu-btn-danger" @click.prevent="removeField(index)"><i
                                        class="fa fa-times"></i> @lang('Remove')</button>
                            </div>
                            <div class="nimmu-default-card-body">
                                <div class="row justify-content-between align-items-center">
                                    <div class="col-md">
                                        <div class="form-group">
                                            <label :for="'title-' + index">@lang('Title') <span
                                                    class="text-danger">*</span></label>
                                            <input :id="'title-' + index" type="text" v-model="field.title"
                                                   :name="'fields['+index+'][title]'"
                                                   class="form-control" required>
                                            <input :id="'id-' + index" type="hidden" v-model="field.id"
                                                   :name="'fields['+index+'][id]'"
                                                   class="form-control">
                                        </div>
                                    </div>
                                    <div class="col-md">
                                        <div class="form-group">
                                            <label :for="'input_type-' + index">@lang('Input Type') <span
                                                    class="text-danger">*</span></label>
                                            <select :id="'input_type-' + index" v-model="field.input_type"
                                                    :name="'fields['+index+'][input_type]'"
                                                    class="form-control" required>
                                                <option value="text">Text</option>
                                                <option value="file">File Input</option>
                                                <option value="textarea">Textarea</option>
                                                <option value="select">Select</option>
                                                <option value="multiple">Multiple Select</option>
                                                <option value="radio">Radio</option>
                                                <option value="checkbox">Checkbox</option>
                                            </select>
                                        </div>
                                    </div>
                                    <div class="col-md"
                                         v-if="field.input_type == 'text' || field.input_type == 'textarea'">
                                        <div class="form-group">
                                            <label :for="'placeholder-' + index">@lang('Placeholder')</label>
                                            <input :id="'placeholder-' + index" type="text" v-model="field.placeholder"
                                                   :name="'fields['+index+'][placeholder]'"
                                                   class="form-control">
                                        </div>
                                    </div>
                                    <div class="col-md">
                                        <div class="form-group">
                                            <label :for="'sort-' + index">@lang('Sort')</label>
                                            <input :id="'sort-' + index" type="number" min="0" step="1" v-model="field.sort"
                                                   :name="'fields['+index+'][sort]'"
                                                   class="form-control">
                                        </div>
                                    </div>
                                    <div class="col-md">
                                        <div class="form-group">
                                            <label>@lang('Is Required?') <span class="text-danger">*</span></label>
                                            <br>
                                            <div class="radio form-check-inline mr-4">
                                                <input type="radio" :id="'is-required-yes-' + index" value="1"
                                                       :name="'fields['+index+'][is_required]'"
                                                       v-model="field.is_required">
                                                <label :for="'is-required-yes-' + index"> @lang('YES') </label>
                                            </div>
                                            <div class="radio form-check-inline">
                                                <input type="radio" id="'is-required-no-' + index" value="0"
                                                       :name="'fields['+index+'][is_required]'"
                                                       v-model="field.is_required">
                                                <label :for="'is-required-no-' + index"> @lang('NO') </label>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md">
                                        <div class="form-group">
                                            <button v-if="field.input_type != 'text' && field.input_type != 'file' && field.input_type != 'textarea'"
                                                    class="btn btn-success mt-3" @click.prevent="addOption(index)"><i
                                                    class="fa fa-plus"></i> @lang('Add Option')</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="card-footer"
                                 v-if="field.input_type != 'text' && field.input_type != 'file' && field.input_type != 'textarea' && field.options.length">
                                <div class="row justify-content-between align-items-center"
                                     v-for="(option, index2) in field.options" :key="index2" v-cloak>
                                    <div class="col-md">
                                        <div class="form-group">
                                            <label :for="'field-' + index + '-title-' + index2">@lang('Title')</label>
                                            <input :id="'field-' + index + '-title-' + index2" type="text"
                                                   v-model="field.options[index2].title"
                                                   :name="'fields['+index+'][options]['+index2+'][title]'"
                                                   class="form-control">
                                            <input :id="'field-' + index + '-id-' + index2" type="hidden"
                                                   v-model="field.options[index2].id"
                                                   :name="'fields['+index+'][options]['+index2+'][id]'"
                                                   class="form-control">
                                        </div>
                                    </div>
                                    <div class="col-md">
                                        <div class="form-group">
                                            <label :for="'field-' + index + '-sort-' + index2">@lang('Sort')</label>
                                            <input :id="'field-' + index + '-sort-' + index2" type="number" step="1" min="0"
                                                   v-model="field.options[index2].sort"
                                                   :name="'fields['+index+'][options]['+index2+'][sort]'"
                                                   class="form-control">
                                        </div>
                                    </div>
                                    <div class="col-md">
                                        <div class="form-group">
                                            <button class="btn btn-danger mt-3"
                                                    @click.prevent="removeOption(index, index2)"><i
                                                    class="fa fa-times"></i> @lang('Remove')</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="form-group my-3 text-md-right text-center">
                            <button class="btn btn-lg btn-outline-primary nimmu-btn nimmu-btn-outline-primary"
                                    @click.prevent="addField">
                                <i class="fa fa-plus"></i> @lang('Add Field')
                            </button>
                        </div>
                    </div>
                </div>
            </div>
            <!-- end row -->
        </form>


    </div> <!-- container -->
@endsection

@section('js_libs')
    {{--    <script src="{{ asset('assets/staff/js/bootstrap4-toggle.min.js') }}"></script>--}}
    {{--    <script src="{{ asset('assets/staff/js/select2.full.min.js') }}"></script>--}}
    <script src="{{ asset('assets/js/vue.js') }}"></script>
    <script src="{{ asset('assets/js/select2.vue.js') }}"></script>
@endsection

@section('js')
    <script>
        window.app = new Vue({
            el: '#app',
            data: {
                fields: @json($withdrawMethod->inputs??[])
            },
            beforeMount() {
                this.fields = this.fields.map(field => {
                    if (!field.hasOwnProperty('options')) {
                        field.options = []
                    }
                    return field;
                })
            },
            methods: {
                addField() {
                    this.fields.push({
                        title: null,
                        input_type: 'text',
                        placeholder: null,
                        options: [],
                        sort: 0,
                        is_required: 0
                    })
                },
                removeField(index) {
                    this.fields.splice(index, 1)
                },
                addOption(index) {
                    this.fields[index].options.push({
                        title: null,
                        sort: 0
                    })
                },
                removeOption(index, index2) {
                    this.fields[index].options.splice(index2, 1)
                }
            }
        })
    </script>
@endsection
