
@extends('staff.layouts.master')

@section('title', __('Workflow Steps'))

@section('content')
    <!-- Start Content-->
    <div class="container-fluid">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a>
                            </li>
                            <li class="breadcrumb-item active">@lang('Workflow Steps')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('Workflow Steps')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <div class="row justify-content-center justify-content-md-end">
            <div class="col-md-2 col-sm-6">
                <a href="{{ route('staff.setting.workflow.create') }}" class="btn btn-block btn-primary">Add New Step</a>
            </div>
        </div>

        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">
                        @include('layouts.partials.flash-alert')
                        <table id="data-table" class="table table-bordered dt-responsive nowrap w-100 text-center">
                            <thead>
                                <tr>
                                    <th>@lang('ID')</th>
                                    <th>@lang('Title')</th>
                                    <th>@lang('Details')</th>
                                    <th>@lang('Action')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach($workFlows as $index=>$workFlow)
                                    <tr>
                                        <td>{{ $index+1 }}</td>
                                        <td>{{ $workFlow->title }}</td>
                                        <td>{{ Str::limit($workFlow->details, 50, '(......)') }}</td>
                                        <td>
                                            <a href="{{ route('staff.setting.workflow.edit',$workFlow->id) }}" class="btn btn-warning btn-edit mr-1 btn-xs"><i class="fa fa-edit"></i></a>
                                            <button class="btn btn-danger btn-delete btn-xs" data-id="{{ $workFlow->id }}"><i class="fa fa-trash"></i></button>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>

                    </div> <!-- end card body-->
                </div> <!-- end card -->
            </div><!-- end col-->
        </div>
        <!-- end row-->


    </div> <!-- container -->

    <div id="delete-modal" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="delete-modalLabel"
         aria-modal="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <form action="" method="post">
                    @csrf
                    @method('DELETE')
                    <div class="modal-header">
                        <h4 class="modal-title" id="delete-modalLabel">@lang('Delete workflow step')</h4>
                        <button type="button" class="close" data-dismiss="modal" aria-hidden="true">×</button>
                    </div>
                    <div class="modal-body">
                        <h4>@lang('Are you sure to delete this step ?')</h4>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-light" data-dismiss="modal">@lang('Close')</button>
                        <button type="submit" class="btn btn-danger">@lang('Delete')</button>
                    </div>
                </form>
            </div><!-- /.modal-content -->
        </div><!-- /.modal-dialog -->
    </div>
@endsection

@section('js')
    <script>
        (function ($) {
            $(document).on('click', '.btn-delete', function (e) {
                e.preventDefault();
                var id = $(this).data('id');
                var url = '{{ url('staff/setting/workflow') }}/' + id
                $('#delete-modal form').prop('action', url);
                $('#delete-modal').modal();
            })
        })(jQuery)
    </script>
@endsection


