@extends('staff.layouts.master')

@section('title', 'Add New Transaction')

@section('css_libs')
    <link href="{{ asset('assets/libs/select2/css/select2.min.css') }}" rel="stylesheet" type="text/css"/>
@endsection

@section('css')
    <style>
        .toggle.btn {
            width: 100% !important;
        }
        [v-cloak] {
            display: none;
        }
    </style>
@endsection

@section('content')
    <!-- Start Content-->
    <div class="container-fluid" id="app">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a>
                            </li>
                            <li class="breadcrumb-item"><a
                                    href="{{ route('staff.transaction.index') }}">@lang('Transactions')</a></li>
                            <li class="breadcrumb-item active">@lang('New Transaction')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('New Transaction')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <form action="{{ route('staff.transaction.store') }}" method="post">
            @csrf
            @include('layouts.partials.flash-alert')
            <div v-cloak>
                <div class="row">
                    <div class="col-md-12">
                        <div class="card-box">
                            <h3 class="text-uppercase bg-light p-2 mt-0 mb-3">@lang('Transaction info details')</h3>
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="user_type">User Type</label>
                                        <select id="user_type" name="user_type" v-model="user_type" class="custom-select @error('user_type') is-invalid @enderror">
                                            <option value="user">@lang('Customer/User')</option>
                                            <option value="doctor">@lang('Doctor')</option>
                                        </select>
                                        @error('user_type')
                                        <div class="invalid-feedback">
                                            {{ $message }}
                                        </div>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group" v-if="user_type === 'user'">
                                        <label for="customer_id">Customers</label>
                                        <select2 id="customer_id" name="user_id" v-model="user_id" key="select2-1" class="form-control customers @error('user_id') is-invalid @enderror">
                                            @foreach($customers as $customer)
                                                <option value="{{ $customer->id }}">{{ $customer->full_name }} - ({{ $customer->balance }} {{ $currency->code }})</option>
                                            @endforeach
                                        </select2>
                                        @error('user_id')
                                        <div class="invalid-feedback">
                                            {{ $message }}
                                        </div>
                                        @enderror
                                    </div>
                                    <div class="form-group" v-else>
                                        <label for="doctor_id">Doctor</label>
                                        <select2 id="doctor_id" name="user_id" v-model="doctor_id" key="select2-2" class="form-control delivery-men @error('user_id') is-invalid @enderror">
                                            @foreach($doctors as $doctor)
                                                <option value="{{ $doctor->id }}">{{ $doctor->full_name }} - ({{ $doctor->balance }} {{ $currency->code }})</option>
                                            @endforeach
                                        </select2>
                                        @error('user_id')
                                        <div class="invalid-feedback">
                                            {{ $message }}
                                        </div>
                                        @enderror
                                    </div>
                                </div>
                            </div>

                            <div class="form-group">
                                <label for="title">Title</label>
                                <input id="title" type="text" class="form-control @error('title') is-invalid @enderror" name="title" value="{{ old('title') }}" required>
                                @error('title')
                                <div class="invalid-feedback">
                                    {{ $message }}
                                </div>
                                @enderror
                            </div>
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="type">Type</label>
                                        <select id="type" name="type" class="custom-select @error('type') is-invalid @enderror">
                                            <option value="+">+ in wallet</option>
                                            <option value="-">- from wallet</option>
                                        </select>
                                        @error('type')
                                        <div class="invalid-feedback">
                                            {{ $message }}
                                        </div>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="amount">Amount</label>
                                        <div class="input-group">
                                            <input id="amount" type="number" step="any" class="form-control @error('amount') is-invalid @enderror" name="amount" value="{{ old('amount') }}" required>
                                            <div class="input-group-append">
                                                <span class="input-group-text">{{ $currency->code }}</span>
                                            </div>
                                        </div>
                                        @error('amount')
                                        <div class="invalid-feedback">
                                            {{ $message }}
                                        </div>
                                        @enderror
                                    </div>
                                </div>
                            </div>
                            <!-- end row -->
                            <div class="form-group">
                                <button class="btn btn-primary btn-block btn-lg nimmu-btn nimmu-btn-primary" type="submit" onclick="return confirm('Are you sure to add this transaction? You can\'t revert this')">Save</button>
                            </div>
                        </div> <!-- end card-box -->
                    </div>
                </div>
            </div>
        </form>
    </div> <!-- container -->
@endsection

@section('js_libs')
    <script src="{{ asset('assets/libs/select2/js/select2.min.js') }}"></script>
    <script src="{{ asset('assets/js/vue.js') }}"></script>
    <script src="{{ asset('assets/js/select2.vue.js') }}"></script>
@endsection

@section('js')
    <script>
        window.app = new Vue({
            el: '#app',
            data: {
                user_type: 'user',
                user: @json($customers),
                doctors: @json($doctors),
                user_id: @json(old('user_id')??null),
                doctor_id: @json(old('doctor_id')??null),
            },
            beforeMount() {
                if (!this.user_id) {
                    if (this[this.user_type].length) {
                        this[this.user_type + '_id'] = this[this.user_type][0].id
                    }
                }
            },
            components: {
                select2: window.select2Vue
            },
            watch: {
                user_type(newVal, oldVal) {
                    if (this[this.user_type].length) {
                        this[this.user_type + '_id'] = this[this.user_type][0].id
                    }
                }
            }
        })

        (function ($) {
            $(document).ready(function () {
                $('.select2').select2();
            })
        })(jQuery)
    </script>
@endsection
