@extends('staff.layouts.master')

@section('title', __('New User'))

@section('css_libs')
    <link href="{{ asset('assets/libs/bootstrap4-toggle/bootstrap4-toggle.min.css') }}" rel="stylesheet">
    <link href="{{ asset('assets/libs/select2/css/select2.min.css') }}" rel="stylesheet" type="text/css"/>
@endsection

@section('css')
    <style>
        .toggle.btn {
            width: 100% !important;
        }
    </style>
@endsection

@section('content')
    <!-- Start Content-->
    <div class="container-fluid">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a>
                            </li>
                            <li class="breadcrumb-item"><a
                                    href="{{ route('staff.user.index') }}">@lang('Users')</a></li>
                            <li class="breadcrumb-item active">@lang('New User')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('New User')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->

        <form action="{{ route('staff.user.store') }}" method="post">
            @csrf
            @include('layouts.partials.flash-alert')
            @if ($errors->any())
                <div class="alert alert-danger">
                    <ul>
                        @foreach ($errors->all() as $error)
                            <li>{{ $error }}</li>
                        @endforeach
                    </ul>
                </div>
            @endif

            <div class="row">
                <div class="col-md-3">
                    <div class="card-box">
                        <div class="nimmu-default-card nimmu-buttons avatar-pro">
                            <div class="nimmu-default-card-body">
                                <div class="form-group text-center">
                                    <img class="img-thumbnail" style="width: 200px;height: 200px;"
                                         src="https://picsum.photos/200" id="avatar-preview">
                                    <input type="hidden" name="avatar" value="https://picsum.photos/200" id="avatar">
                                    <button class="btn btn-outline-info nimmu-btn nimmu-btn-outline-info btn-select">Change Avatar</button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-md-9">
                    <div class="card-box">
                        <div class="nimmu-default-card nimmu-buttons">
                            <div
                                class="nimmu-default-card-header nimmu-mb-30 d-flex justify-content-between align-content-center">
                                <div class="nimmu-header-left">
                                    <h3>Customer Details</h3>
                                </div>
                            </div>
                            <div class="nimmu-default-card-body">
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="first_name">First Name</label>
                                            <input id="first_name" type="text" class="form-control" name="first_name" value="{{ old('first_name') }}" required>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="last_name">Last Name</label>
                                            <input id="last_name" type="text" class="form-control" name="last_name" value="{{ old('last_name') }}" required>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="username">Username <span class="badge badge-info">unique</span></label>
                                            <input id="username" type="text" class="form-control" name="username" value="{{ old('username') }}" required>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="username">Role</label>
                                            <select class="form-control select2" name="role_id" required>
                                                <option value="">--Select Role--</option>
                                                @foreach($roles as $role)
                                                    <option value="{{ $role->id }}">{{ $role->name }}</option>
                                                @endforeach
                                            </select>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="email">Email <span class="badge badge-info">unique</span></label>
                                            <input id="email" type="email" class="form-control" name="email" value="{{ old('email') }}" required>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="phone">Phone (without +) <span class="badge badge-info">unique</span></label>
                                            <input id="phone" type="text" class="form-control" name="phone" value="{{ old('phone') }}" required>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="password">Password</label>
                                            <input id="password" type="password" class="form-control" name="password" required>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label for="password_confirmation">Retype Password</label>
                                            <input id="password_confirmation" type="password" class="form-control" name="password_confirmation" required>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-4">
                                        <div class="form-group">
                                            <label for="email_verification">Email Verification</label>
                                            <input id="email_verification" name="email_verification" type="checkbox" {{ old('email_verification') == 'on'?'checked':'' }} data-toggle="toggle" data-on="Verified" data-off="Unverified" data-onstyle="success" data-offstyle="danger">
                                        </div>
                                    </div>
                                    <div class="col-md-4">
                                        <div class="form-group">
                                            <label for="phone_verification">Phone Verification</label>
                                            <input id="phone_verification" name="phone_verification" type="checkbox" {{ old('phone_verification') == 'on'?'checked':'' }} data-toggle="toggle" data-on="Verified" data-off="Unverified" data-onstyle="success" data-offstyle="danger">
                                        </div>
                                    </div>
                                    <div class="col-md-4">
                                        <div class="form-group">
                                            <label for="enabled_2fa">Enable 2FA</label>
                                            <input id="enabled_2fa" name="enabled_2fa" type="checkbox" {{ old('enabled_2fa') == 'on'?'checked':'' }} data-toggle="toggle" data-on="Enabled" data-off="Disabled" data-onstyle="success" data-offstyle="danger">
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-4">
                                        <div class="form-group">
                                            <label for="verified_2fa">2FA Verification</label>
                                            <input id="verified_2fa" name="verified_2fa" type="checkbox" {{ old('verified_2fa') == 'on'?'checked':'' }} data-toggle="toggle" data-on="Verified" data-off="Unverified" data-onstyle="success" data-offstyle="danger">
                                        </div>
                                    </div>
                                    <div class="col-md-4">
                                        <div class="form-group">
                                            <label for="push_notification">Push Notification</label>
                                            <input id="push_notification" name="push_notification" type="checkbox" {{ old('push_notification') == 'on'?'checked':'' }} data-toggle="toggle" data-on="Enabled" data-off="Disabled" data-onstyle="success" data-offstyle="danger">
                                        </div>
                                    </div>
                                    <div class="col-md-4">
                                        <div class="form-group">
                                            <label for="status">Status</label>
                                            <input id="status" name="status" type="checkbox" {{ old('status') == 'on'?'checked':'' }} data-toggle="toggle" data-on="Activated" data-off="Deactivated" data-onstyle="success" data-offstyle="danger">
                                        </div>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <button class="btn btn-primary btn-block btn-lg nimmu-btn nimmu-btn-primary" type="submit">Save Customer</button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </form>


    </div> <!-- container -->
@endsection

@section('js_libs')
    <script src="{{ asset('assets/libs/bootstrap4-toggle/bootstrap4-toggle.min.js') }}"></script>
    <script src="{{ asset('assets/libs/select2/js/select2.min.js') }}"></script>
@endsection

@section('js')
    <script>
        (function ($) {
            $(document).ready(function () {
                $('.select2').select2();
            })
            $(document).on('click', '.btn-select', function (e) {
                e.preventDefault()
                openMediaManager(items => {
                    if (items[0] && items[0].hasOwnProperty('url')) {
                        $('#avatar').val(items[0].url)
                    }
                    if (items[0] && items[0].hasOwnProperty('thumb_url')) {
                        $('#avatar-preview').attr('src', items[0].thumb_url)
                    }
                }, 'image', 'Select Avatar')
            })
        })(jQuery)
    </script>
@endsection
