@extends('staff.layouts.master')

@section('title', __('User Wallets'))

@section('content')
    <!-- Start Content-->
    <div class="container-fluid">

        <!-- start page title -->
        <div class="row">
            <div class="col-12">
                <div class="page-title-box">
                    <div class="page-title-right">
                        <ol class="breadcrumb m-0">
                            <li class="breadcrumb-item"><a href="{{ route('staff.dashboard') }}">@lang('Dashboard')</a></li>
                            <li class="breadcrumb-item active">@lang('User Wallets')</li>
                        </ol>
                    </div>
                    <h4 class="page-title">@lang('User Wallets')</h4>
                </div>
            </div>
        </div>
        <!-- end page title -->
        <div class="row">
            <div class="col-md-12">
                @include('layouts.partials.flash-alert')
                @if($errors->any())
                    @foreach($errors->all() as $error)
                        <div class="alert alert-danger alert-dismissable fade show" role="alert">
                            {{ $error }}
                            <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                <span aria-hidden="true">&times;</span>
                            </button>
                        </div>
                    @endforeach
                @endif
            </div>
            <div class="col-xl-3 col-lg-12">
                <div class="card-box">
                    <div class="nimmu-default-card nimmu-buttons avatar-pro">
                        <div
                            class="nimmu-default-card-header d-flex justify-content-center align-content-center bg-light">
                            <h3 class="text-uppercase p-0 text-center">User Info</h3>
                        </div>
                        <div class="nimmu-default-card-body mt-3">
                            <div class="form-group text-center">
                                <img class="img-thumbnail" style="width: 200px;height: 200px;"
                                     src="{{ $user->avatar??'https://picsum.photos/200' }}" id="avatar-preview">
                                <input type="hidden" name="avatar" value="{{ $user->avatar??'https://picsum.photos/200' }}" id="avatar">
                            </div>
                            <p class="text-black-50 text-center">
                                <b>Name : </b>{{ $user->first_name . ' ' . $user->last_name }}
                            </p>
                            <p class="text-black-50 text-center">
                                <b>Email : </b>{{ $user->email }}
                            </p>
                            <p class="text-black-50 text-center">
                                <b>Phone No : </b>{{ $user->phone }}
                            </p>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-xl-9 col-lg-12 ">
                <div class="card-box">
                    <div class="nimmu-default-card nimmu-buttons">
                        <div
                            class="nimmu-default-card-header d-flex justify-content-left align-content-center bg-light">
                            <h3 class="text-uppercase p-0 text-center pl-2">Wallet Info</h3>
                        </div>
                        <div class="nimmu-default-card-body mt-3">
                            <div class="row">
                                @foreach($user->wallets as $wallet)
                                    <div class="col-md-6 col-xl-3">
                                        <div class="widget-rounded-circle card-box bg-info">
                                            <div class="row align-items-center">
                                                <div class="col text-center">
                                                    <h5 class="mb-1 mt-2 font-16 text-white">{{ $wallet->currency['name'] }}</h5>
                                                    <p class="mb-2 text-white">Balance : {{ $wallet->balance .$wallet->currency['symbol']  }}</p>
                                                    <button class="btn btn-select bg-light d-block w-100" type="button" onclick="manageBalance({{ json_encode(['wallet'=>$wallet->id, 'currency_name'=>$wallet->currency['name'], 'currency_symbol'=>$wallet->currency['symbol']]) }})">Manage Balance</button>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                @endforeach
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <div class="modal fade" id="edit-modal">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title" id="wallet_for">Manage Balance</h4>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">×</span></button>
                </div>
                <form method="post">
                    @csrf
                    @method('PUT')
                    <div class="modal-body">
                        <div class="form-group">
                            <label class="control-label">Action Type</label>
                            <select class="form-control" name="action_type" required>
                                <option value="">--Select Action--</option>
                                <option value="add">Add</option>
                                <option value="deduct">Deduct</option>
                            </select>
                        </div>
                        <div class="form-group">
                            <label class="control-label">Action Title</label>
                            <input type="text" class="form-control" name="action_title" required>
                        </div>
                        <label class="control-label">Amount</label>
                        <div class="input-group">
                            <div class="input-group-append">
                                <span class="input-group-text" id="currency_symbol">$</span>
                            </div>
                            <input type="number" min="0.01" step="0.01" name="amount" id="amount" value="{{ old('amount') }}" class="form-control" required>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-default pull-left" data-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary" onclick="this.disabled=true;this.form.submit();">Update</button>
                    </div>
                </form>
            </div>
            <!-- /.modal-content -->
        </div>
        <!-- /.modal-dialog -->
    </div>
@endsection

@section('js')
    <script>
        function manageBalance(data){
            var url = '{{ url('staff/update-wallet-balance') }}/' + data.wallet;
            $('#wallet_for').text('Manage Balance ( for ' + data.currency_name + ' )')
            $('#currency_symbol').text(data.currency_symbol)
            $('#edit-modal form').prop('action', url);
            $('#edit-modal').modal('show');
        }
        $(document).ready(function (){

        })
        $(document).on('click', '.btn-edit', function (e) {
            e.preventDefault();

            var datas = [];
            [].forEach.call(this.attributes, function (attr) {
                if (/^data-/.test(attr.name)) {
                    var camelCaseName = attr.name.substr(5).replace(/-(.)/g, function ($0, $1) {
                        return $1.toUpperCase();
                    });
                    datas.push({
                        name: camelCaseName,
                        value: attr.value
                    });
                }
            });
            datas.forEach(function (data) {
                if (data.name == 'id') {
                    var url = '{{ url('staff/setting/language') }}/' + data.value;
                    $('#edit-modal form').prop('action', url);
                } else if ((data.name == 'status') || (data.name == 'is_default')) {
                    if (parseInt(data.value) == 1) {
                        $('#' + data.name).prop('checked', true)
                    } else {
                        $('#' + data.name).prop('checked', false)
                    }
                } else {
                    $('#' + data.name).val(data.value);
                }
            })
            $('#edit-modal').modal('show');
        })
    </script>
@endsection

