@extends('user.layouts.master')

@section('title', ' | Dashboard')

@section('css_libs')
    <link rel="stylesheet" href="{{ asset('assets/libs/select2/css/select2.min.css') }}">
    <link rel="stylesheet" href="{{ asset('assets/libs/select2/css/select2-bootstrap.css') }}">
@endsection

@section('css')
    <style>
        [v-cloak] {
            display: none;
        }
    </style>
@endsection

@section('breadcrumb')
    <div class="breadcrumb-area">
        <div class="container">
            <div class="breadcrumb-content">
                <h2>@lang('Dashboard') / @lang('New Deposit')</h2>
            </div>
        </div>
    </div>
@endsection

@section('content')
    <section class="wallet-list pt-100 pb-100" id="app" v-cloak>
        <div class="container">
            @include('layouts.partials.flash-alert', ['form' => true])
            <div class="row mb-3">
                <div class="col-md-6">
                    <div class="formInput mb-3">
                        <input type="number" max="99999" class="form-control" step="any" name="amount" id="amount" placeholder="1000" v-model="amount">
                        <small class="form-text text-danger ml-2" v-if="amount<=0 || amount>99999">Amount should greater than 0 and less than or equal to 99999.</small>
                    </div>
                </div>
                <div class="col-md-6">
                    <div class="formInput">
                        <select class="form-control form-control-lg" name="currency_code" id="currency_code"
                                 v-model="currency_code" key="currency-selector">
                            <option v-for="(curr, currIndex) in currencies" :key="'currency-' + curr.code"
                                    :value="curr.code">
                                @{{ curr.code }}
                            </option>
                        </select>
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="col-md-3" v-for="(gatew, gatewayIndex) in currency.gateways"
                     :key="'gateway-' + gatewayIndex">
                    <div class="card">
                        <div class="card-header">
                            <h5>@{{ gatew.name }}</h5>
                        </div>
                        <div class="card-body text-center">
                            <img :src="gatew.image" :alt="gatew.name">
                            <p class="text-center">
                                <b v-if="gatew.min != -1">@lang('Min:') @{{ gatew.min }}, </b>
                                <b v-if="gatew.max != -1">@lang('Max:') @{{ gatew.max }}, </b>
                                <b>@lang('Charge:') @{{ gatew.percent_charge }}%+@{{ gatew.fixed_charge }}</b>
                            </p>
                        </div>
                        <div class="card-footer" v-if="(amount>0) && (amount<=99999)">
                            <button
                                :disabled="(gatew.min != -1 && amount < gatew.min) || (gatew.max != -1 && amount > gatew.max)"
                                type="button" class="btn w-100 btn-outline-primary"
                                @click.prevent="gatewaySelected(gatewayIndex)">@lang('Select It')</button>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="modal fade" id="depositDetailsModal" tabindex="-1" role="dialog"
             aria-labelledby="depositDetailsModalLabel" aria-hidden="true">
            <div class="modal-dialog" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="depositDetailsModalLabel">@lang('Details')</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                    </div>
                    <form action="{{ route('deposit.store') }}" method="post" v-if="gateway">
                        @csrf
                        <div class="modal-body text-center">
                            <h6>@lang('Gateway'): @{{ gateway.name }}</h6>
                            <h6>@lang('Amount'): @{{ amount }} @{{ currency.code }}</h6>
                            <h6>@lang('Charges'): @{{ gateway.percent_charge }}%+@{{ gateway.fixed_charge }} @{{ currency.code }}</h6>
                            <input type="hidden" name="currency_id" :value="currency.id">
                            <input type="hidden" name="amount" :value="amount">
                            <input type="hidden" name="gateway_id" :value="gateway.id">
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">@lang('Close')</button>
                            <button type="submit" class="btn btn-primary">@lang('Next')</button>
                        </div>
                    </form>
                </div>
            </div>
        </div>

    </section>
@endsection

@section('js_libs')
    <script src="{{ config('app.debug')?asset('assets/js/vue.dev.js'):asset('assets/js/vue.prod.js') }}"></script>
    <script src="{{ asset('assets/js/select2.full.min.js') }}"></script>
    <script src="{{ asset('assets/js/select2.vue.js') }}"></script>
@endsection

@section('js')
    <script>
        window.app = new Vue({
            el: '#app',
            components: {
                select2Vue
            },
            data: {
                amount: @json(old('amount')??1000),
                currencies: @json($currencies),
                currency_code: @json(old('currency_code')??null),
                gateway: null
            },
            beforeMount() {
                if (!this.currency_code) {
                    const de = this.currencies.filter(curren => {
                        return curren.is_default == 1
                    })
                    if (de.length) {
                        this.currency_code = de[0].code
                    }
                }
            },
            methods: {
                gatewaySelected(index) {
                    this.gateway = this.currency.gateways[index]
                    $('#depositDetailsModal').modal('show')
                }
            },
            computed: {
                currency() {
                    return this.currencies.filter(curren => {
                        return curren.code === this.currency_code
                    })[0]
                }
            }
        })
    </script>
@endsection
