@extends('user.layouts.master')

@section('title', ' | Payment Requests')

@section('css_libs')
    <link href="{{ asset('assets/libs/select2/css/select2.min.css') }}" rel="stylesheet" type="text/css"/>
@endsection

@section('breadcrumb')
    <div class="breadcrumb-area">
        <div class="container">
            <div class="breadcrumb-content">
                <h2><a href="{{ route('dashboard') }}">Dashboard</a> / Payment Requests To You</h2>
                {{--                <p>--}}
                {{--                    There are many variations of passages of Lorem Ipsum available, but--}}
                {{--                    the majority have suffered alteration in some form, by injected--}}
                {{--                    humour, or randomised words which slightly believable.--}}
                {{--                </p>--}}
            </div>
        </div>
    </div>
@endsection

@section('content')
    <section class="wallet-list pt-100 pb-100">
        <div class="container">
            @if ($errors->any())
                <div class="alert alert-danger">
                    <ul>
                        @foreach ($errors->all() as $error)
                            <li>{{ $error }}</li>
                        @endforeach
                    </ul>
                </div>
            @endif
            @if (session('success'))
                <div class="alert alert-success" role="alert">
                    {{ session('success') }}
                </div>
            @endif
            <div class="mt-4">
                <table class="table-style-2">
                    <thead>
                    <tr>
                        <th>#SL</th>
                        <th>Request By</th>
                        <th>Currency</th>
                        <th>Amount</th>
                        <th>Status</th>
                        <th class="text-center">Action</th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach($payment_requests as $index=>$payment_request)
                        <tr>
                            <td>{{ $index+1 }}</td>
                            <td>{{ $payment_request->requestBy['full_name'] .' (' .$payment_request->requestBy['username'] .')' }}</td>
                            <td>{{ $payment_request->currency['name'] }}</td>
                            <td>{{ $payment_request->currency['symbol'] .$payment_request->amount }}</td>
                            <td>
                                @if($payment_request->status == 'approved')
                                    <span class="badge bg-success">{{ ucfirst($payment_request->status) }}</span>
                                @elseif($payment_request->status == 'pending')
                                    <span class="badge bg-secondary">{{ ucfirst($payment_request->status) }}</span>
                                @else
                                    <span class="badge bg-danger">{{ ucfirst($payment_request->status) }}</span>
                                @endif
                            </td>
                            <td>
                                <div class="d-flex justify-content-center actions">
                                    <button type="button" class="btn-show" data-fields="{{ $payment_request }}"><i
                                            class="fa fa-eye text-success"></i></button>
                                    @if($payment_request->status == 'pending')
                                        <button type="button" class="btn-accept" data-id="{{ $payment_request->id }}"><i
                                                class="fa fa-check-circle text-primary"></i></button>
                                        <button type="button" class="btn-reject" data-id="{{ $payment_request->id }}"><i
                                                class="fa fa-times text-danger"></i></button>
                                    @endif
                                </div>
                            </td>
                        </tr>
                    @endforeach
                    </tbody>
                </table>
                @if(count($payment_requests)<=0)
                    <h4 class="text-center text-muted mt-4">No Payment requests data available</h4>
                @endif
            </div>
        </div>
    </section>

    <div class="modal fade" id="show-modal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="sendMoneyModalLabel">Payment Request Details</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div class="mb-3">
                        <p><b>Order By : </b><span id="orderBy"></span></p>
                        <p><b>Currency : </b><span id="currencyName"></span></p>
                        <p><b>Amount : </b><span id="requestAmount"></span></p>
                        <p><b>Note : </b><span id="paymentNote"></span></p>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                </div>
            </div>
        </div>
    </div>

    <div class="modal fade" id="accept-modal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="sendMoneyModalLabel">Accept Withdraw Request</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form method="post">
                    @csrf
                    @method('PUT')
                    <div class="modal-body">
                        <input type="hidden" name="action" value="approved">
                        <div class="mb-3">
                            <h5 class="text-center">Are you sure to accept this request?</h5>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-success">Accept</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div class="modal fade" id="reject-modal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="sendMoneyModalLabel">Reject Payment Request</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form method="post">
                    @csrf
                    @method('PUT')
                    <div class="modal-body">
                        <input type="hidden" name="action" value="rejected">
                        <div class="mb-3">
                            <h5 class="text-center">Are you sure to reject this request?</h5>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-danger">Reject</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@section('js_libs')
    <script src="{{ asset('assets/js/vue.js') }}"></script>
    <script src="{{ asset('assets/libs/select2/js/select2.min.js') }}"></script>
@endsection

@section('js')

    <script>
        $(document).on('click', '.btn-show', function (e) {
            e.preventDefault();
            let fields = $(this).data('fields');
            console.log(fields);
            if (typeof fields == 'object') {
                $('#orderBy').html(fields.request_by.first_name + ' ' + fields.request_by.last_name)
                $('#currencyName').html(fields.currency.name)
                $('#requestAmount').html(fields.currency.symbol+fields.amount)
                $('#paymentNote').html(fields.note)
            }
            $('#show-modal').modal('show')
        })

        $(document).on('click', '.btn-accept', function (e) {
            e.preventDefault();
            var id = $(this).data('id');
            var url = '{{ url('dashboard/payment-requests') }}/' + id
            $('#accept-modal form').prop('action', url);
            $('#accept-modal').modal('show');
        })

        $(document).on('click', '.btn-reject', function (e) {
            e.preventDefault();
            var id = $(this).data('id');
            var url = '{{ url('dashboard/payment-requests') }}/' + id
            $('#reject-modal form').prop('action', url);
            $('#reject-modal').modal('show');
        })
    </script>

@endsection
