@extends('user.layouts.master')

@section('title', ' | Edit Store Info')

@section('breadcrumb')
    <div class="breadcrumb-area">
        <div class="container">
            <div class="breadcrumb-content">
                <h2><a href="{{ route('dashboard') }}">Dashboard</a> / <a href="{{ route('stores.index') }}">Store</a> / Edit</h2>
            </div>
        </div>
    </div>
@endsection

@section('content')
    <div class="pt-100 pb-80">
        <div class="container">
            <div class="row justify-content-center">
                <div class="col-12 col-lg-9">
                    @if ($errors->any())
                        <div class="alert alert-danger">
                            <ul>
                                @foreach ($errors->all() as $error)
                                    <li>{{ $error }}</li>
                                @endforeach
                            </ul>
                        </div>
                    @endif
                    @if (session('success'))
                        <div class="alert alert-success" role="alert">
                            {{ session('success') }}
                        </div>
                    @endif
                    <div class="card">
                        <div class="card-body p-3 p-md-5">
                            <div class="card-title mb-4">Update Store Info</div>

                            <div class="gauth-settings">
                                <form action="{{ route('stores.update',$store->id) }}" method="post">
                                    @csrf
                                    @method('PUT')
                                    <div class="mb-3">
                                        <label class="form-label"><b>Store Name</b></label>
                                        <div class="row align-items-center g-3">
                                            <div class="col-11">
                                                <input type="text" class="form-control" name="name" placeholder="Name"
                                                       value="{{ $store->name }}"/>
                                            </div>
                                        </div>
                                        <label class="form-label mt-3 font-weight-bold"><b>Supported Payment Gateways</b></label>
                                        <div class="row">
                                            @foreach($paymentGateways as $index=>$paymentGateway)
                                                <div class="col-md-4">
                                                    <div class="form-check">
                                                        <input class="form-check-input" name="supported_payment_gateway[]" type="checkbox" value="{{ $paymentGateway->id }}" id="flexCheckDefault{{ $index }}" {{ in_array($paymentGateway->id,($store->payment_gateways->pluck('id')->all() ?? [])) ? 'checked':'' }}>
                                                        <label class="form-check-label" for="flexCheckDefault{{ $index }}">
                                                            {{ $paymentGateway->name }}
                                                        </label>
                                                    </div>
                                                </div>
                                            @endforeach
                                        </div>
                                    </div>
                                    <div class="mb-3">
                                        <label class="form-label"><b>API Key</b></label>
                                        <div class="row align-items-center g-3">
                                            <div class="col-8">
                                                <input type="text" class="form-control" placeholder="API Key"
                                                       value="{{ $store->api_key }}"/>
                                            </div>
                                            <div class="col-auto">
                                                <button type="button" onclick="copy('{{ $store->api_key }}')"
                                                        class="badge bg-info p-3 text-white"><i
                                                        class="fa fa-clipboard"></i></button>
                                            </div>
                                            <div class="col-auto">
                                                <button data-bs-toggle="modal" data-bs-target="#generateApiKey"
                                                        type="button"
                                                        class="badge bg-primary p-3 text-white">
                                                    Regenerate
                                                </button>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="mb-3">
                                        <label class="form-label"><b>API Secret</b></label>
                                        <div class="row align-items-center g-3">
                                            <div class="col-8">
                                                <input type="text" class="form-control" placeholder="API Secret"
                                                       value="{{ $store->api_secret }}"/>
                                            </div>
                                            <div class="col-auto">
                                                <button type="button" onclick="copy('{{ $store->api_secret }}')"
                                                        class="badge bg-info p-3 text-white"><i
                                                        class="fa fa-clipboard"></i></button>
                                            </div>
                                            <div class="col-auto">
                                                <button data-bs-toggle="modal" data-bs-target="#generateApiSecret"
                                                        type="button"
                                                        class="badge bg-primary p-3 text-white">
                                                    Regenerate
                                                </button>
                                            </div>
                                        </div>
                                    </div>
                                    <button class="my-4 btn btn-primary" type="submit">Save</button>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- Regenerate API Key -->
    <div class="modal fade" id="generateApiKey" tabindex="-1" aria-labelledby="apiKeyModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title" id="apiKeyModalLabel">Do you want to replace the current api key with a new one ?</h4>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <p>The new key will be available immediately. The current key will be deactivated permanently.</p>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary ps-4 pe-4" data-bs-dismiss="modal">Cancel</button>
                    <form action="{{ route('regenerate-api-key',$store->id) }}" method="post">
                        @csrf
                        <button type="submit" class="btn btn-primary">Confirm</button>
                    </form>
                </div>
            </div>
        </div>
    </div>

    <!-- Regenerate API Secret -->
    <div class="modal fade" id="generateApiSecret" tabindex="-1" aria-labelledby="apiSecretModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title" id="apiSecretModalLabel">Do you want to replace the current api secret with a new one ?</h4>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <p>The new secret key will be available immediately. The current secret key will be deactivated permanently.</p>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary ps-4 pe-4" data-bs-dismiss="modal">Cancel</button>
                    <form action="{{ route('regenerate-api-secret',$store->id) }}" method="post">
                        @csrf
                        <button type="submit" class="btn btn-primary">Confirm</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
    <!-- Toaster -->
    <div class="position-fixed top-0 start-50 translate-middle-x p-3" style="z-index: 11">
        <div id="liveToast" class="toast align-items-center justify-content-center text-white bg-primary border-0"
             role="alert" aria-live="assertive" aria-atomic="true">
            <div class="d-flex">
                <div class="toast-body">
                    Copied to clipboard!
                </div>
                <button type="button" class="btn-close btn-close-white me-2 m-auto" data-bs-dismiss="toast"
                        aria-label="Close"></button>
            </div>
        </div>
    </div>
@endsection

@section('js')
    <script>
        function copy(text) {
            var input = document.createElement('textarea');
            input.innerHTML = text;
            document.body.appendChild(input);
            input.select();
            var result = document.execCommand('copy');
            document.body.removeChild(input);

            // toaster activation script
            const toastLiveExample = document.getElementById('liveToast')
            const toast = new bootstrap.Toast(toastLiveExample)
            toast.show()

            // returning
            return result;
        }
    </script>
@endsection
