@extends('user.layouts.master')

@section('title', ' | Stores')

@section('breadcrumb')
    <div class="breadcrumb-area">
        <div class="container">
            <div class="breadcrumb-content">
                <h2><a href="{{ route('dashboard') }}">Dashboard</a> / Stores</h2>
            </div>
        </div>
    </div>
@endsection

@section('content')
    <div class="pt-100 pb-80">
        <div class="container">
            @if ($errors->any())
                <div class="alert alert-danger">
                    <ul>
                        @foreach ($errors->all() as $error)
                            <li>{{ $error }}</li>
                        @endforeach
                    </ul>
                </div>
            @endif
            @if (session('success'))
                <div class="alert alert-success" role="alert">
                    {{ session('success') }}
                </div>
            @endif
            <div class="px-3 mb-3">
                <div class="text-end">
                    <a class="btn btn-primary" href="{{ route('stores.create') }}">Add New Store</a>
                </div>
            </div>

            <div class="mt-4">
                <div class="table-responsive">
                    <table class="table-style-2">
                        <thead>
                        <tr>
                            <th>Name</th>
                            <th>API Key</th>
                            <th>API Secret</th>
                            <th>Creation At</th>
                            <th>
                                <div class="text-center">Actions</div>
                            </th>
                        </tr>
                        </thead>
                        <tbody>
                        @foreach($stores as $store)
                            <tr>
                                <td>{{ $store->name }}</td>
                                <td>{{ Str::limit($store->api_key, 20) }} <i onclick="copy('{{ $store->api_key }}')"
                                                                             class="cursor ms-2 fa fa-clipboard"></i>
                                </td>
                                <td>{{ Str::limit($store->api_secret, 20) }} <i
                                        onclick="copy('{{ $store->api_secret }}')"
                                        class="cursor ms-2 fa fa-clipboard"></i></td>
                                <td>{{ $store->created_at->format('Y-m-d') }}</td>
                                <td>
                                    <div class="d-flex justify-content-center actions">
                                        <a href="{{ route('store.transactions', $store->id) }}" title="Transactions">
                                            <i class="fa fa-exchange"></i>
                                        </a>
                                        <a href="{{ route('stores.edit', $store->id) }}" title="Edit">
                                            <i class="fa fa-pencil"></i>
                                        </a>
                                        <button class="btn-delete" type="button" data-id="{{ $store->id }}">
                                            <i class="fa fa-trash"></i>
                                        </button>
                                    </div>
                                </td>
                            </tr>
                        @endforeach
                        </tbody>
                    </table>
                    @if(count($stores)<=0)
                        <h4 class="text-center text-muted mt-4">No Store data available</h4>
                    @endif
                </div>
            </div>
        </div>
    </div>

    <!-- Toaster -->
    <div class="position-fixed top-0 start-50 translate-middle-x p-3" style="z-index: 11">
        <div id="liveToast" class="toast align-items-center justify-content-center text-white bg-primary border-0"
             role="alert" aria-live="assertive" aria-atomic="true">
            <div class="d-flex">
                <div class="toast-body">
                    Copied to clipboard!
                </div>
                <button type="button" class="btn-close btn-close-white me-2 m-auto" data-bs-dismiss="toast"
                        aria-label="Close"></button>
            </div>
        </div>
    </div>

    <!-- Delete Store Modal -->
    <div class="modal fade" id="deleteStore" tabindex="-1" aria-labelledby="deleteStoreModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title" id="deleteStoreModalLabel">@lang('Are you sure to delete this store?')</h4>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <p>All of this store transaction will be deleted permanently.</p>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary ps-4 pe-4" data-bs-dismiss="modal">Cancel</button>
                    <form action="" method="post">
                        @csrf
                        @method('DELETE')
                        <button type="submit" class="btn btn-primary">Confirm</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
@endsection

@section('js')
    <script>
        $(document).on('click', '.btn-delete', function (e) {
            e.preventDefault()
            const url = '{{ url('dashboard/stores') }}/' + $(this).data('id')
            $('#deleteStore form').attr('action', url)
            $('#deleteStore').modal('show')
        })
    </script>

    <script>
        // copy to clipboard script
        function copy(text) {
            const input = document.createElement('textarea');
            input.innerHTML = text;
            document.body.appendChild(input);
            input.select();
            const result = document.execCommand('copy');
            document.body.removeChild(input);

            // toaster activation script
            const toastLiveExample = document.getElementById('liveToast')
            const toast = new bootstrap.Toast(toastLiveExample)
            toast.show()

            // returning
            return result;
        }
    </script>
@endsection
