@extends('user.layouts.master')

@section('title', ' | Dashboard')

@section('css_libs')
    <link href="{{ asset('assets/libs/select2/css/select2.min.css') }}" rel="stylesheet" type="text/css"/>
@endsection

@section('breadcrumb')
    <div class="breadcrumb-area">
        <div class="container">
            <div class="breadcrumb-content">
                <h2><a href="{{ route('dashboard') }}">Dashboard</a> / My Wallet</h2>
                {{--                <p>--}}
                {{--                    There are many variations of passages of Lorem Ipsum available, but--}}
                {{--                    the majority have suffered alteration in some form, by injected--}}
                {{--                    humour, or randomised words which slightly believable.--}}
                {{--                </p>--}}
            </div>
        </div>
    </div>
@endsection

@section('content')
    <section class="wallet-list pt-100 pb-100">
        <div class="container">

            @if ($errors->any())
                <div class="alert alert-danger">
                    <ul>
                        @foreach ($errors->all() as $error)
                            <li>{{ $error }}</li>
                        @endforeach
                    </ul>
                </div>
            @endif
            @if (session('success'))
                <div class="alert alert-success" role="alert">
                    {{ session('success') }}
                </div>
            @endif
            <div class="px-3 mb-3">
                <div class="text-end">
                    <a class="btn btn-primary" href="{{ route('deposit') }}">@lang('New Deposit')</a>
                </div>
            </div>
            <div class="mt-4">
                <div class="table-responsive">
                    <table class="table-style-2">
                        <thead>
                        <tr>
                            <th>#SL</th>
                            <th>Wallet Name</th>
                            <th>Currency</th>
                            <th>My Balance</th>
                            <th class="text-center">Action</th>
                        </tr>
                        </thead>
                        <tbody>
                        @foreach($wallets as $index=>$wallet)
                            <tr>
                                <td>{{ $index+1 }}</td>
                                <td>
                                    <div class="d-flex align-items-center">
                                        {{ $wallet->currency['code'] }}
                                    </div>
                                </td>
                                <td>{{ $wallet->currency['name'] }}</td>
                                <td>{{ $wallet->currency['symbol'] .$wallet->balance }}</td>
                                <td>
                                    <div class="d-flex justify-content-center actions">
                                        <a href="{{ route('withdrawals.create', ['wallet' => $wallet->id]) }}"
                                           title="Withdraw">
                                            <img
                                                src="{{ asset('assets/front_end/images/icon/balance-withdrawal.png') }}"
                                                alt=""/>
                                        </a>
                                        <button class="openSendMoneyDialog" title="Send Money"
                                                data-id="{{ $wallet->id }}"
                                                data-title="{{ $wallet->currency['name'] }}">
                                            <img src="{{ asset('assets/front_end/images/icon/paper-plane.png') }}"
                                                 alt="">
                                        </button>
                                        <button class="openPaymentRequestDialog" title="Payment Request"
                                                data-id="{{ $wallet->currency['id'] }}"
                                                data-title="{{ $wallet->currency['name'] }}">
                                            <img src="{{ asset('assets/front_end/images/icon/payment-request.png') }}"
                                                 alt="">
                                        </button>
                                    </div>
                                </td>
                            </tr>
                        @endforeach
                        </tbody>
                    </table>
                </div>
                @if(count($wallets)<=0)
                    <h4 class="text-center text-muted mt-4">No Wallet data available</h4>
                @endif
            </div>
        </div>
    </section>

    {{--  Send Money Modal  --}}
    <div class="modal fade" id="sendMoneyDialog" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-lg" id="app">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="sendMoneyModalLabel">Send Money</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <form action="{{ route('dashboard.wallet.send-money') }}" method="post" id="sendMoneyRequest">
                        @csrf
                        <input type="hidden" name="wallet_id" id="walletID">
                        <div class="mb-3">
                            <label for="sendTo" class="col-form-label">Send To:</label>
                            <select class="form-control select2" id="sendTo" name="send_to">
                                @foreach($users as $user)
                                    <option
                                        value="{{ $user->id }}">{{ $user->first_name .' ' .$user->last_name }}</option>
                                @endforeach
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="amount" class="col-form-label">Amount:</label>
                            <input type="text" class="form-control" id="amount" name="amount" v-model="amount">
                        </div>
                        <div class="mb-3">
                            <label for="message" class="col-form-label">Message:</label>
                            <textarea class="form-control" id="message" name="message" required></textarea>
                        </div>
                    </form>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <button type="button" class="btn btn-primary submitRequest">Send Money</button>
                </div>
            </div>
        </div>
    </div>

    {{--  Payment Request Modal  --}}
    <div class="modal fade" id="paymentRequestDialog" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="sendPaymentModalLabel">Send Payment Request</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <form action="{{ route('payment-requests.store') }}" method="post" id="sendPaymentRequest">
                        @csrf
                        <input type="hidden" name="currency_id" id="currencyID">
                        <div class="mb-3">
                            <label for="sendTo" class="col-form-label">Request To:</label>
                            <select class="form-control select2" id="sendTo" name="to_id">
                                @foreach($users as $user)
                                    <option
                                        value="{{ $user->id }}">{{ $user->first_name .' ' .$user->last_name }}</option>
                                @endforeach
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="paymentAmount" class="col-form-label">Amount:</label>
                            <input type="text" class="form-control" id="paymentAmount" name="amount">
                        </div>
                        <div class="mb-3">
                            <label for="message" class="col-form-label">Note:</label>
                            <textarea class="form-control" id="message" name="note" required></textarea>
                        </div>
                    </form>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <button type="button" class="btn btn-primary submitPaymentRequest">Send Request</button>
                </div>
            </div>
        </div>
    </div>
@endsection

@section('js_libs')
    <script src="{{ asset('assets/js/vue.js') }}"></script>
    <script src="{{ asset('assets/libs/select2/js/select2.min.js') }}"></script>
@endsection

@section('js')
    <script>
        $(document).ready(function () {
            $(document).on("click", ".openSendMoneyDialog", function () {
                var walletId = $(this).data('id');
                var walletTitle = $(this).data('title');
                $(".modal-body #walletID").val(walletId);
                $("#sendMoneyModalLabel").html('Send Money (' + walletTitle + ')');
                $('#sendMoneyDialog').modal('show');
            });

            $(document).on("click", ".submitRequest", function () {
                $("#sendMoneyRequest").submit();
                $('#sendMoneyDialog').modal('hide');
            });
        })
    </script>

    <script>
        $(document).ready(function () {
            $(document).on("click", ".openPaymentRequestDialog", function () {
                var currencyID = $(this).data('id');
                var walletTitle = $(this).data('title');
                $(".modal-body #currencyID").val(currencyID);
                $("#sendPaymentModalLabel").html('Send Payment Request (' + walletTitle + ')');
                $('#paymentRequestDialog').modal('show');
            });

            $(document).on("click", ".submitPaymentRequest", function () {
                $("#sendPaymentRequest").submit();
                $('#paymentRequestDialog').modal('hide');
            });
        })
    </script>

    <script>
        window.app = new Vue({
            el: '#app',
            data: {
                withdraw_method_id: @json(old('withdraw_method_id')??null),
                methods: @json($methods),
                users: @json($users),
                amount: 0,
            },
            beforeMount() {
                if (!this.withdraw_method_id) {
                    if (this.methods.length) {
                        this.withdraw_method_id = this.methods[0].id
                    }
                }
            },
            components: {
                select2: window.select2Vue
            },
            computed: {
                method() {
                    var method = null
                    const filter = this.methods.filter(method => {
                        return method.id === this.withdraw_method_id
                    });
                    if (filter.length) {
                        method = filter[0]
                        if (method.min !== -1 && this.amount < method.min) {
                            this.amount = method.min
                        }
                        if (method.max !== -1 && this.amount > method.max) {
                            this.amount = method.max
                        }
                    }
                    return method
                },
                charge() {
                    if (!this.method) return 0;
                    var percentCharge = (this.amount * this.method.percent_charge) / 100
                    return (percentCharge + this.method.fixed_charge).toFixed({{ config('iwallet.decimals') }})
                },
                isValid() {

                }
            },
            watch: {
                // withdraw_method_id(newVal, oldVal) {
                //     if (this[this.user_type].length) {
                //         this[this.user_type + '_id'] = this[this.user_type][0].id
                //     }
                // }
            }
        })
    </script>
@endsection
