<?php

use App\Http\Controllers\Staff\CurrencyController;
use App\Http\Controllers\Staff\MixedController;
use App\Http\Controllers\Staff\NotificationController;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;
use UniSharp\LaravelFilemanager\Lfm;
use App\Http\Controllers\Staff\StaffRoleController;
use App\Http\Controllers\Staff\StaffController;
use App\Http\Controllers\Staff\UserRoleController;
use App\Http\Controllers\Staff\SettingsController;
use App\Http\Controllers\Staff\NotificationTemplateController;
use App\Http\Controllers\Staff\MenuController;
use App\Http\Controllers\Staff\UpdateController;

Auth::routes(['register' => false]);

Route::group(['middleware' => 'auth:staff'], function () {
    Route::group(['middleware' => 'able:manage_media', 'prefix' => 'media'], function () {
        Lfm::routes();
    });
    Route::get('profile/edit', [MixedController::class, 'profile'])->name('profile.edit');
    Route::put('profile/edit', [MixedController::class, 'updateProfile'])->name('profile.update');

    Route::get('dashboard', [MixedController::class, 'dashboard'])->name('dashboard');
    Route::resource('transaction', 'TransactionController')->except(['show', 'destroy', 'edit', 'update'])->middleware('able:manage_payment');
    Route::get('user-wallet/{user}', 'UserController@wallets')->middleware('able:manage_user')->name('user-wallet');
    Route::put('update-wallet-balance/{wallet}', 'UserController@updateWalletBalance')->middleware('able:manage_user');
    Route::resource('user', 'UserController')->middleware('able:manage_user');
    Route::resource('subscribers', 'SubscriberController')->middleware('able:manage_user');
    Route::resource('withdraw', 'WithdrawController')->only(['index', 'update'])->middleware('able:manage_payment');
    Route::get('all-notifications', [NotificationController::class, 'index'])->name('all-notifications');
    Route::get('view-notification/{notificationId}', [NotificationController::class, 'show'])->name('view-notification');
    Route::get('clear-all-notifications', [NotificationController::class, 'clearAll'])->name('clear-all-notifications');
    Route::resource('page', 'PageController')->middleware('able:manage_front_end');
    Route::resource('faq', 'FaqController')->middleware('able:manage_front_end');
    Route::resource('tag', 'TagController')->only(['store']);
    Route::resource('blog-post', 'BlogPostController')->middleware('able:manage_front_end');

    Route::group(['prefix' => 'staff-role', 'as' => 'staff-role.', 'middleware' => 'able:manage_role'], function () {
        Route::get('/', [StaffRoleController::class, 'index'])->name('index');
        Route::post('/', [StaffRoleController::class, 'store'])->name('store');
        Route::put('{role}', [StaffRoleController::class, 'update'])->name('update');
        Route::delete('{role}', [StaffRoleController::class, 'destroy'])->name('destroy');
    });

    Route::group(['prefix' => 'user-role', 'as' => 'user-role.', 'middleware' => 'able:manage_role'], function () {
        Route::get('/', [UserRoleController::class, 'index'])->name('index');
        Route::post('/', [UserRoleController::class, 'store'])->name('store');
        Route::get('/create', [UserRoleController::class, 'create'])->name('create');
        Route::get('{role}', [UserRoleController::class, 'edit'])->name('edit');
        Route::put('{role}', [UserRoleController::class, 'update'])->name('update');
        Route::delete('{role}', [UserRoleController::class, 'destroy'])->name('destroy');
    });

    Route::group(['prefix' => 'staff', 'as' => 'staff.', 'middleware' => 'able:manage_staff'], function () {
        Route::get('/', [StaffController::class, 'index'])->name('index');
        Route::post('/', [StaffController::class, 'store'])->name('store');
        Route::put('{staff}', [StaffController::class, 'update'])->name('update');
        Route::delete('{staff}', [StaffController::class, 'destroy'])->name('destroy');
    });

    Route::group(['prefix' => 'setting', 'as' => 'setting.', 'middleware' => 'able:manage_setting'], function () {
        Route::put('currency/refresh', [CurrencyController::class, 'refresh'])->name('currency.refresh');
        Route::resource('currency', 'CurrencyController');
        Route::resource('payment-gateway', 'PaymentGatewayController');
        Route::resource('language', 'LanguageController')->except([
            'create', 'edit', 'show'
        ]);
        Route::get('template/{type?}', [NotificationTemplateController::class, 'index'])->name('template.index');
        Route::get('template/{notificationTemplate}/edit', [NotificationTemplateController::class, 'edit'])->name('template.edit');
        Route::put('template/{notificationTemplate}', [NotificationTemplateController::class, 'update'])->name('template.update');
        Route::get('general', [SettingsController::class, 'generalSettings'])->name('general.index');
        Route::put('general', [SettingsController::class, 'updateGeneralSettings'])->name('general.update');
        Route::get('theme-settings', [SettingsController::class, 'themeSettings'])->name('theme.setting');
        Route::put('theme-settings', [SettingsController::class, 'updateThemeSettings'])->name('update.theme.setting');
        Route::get('logo', [SettingsController::class, 'logoSettings'])->name('logo.index');
        Route::put('logo', [SettingsController::class, 'updateLogoSettings'])->name('logo.update');
        Route::get('email', [SettingsController::class, 'emailSettings'])->name('email.index');
        Route::put('email', [SettingsController::class, 'updateEmailSettings'])->name('email.update');
        Route::get('service', [SettingsController::class, 'serviceSettings'])->name('service.index');
        Route::put('service', [SettingsController::class, 'updateServiceSettings'])->name('service.update');
        Route::get('app', [SettingsController::class, 'appSettings'])->name('app.index');
        Route::put('app', [SettingsController::class, 'updateAppSettings'])->name('app.update');
        Route::get('menu/{menu}/items', [MenuController::class, 'getItems'])->name('menu.getItem');
        Route::put('menu/{menu}/items', [MenuController::class, 'updateItems'])->name('menu.itemupdate');
        Route::group(['prefix' => 'application', 'as' => 'application.'], function () {
            Route::get('/', [UpdateController::class, 'index'])->name('update.index');
            Route::get('check-update', [UpdateController::class, 'checkUpdate'])->name('update.check');
            Route::get('make-backup', [UpdateController::class, 'makeBackup'])->name('update.backup');
            Route::get('download-file', [UpdateController::class, 'downloadFile'])->name('update.download');
            Route::get('update', [UpdateController::class, 'update'])->name('update.perform');
        });
        Route::resource('menu', 'MenuController');
        Route::resource('key-features', 'KeyFeatureController');
        Route::resource('our-services', 'OurServiceController');
        Route::resource('workflow', 'WorkFlowController');

        Route::put('payment-method/{paymentMethod}', 'PaymentMethodController@updateMethod')->name('payment-method.updateMethod');
        Route::resource('payment-method', 'PaymentMethodController')->only([
            'index', 'create', 'store', 'edit', 'update'
        ]);
        Route::resource('withdraw-method', 'WithdrawMethodController');
    });
});
