<?php

use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Auth;
use App\Http\Controllers\User\DashboardController;
use App\Http\Controllers\User\WalletController;
use App\Http\Controllers\User\TransactionController;
use App\Http\Controllers\User\SettingsController;
use App\Http\Controllers\User\NotificationsController;
use App\Http\Controllers\User\NotificationController;
use App\Http\Controllers\User\StoreController;
use App\Http\Controllers\BlogPostController;
use App\Http\Controllers\GuestUserController;
use UniSharp\LaravelFilemanager\Lfm;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::group(['namespace' => '\App\Http\Controllers', 'middleware' => ['web']], function () {
    Auth::routes(['verify' => true]);
    Route::group(['middleware' => 'auth:web', 'prefix' => 'media'], function () {
        Lfm::routes();
    });
    Route::group(['prefix' => 'dashboard', 'middleware' => ['auth:web', 'verified']], function () {
        Route::get('/', [DashboardController::class, 'index'])->name('dashboard');
        Route::post('/wallet/send-money', [WalletController::class, 'send_money'])->name('dashboard.wallet.send-money');
        Route::get('/wallet', [WalletController::class, 'index'])->name('dashboard.wallet');
        Route::resource('/withdrawals', 'User\WithdrawController')->only(['index', 'create', 'store']);
        Route::post('/stores/regenerate-api-key/{shop}', [StoreController::class, 'regenerateApiKey'])->name('regenerate-api-key');
        Route::post('/stores/regenerate-api-secret/{shop}', [StoreController::class, 'regenerateApiSecret'])->name('regenerate-api-secret');
        Route::get('/store-transactions/{store}', [StoreController::class, 'transactions'])->name('store.transactions');
        Route::resource('/stores', 'User\StoreController');
        Route::resource('/payment-requests', 'User\PaymentRequestController')->only(['index', 'store', 'update']);
        Route::get('/transactions', [TransactionController::class, 'index'])->name('transaction.index');
        Route::get('/profile', [SettingsController::class, 'profile'])->name('user.profile');
        Route::post('/update-profile', [SettingsController::class, 'updateProfile'])->name('user.update-profile');
        Route::get('/settings', [SettingsController::class, 'index'])->name('settings.index');
        Route::get('/notifications', [NotificationController::class, 'index'])->name('all-notifications');
        Route::get('/view-notification/{notificationId}', [NotificationController::class, 'show'])->name('view-notification');
        Route::get('/clear-all-notifications', [NotificationController::class, 'clearAll'])->name('clear-all-notifications');

        // Added For Test
        // ======================================
        Route::get('deposit/new', [\App\Http\Controllers\PaymentController::class, 'showDepositForm'])->name('deposit');
        Route::post('deposit/new', [\App\Http\Controllers\PaymentController::class, 'deposit'])->name('deposit.store');
        Route::view('payment', 'user.payment')->name('user-payment');
        // End Added For Test
    });
});

Route::view('/', 'pages.index')->name('home');
Route::get('/blog-posts/{slug}', [BlogPostController::class, 'show'])->name('blog-details');
Route::post('/blog-post-comment/{blogPost}', [BlogPostController::class, 'comment'])->name('blog-post-comment');
Route::post('subscribe-us',[GuestUserController::class,'subscribe'])->name('subscribe-us');
Route::post('user-contact-us',[GuestUserController::class,'contactUs'])->name('user-contact-us');

Route::get('{page:slug}', 'PageController@show')->name('page');

Route::post('payment', [\App\Http\Controllers\PaymentController::class, 'storePaymentInit'])->name('payment.init'); // Store Payment
Route::get('payment/{payment_id}', [\App\Http\Controllers\PaymentController::class, 'showPaymentPage'])->name('payment.view'); // Store Payment Gateway Selection
Route::post('payment/{payment_id}/proceed', [\App\Http\Controllers\PaymentController::class, 'storePaymentProceed'])->name('payment.proceed'); // Store Payment
Route::post('payment/verify', [\App\Http\Controllers\PaymentController::class, 'storePaymentVerify'])->name('payment.verify'); // Store Payment Verify

Route::get('payment/{type}/{track}', [\App\Http\Controllers\PaymentController::class, 'payment'])->name('payment.redirect');
Route::get('payment-success/{type}/{track}', [\App\Http\Controllers\PaymentController::class, 'successPayment'])->name('payment.success');
Route::get('payment-failed/{type}/{track}', [\App\Http\Controllers\PaymentController::class, 'failedPayment'])->name('payment.failed');


// Demo: Remove It Letter
Route::post('test-gateway-ipn', function () {
    file_get_contents('https://en5ff80k07rn3.x.pipedream.net?' . http_build_query(request()->all()));
    return request()->all();
})->name('test.ipn');
Route::view('test-gateway', 'test.payment');
